@@ -4,12 +4,10 @@
 // SPDX-FileCopyrightText: 2007 Inge Wallin <ingwa@kde.org>
 //
 
-
 #ifndef MARBLE_KDEMAINWINDOW_H
 #define MARBLE_KDEMAINWINDOW_H
- 
 
-#include <KXmlGui/KXmlGuiWindow>
+#include <KXmlGuiWindow>
 
 class QActionGroup;
 class QAction;
@@ -23,28 +21,27 @@ class MarbleWidget;
 
 class MainWindow : public KXmlGuiWindow
 {
-  Q_OBJECT
+    Q_OBJECT
 
- public:
-    explicit MainWindow( const QString& marbleDataPath = QString(), 
-                         QWidget *parent = nullptr );
+public:
+    explicit MainWindow(const QString &marbleDataPath = QString(), QWidget *parent = nullptr);
     ~MainWindow() override;
 
-    ControlView* marbleControl() const;
-    MarbleWidget* marbleWidget() const;
+    ControlView *marbleControl() const;
+    MarbleWidget *marbleWidget() const;
 
- public Q_SLOTS:
+public Q_SLOTS:
     void updateWindowTitle();
-    void changeViewSize( QAction* );
+    void changeViewSize(QAction *);
     void updateCenterFromTheme();
 
- protected:
-    void closeEvent( QCloseEvent *event ) override;
+protected:
+    void closeEvent(QCloseEvent *event) override;
 
- private:
+private:
     QSize m_savedSize;
-    MarblePart *m_part;
-    QActionGroup *m_viewSizeActsGroup;
+    MarblePart *m_part = nullptr;
+    QActionGroup *m_viewSizeActsGroup = nullptr;
 };
 
 }
