@@ -7,18 +7,21 @@
 #define TEXTTOSPEECHCLIENT_H
 
 #include <QObject>
+#include <qqmlregistration.h>
 
 class TextToSpeechClient : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
-    explicit TextToSpeechClient(QObject * parent = nullptr);
+    explicit TextToSpeechClient(QObject *parent = nullptr);
     ~TextToSpeechClient() override;
 
 public Q_SLOTS:
-    Q_INVOKABLE void readText(const QString & text);
-    Q_INVOKABLE void setLocale(const QString & locale);
+    Q_INVOKABLE void readText(const QString &text);
+    Q_INVOKABLE void setLocale(const QString &locale);
 };
 
 #endif
