@@ -18,14 +18,14 @@ class MarbleWidget;
 
 class MarbleTest
 {
- public:
-    explicit MarbleTest( MarbleWidget* marbleWidget );
-    virtual ~MarbleTest(){ }
+public:
+    explicit MarbleTest(MarbleWidget *marbleWidget);
+    virtual ~MarbleTest() = default;
 
     void timeDemo();
 
- private:
-    MarbleWidget      *m_marbleWidget;
+private:
+    MarbleWidget *const m_marbleWidget;
 };
 
 }
