@@ -6,24 +6,25 @@
 #ifndef MARBLE_GEOURIPARSER_H
 #define MARBLE_GEOURIPARSER_H
 
-#include "Planet.h"
 #include "GeoDataCoordinates.h"
+#include "Planet.h"
 #include "marble_export.h"
 
-namespace Marble {
+namespace Marble
+{
 
 /**
  * A class for parsing Geo: URIs.
  * Wikipage: https://en.wikipedia.org/wiki/Geo_URI
  * RFC: 5870 (8 June 2010)
  */
-class MARBLE_EXPORT GeoUriParser {
-
+class MARBLE_EXPORT GeoUriParser
+{
 public:
     /**
      * Constructs a new GeoUriParser with the given Geo URI
      */
-    explicit GeoUriParser( const QString& geoUri = QString() );
+    explicit GeoUriParser(const QString &geoUri = QString());
 
     /**
      * Returns the Geo URI stored in this parser
@@ -32,7 +33,7 @@ public:
     /**
      * Set the Geo URI to be parsed.
      */
-    void setGeoUri( const QString& geoUri );
+    void setGeoUri(const QString &geoUri);
 
     /**
      * Returns the coordinates parsed.
@@ -53,7 +54,7 @@ public:
     bool parse();
 
 private:
-    static QString queryValue( const QUrl& url, const QString& key, const QString& secondaryKey=QString() );
+    static QString queryValue(const QUrl &url, const QString &key, const QString &secondaryKey = QString());
 
     QString m_geoUri;
     GeoDataCoordinates m_coordinates;
