@@ -15,7 +15,6 @@ LayerInterface::~LayerInterface()
     // nothing to do
 }
 
-
 qreal LayerInterface::zValue() const
 {
     return 0.0;
@@ -28,7 +27,7 @@ RenderState LayerInterface::renderState() const
 
 QString LayerInterface::runtimeTrace() const
 {
-    return QString();
+    return {};
 }
 
 } // namespace Marble
