@@ -6,7 +6,6 @@
 #include "MarbleGlobal.h"
 #include "MarbleGlobal_p.h"
 
-
 namespace Marble
 {
 
@@ -17,15 +16,12 @@ MarbleGlobalPrivate::MarbleGlobalPrivate()
     m_profiles |= MarbleGlobal::SmallScreen;
     m_profiles |= MarbleGlobal::HighResolution;
 #endif
-
 }
 
-MarbleGlobalPrivate::~MarbleGlobalPrivate()
-{
-}
+MarbleGlobalPrivate::~MarbleGlobalPrivate() = default;
 
 MarbleGlobal::MarbleGlobal()
-    : d ( new MarbleGlobalPrivate )
+    : d(new MarbleGlobalPrivate)
 {
 }
 
@@ -34,22 +30,24 @@ MarbleGlobal::~MarbleGlobal()
     delete d;
 }
 
-MarbleGlobal * MarbleGlobal::getInstance()
+MarbleGlobal *MarbleGlobal::getInstance()
 {
-    static MarbleGlobal instance; 
-    return &instance; 
+    static MarbleGlobal instance;
+    return &instance;
 }
 
-MarbleLocale * MarbleGlobal::locale() const
+MarbleLocale *MarbleGlobal::locale() const
 {
-    return &d->m_locale; 
+    return &d->m_locale;
 }
 
-MarbleGlobal::Profiles MarbleGlobal::profiles() const {
+MarbleGlobal::Profiles MarbleGlobal::profiles() const
+{
     return d->m_profiles;
 }
 
-void MarbleGlobal::setProfiles( MarbleGlobal::Profiles profiles ) {
+void MarbleGlobal::setProfiles(MarbleGlobal::Profiles profiles)
+{
     d->m_profiles = profiles;
 }
 
