@@ -18,21 +18,45 @@ OsmcSymbol::OsmcSymbol(const QString &tag, int size)
     , m_textColor(Qt::black)
     , m_side(size)
 {
-    m_backgroundTypes
-            << "round" << "circle" << "frame";
+    m_backgroundTypes << "round"
+                      << "circle"
+                      << "frame";
 
-    m_foregroundTypes
-            << "dot" << "bowl" << "circle" << "bar"
-            << "stripe" << "cross" << "x" << "slash"
-            << "backslash" << "rectangle" << "rectangle_line"
-            << "triangle" << "triangle_turned" << "triangle_line"
-            << "diamond" << "pointer" << "fork" << "arch"
-            << "turned_T" << "L" << "lower" << "corner"
-            << "drop_line" << "horse" << "hiker";
+    m_foregroundTypes << "dot"
+                      << "bowl"
+                      << "circle"
+                      << "bar"
+                      << "stripe"
+                      << "cross"
+                      << "x"
+                      << "slash"
+                      << "backslash"
+                      << "rectangle"
+                      << "rectangle_line"
+                      << "triangle"
+                      << "triangle_turned"
+                      << "triangle_line"
+                      << "diamond"
+                      << "pointer"
+                      << "fork"
+                      << "arch"
+                      << "turned_T"
+                      << "L"
+                      << "lower"
+                      << "corner"
+                      << "drop_line"
+                      << "horse"
+                      << "hiker";
 
-    m_precoloredForegroundTypes
-            << "wolfshook" << "shell" << "shell_modern" << "ammonit"
-            << "mine" << "hiker" << "heart" << "tower" << "bridleway";
+    m_precoloredForegroundTypes << "wolfshook"
+                                << "shell"
+                                << "shell_modern"
+                                << "ammonit"
+                                << "mine"
+                                << "hiker"
+                                << "heart"
+                                << "tower"
+                                << "bridleway";
 
     if (parseTag(tag)) {
         render();
@@ -63,8 +87,8 @@ bool OsmcSymbol::parseTag(const QString &tag)
     }
 
     // Determine way color
-    if (QColor::isValidColor(parts.at(0))) {
-        m_wayColor.setNamedColor(parts.at(0));
+    if (QColor::isValidColorName(parts.at(0))) {
+        m_wayColor.fromString(parts.at(0));
     } else {
         return false;
     }
@@ -76,7 +100,7 @@ bool OsmcSymbol::parseTag(const QString &tag)
     if (parts.size() == 3) {
         m_foreground = parseForeground(parts.at(2));
     } else if (parts.size() == 4) {
-        if (QColor::isValidColor(parts.at(3))) {
+        if (QColor::isValidColorName(parts.at(3))) {
             m_text = parts.at(2);
             m_textColor = parts.at(3);
         } else {
@@ -85,7 +109,7 @@ bool OsmcSymbol::parseTag(const QString &tag)
         }
     } else if (parts.size() == 5) {
         m_foreground = parseForeground(parts.at(2));
-        if (QColor::isValidColor(parts.at(4))) {
+        if (QColor::isValidColorName(parts.at(4))) {
             m_text = parts.at(3);
             m_textColor = parts.at(4);
         } else {
@@ -94,9 +118,9 @@ bool OsmcSymbol::parseTag(const QString &tag)
     } else if (parts.size() == 6) {
         m_foreground = parseForeground(parts.at(2));
         m_foreground2 = parseForeground(parts.at(3));
-        if (QColor::isValidColor(parts.at(5))) {
+        if (QColor::isValidColorName(parts.at(5))) {
             m_text = parts.at(4);
-            m_textColor.setNamedColor(parts.at(5));
+            m_textColor.fromString(parts.at(5));
         } else {
             return false;
         }
@@ -112,16 +136,16 @@ bool OsmcSymbol::parseBackground(const QString &bg)
     QString color = bg.section("_", 0, 0);
     QString type = bg.section("_", 1, -1);
 
-    if (!QColor::isValidColor(color)) {
+    if (!QColor::isValidColorName(color)) {
         return false;
     }
 
     // Plain color was provided
     if (type.isEmpty()) {
-        m_backgroundColor.setNamedColor(color);
+        m_backgroundColor.fromString(color);
         m_backgroundType = type;
     } else if (m_backgroundTypes.contains(type)) {
-        m_backgroundColor.setNamedColor(color);
+        m_backgroundColor.fromString(color);
         m_backgroundType = type;
     } else {
         return false;
@@ -130,19 +154,19 @@ bool OsmcSymbol::parseBackground(const QString &bg)
     return true;
 }
 
-void setXMLAttribute(QDomElement &elem, const QString& tag, const QString& attr, const QString& attrValue);
+void setXMLAttribute(QDomElement &elem, const QString &tag, const QString &attr, const QString &attrValue);
 
-QSvgRenderer* OsmcSymbol::parseForeground(const QString &fg)
+QSvgRenderer *OsmcSymbol::parseForeground(const QString &fg)
 {
     if (m_precoloredForegroundTypes.contains(fg)) {
-        return new QSvgRenderer(QString(":/osmc-symbols/%1.svg").arg(fg));
+        return new QSvgRenderer(QStringLiteral(":/osmc-symbols/%1.svg").arg(fg));
     }
 
     QString color = fg.section('_', 0, 0);
     QString type = fg.section('_', 1, -1);
-    if (QColor::isValidColor(color) && m_foregroundTypes.contains(type)) {
+    if (QColor::isValidColorName(color) && m_foregroundTypes.contains(type)) {
         // Open svg resource and load contents to QByteArray
-        QFile file(QString(":/osmc-symbols/%1.svg").arg(type));
+        QFile file(QStringLiteral(":/osmc-symbols/%1.svg").arg(type));
         file.open(QIODevice::ReadOnly);
         QByteArray baData = file.readAll();
 
@@ -229,7 +253,7 @@ QColor OsmcSymbol::wayColor() const
     return m_wayColor;
 }
 
-void setXMLAttribute(QDomElement &elem, const QString& tag, const QString& attr, const QString& attrValue)
+void setXMLAttribute(QDomElement &elem, const QString &tag, const QString &attr, const QString &attrValue)
 {
     // If elem's tag is equal to the provided one then overwrite desired attribute
     if (elem.tagName() == tag) {
