@@ -9,8 +9,8 @@
 
 #include "PositionProviderPlugin.h"
 
-#include "GeoDataCoordinates.h"
 #include "GeoDataAccuracy.h"
+#include "GeoDataCoordinates.h"
 
 #include <QDateTime>
 
@@ -20,13 +20,13 @@ namespace Marble
 class GeoDataPlacemark;
 class MarbleModel;
 
-class PlacemarkPositionProviderPlugin: public PositionProviderPlugin
+class PlacemarkPositionProviderPlugin : public PositionProviderPlugin
 {
     Q_OBJECT
-    Q_INTERFACES( Marble::PositionProviderPluginInterface )
+    Q_INTERFACES(Marble::PositionProviderPluginInterface)
 
- public:
-    explicit PlacemarkPositionProviderPlugin( MarbleModel *marbleModel, QObject* parent=nullptr );
+public:
+    explicit PlacemarkPositionProviderPlugin(MarbleModel *marbleModel, QObject *parent = nullptr);
 
     QString name() const override;
     QString nameId() const override;
@@ -34,7 +34,7 @@ class PlacemarkPositionProviderPlugin: public PositionProviderPlugin
     QString version() const override;
     QString description() const override;
     QString copyrightYears() const override;
-    QVector<PluginAuthor> pluginAuthors() const override;
+    QList<PluginAuthor> pluginAuthors() const override;
     QIcon icon() const override;
     void initialize() override;
     bool isInitialized() const override;
@@ -48,7 +48,7 @@ class PlacemarkPositionProviderPlugin: public PositionProviderPlugin
     qreal direction() const override;
     QDateTime timestamp() const override;
 
- private:
+private:
     MarbleModel *const m_marbleModel;
     const GeoDataPlacemark *m_placemark;
     GeoDataCoordinates m_coordinates;
@@ -60,8 +60,8 @@ class PlacemarkPositionProviderPlugin: public PositionProviderPlugin
     GeoDataAccuracy m_accuracy;
     bool m_isInitialized;
 
- private Q_SLOTS:
-    void setPlacemark( const GeoDataPlacemark *placemark );
+private Q_SLOTS:
+    void setPlacemark(const GeoDataPlacemark *placemark);
 
     void updatePosition();
 };
