@@ -11,14 +11,12 @@ namespace Marble
 class PositionProviderPluginPrivate
 {
 public:
-    PositionProviderPluginPrivate()
-    {
-    }
+    PositionProviderPluginPrivate() = default;
 };
 
 PositionProviderPlugin::PositionProviderPlugin(QObject *parent)
-    : QObject(parent),
-      d( new PositionProviderPluginPrivate() )
+    : QObject(parent)
+    , d(new PositionProviderPluginPrivate())
 {
 }
 
