@@ -9,7 +9,6 @@
 #include "PositionProviderPluginInterface.h"
 #include "marble_export.h"
 
-
 namespace Marble
 {
 class PositionProviderPluginPrivate;
@@ -21,7 +20,7 @@ class MARBLE_EXPORT PositionProviderPlugin : public QObject, public PositionProv
 {
     Q_OBJECT
 
- public:
+public:
     ~PositionProviderPlugin() override;
 
     /**
@@ -35,20 +34,18 @@ class MARBLE_EXPORT PositionProviderPlugin : public QObject, public PositionProv
      * Create a new PositionProvider Plugin and return it.
      * Has to be defined in concrete position provider plugin classes.
      */
-    virtual PositionProviderPlugin * newInstance() const = 0;
+    virtual PositionProviderPlugin *newInstance() const = 0;
 
- Q_SIGNALS:
-    void statusChanged( PositionProviderStatus status ) const;
-    void positionChanged( const GeoDataCoordinates& position,
-                          const GeoDataAccuracy& accuracy ) const;
+Q_SIGNALS:
+    void statusChanged(PositionProviderStatus status) const;
+    void positionChanged(const GeoDataCoordinates &position, const GeoDataAccuracy &accuracy) const;
 
- protected:
-    PositionProviderPlugin(QObject* parent=nullptr);
-
- private:
-    Q_DISABLE_COPY( PositionProviderPlugin )
-    PositionProviderPluginPrivate *d;
+protected:
+    PositionProviderPlugin(QObject *parent = nullptr);
 
+private:
+    Q_DISABLE_COPY(PositionProviderPlugin)
+    PositionProviderPluginPrivate *const d;
 };
 
 }
