@@ -8,9 +8,9 @@
 
 #include <QDialog>
 
-#include "marble_export.h"
 #include "MarbleGlobal.h"
 #include "MarbleLocale.h"
+#include "marble_export.h"
 
 namespace Marble
 {
@@ -23,14 +23,13 @@ class QtMarbleConfigDialogPrivate;
 class MARBLE_EXPORT QtMarbleConfigDialog : public QDialog
 {
     Q_OBJECT
-    
-    public:
-    explicit QtMarbleConfigDialog(MarbleWidget *marbleWidget, CloudSyncManager *syncManager = nullptr,
-                                   QWidget *parent = nullptr );
+
+public:
+    explicit QtMarbleConfigDialog(MarbleWidget *marbleWidget, CloudSyncManager *syncManager = nullptr, QWidget *parent = nullptr);
     ~QtMarbleConfigDialog() override;
 
     // View Settings
-    
+
     MarbleLocale::MeasurementSystem measurementSystem() const;
     Marble::AngleUnit angleUnit() const;
     void setAngleUnit(Marble::AngleUnit unit);
@@ -86,9 +85,9 @@ class MARBLE_EXPORT QtMarbleConfigDialog : public QDialog
      * Read the value of 'Time/chosenTimezone' key from settings
      */
     int chosenTimezone() const;
-    
+
     void initializeCustomTimezone();
-    
+
     // CloudSync settings
     bool syncEnabled() const;
     QString syncBackend() const;
@@ -98,7 +97,7 @@ class MARBLE_EXPORT QtMarbleConfigDialog : public QDialog
     QString owncloudUsername() const;
     QString owncloudPassword() const;
 
-    Q_SIGNALS:
+Q_SIGNALS:
     /**
      * This signal is emitted when the loaded settings were changed.
      * Either by the user or by loading them initially from disk.
@@ -120,7 +119,7 @@ class MARBLE_EXPORT QtMarbleConfigDialog : public QDialog
      */
     void syncNowClicked();
 
-    public Q_SLOTS:
+public Q_SLOTS:
     /**
      * Disable "Sync Now" button while sync or for 30 sec of timout
      */
@@ -140,14 +139,14 @@ class MARBLE_EXPORT QtMarbleConfigDialog : public QDialog
     /**
      * Show status on cloud sync settings tab
      */
-    void updateCloudSyncStatus( const QString &status );
+    void updateCloudSyncStatus(const QString &status);
 
     /**
      * Write settings to disk.
      */
     void writeSettings();
-    
-    private Q_SLOTS:
+
+private Q_SLOTS:
     /**
      * Synchronize the loaded settings with the file on hard disk.
      */
@@ -155,10 +154,10 @@ class MARBLE_EXPORT QtMarbleConfigDialog : public QDialog
 
     void updateCloudSyncCredentials();
 
-    private:
-    Q_DISABLE_COPY( QtMarbleConfigDialog )
+private:
+    Q_DISABLE_COPY(QtMarbleConfigDialog)
 
-    QtMarbleConfigDialogPrivate * const d;
+    QtMarbleConfigDialogPrivate *const d;
 };
 
 } // Marble namespace
