@@ -31,18 +31,18 @@ public:
      * This enum contains the data roles for the QStandardItems.
      */
     enum ItemDataRole {
-        Name = Qt::DisplayRole,          // QString
-        Icon = Qt::DecorationRole,       // QIcon
-        Description = Qt::ToolTipRole,   // QString
-        NameId = Qt::UserRole + 2,       // QString
-        ConfigurationDialogAvailable,    // bool
-        BackendTypes,                    // QStringList
-        Version,                         // QString
-        AboutDataText,                   // QString
-        CopyrightYears                   // QString
+        Name = Qt::DisplayRole, // QString
+        Icon = Qt::DecorationRole, // QIcon
+        Description = Qt::ToolTipRole, // QString
+        NameId = Qt::UserRole + 2, // QString
+        ConfigurationDialogAvailable, // bool
+        BackendTypes, // QStringList
+        Version, // QString
+        AboutDataText, // QString
+        CopyrightYears // QString
     };
 
-    explicit RenderPluginModel( QObject *parent = nullptr );
+    explicit RenderPluginModel(QObject *parent = nullptr);
 
     ~RenderPluginModel() override;
 
@@ -54,11 +54,11 @@ public:
      *
      * @param renderPlugins the RenderPlugins to be managed
      */
-    void setRenderPlugins( const QList<RenderPlugin *> &renderPlugins );
+    void setRenderPlugins(const QList<RenderPlugin *> &renderPlugins);
 
-    QVector<PluginAuthor> pluginAuthors( const QModelIndex &index ) const;
+    QList<PluginAuthor> pluginAuthors(const QModelIndex &index) const;
 
-    DialogConfigurationInterface *pluginDialogConfigurationInterface( const QModelIndex &index );
+    DialogConfigurationInterface *pluginDialogConfigurationInterface(const QModelIndex &index);
 
 public Q_SLOTS:
     /**
