@@ -5,22 +5,20 @@
 
 #include "MergeItem.h"
 
-
-namespace Marble {
-
-MergeItem::MergeItem()
+namespace Marble
 {
-}
+
+MergeItem::MergeItem() = default;
 
 QString MergeItem::pathA() const
 {
     return m_pathA;
 }
 
-void MergeItem::setPathA( const QString &path )
+void MergeItem::setPathA(const QString &path)
 {
     m_pathA = path;
-    emit pathAChanged();
+    Q_EMIT pathAChanged();
 }
 
 QString MergeItem::pathB() const
@@ -28,10 +26,10 @@ QString MergeItem::pathB() const
     return m_pathB;
 }
 
-void MergeItem::setPathB( const QString &path )
+void MergeItem::setPathB(const QString &path)
 {
     m_pathB = path;
-    emit pathBChanged();
+    Q_EMIT pathBChanged();
 }
 
 GeoDataPlacemark MergeItem::placemarkA() const
@@ -39,12 +37,12 @@ GeoDataPlacemark MergeItem::placemarkA() const
     return m_placemarkA;
 }
 
-void MergeItem::setPlacemarkA( const GeoDataPlacemark &placemark )
+void MergeItem::setPlacemarkA(const GeoDataPlacemark &placemark)
 {
     m_placemarkA = placemark;
-    emit placemarkAChanged();
-    emit nameAChanged();
-    emit descriptionAChanged();
+    Q_EMIT placemarkAChanged();
+    Q_EMIT nameAChanged();
+    Q_EMIT descriptionAChanged();
 }
 
 GeoDataPlacemark MergeItem::placemarkB() const
@@ -52,12 +50,12 @@ GeoDataPlacemark MergeItem::placemarkB() const
     return m_placemarkB;
 }
 
-void MergeItem::setPlacemarkB( const GeoDataPlacemark &placemark )
+void MergeItem::setPlacemarkB(const GeoDataPlacemark &placemark)
 {
     m_placemarkB = placemark;
-    emit placemarkBChanged();
-    emit nameBChanged();
-    emit descriptionBChanged();
+    Q_EMIT placemarkBChanged();
+    Q_EMIT nameBChanged();
+    Q_EMIT descriptionBChanged();
 }
 
 QString MergeItem::nameA() const
@@ -80,12 +78,12 @@ QString MergeItem::descriptionB() const
     return m_placemarkB.description();
 }
 
-MergeItem::Action MergeItem::actionA()
+MergeItem::Action MergeItem::actionA() const
 {
     return m_actionA;
 }
 
-void MergeItem::setActionA( MergeItem::Action action )
+void MergeItem::setActionA(MergeItem::Action action)
 {
     m_actionA = action;
 }
@@ -95,7 +93,7 @@ MergeItem::Action MergeItem::actionB() const
     return m_actionB;
 }
 
-void MergeItem::setActionB( MergeItem::Action action )
+void MergeItem::setActionB(MergeItem::Action action)
 {
     m_actionB = action;
 }
@@ -105,10 +103,10 @@ MergeItem::Resolution MergeItem::resolution() const
     return m_resolution;
 }
 
-void MergeItem::setResolution( MergeItem::Resolution resolution )
+void MergeItem::setResolution(MergeItem::Resolution resolution)
 {
     m_resolution = resolution;
-    emit resolutionChanged();
+    Q_EMIT resolutionChanged();
 }
 
 }
