@@ -6,32 +6,32 @@
 #ifndef MERGEITEM_H
 #define MERGEITEM_H
 
-#include "marble_export.h"
 #include "GeoDataPlacemark.h"
+#include "marble_export.h"
 
 #include <QObject>
 
-namespace Marble {
+namespace Marble
+{
 
 class MARBLE_EXPORT MergeItem : public QObject
 {
-
     Q_OBJECT
 
 public:
     MergeItem();
 
-    Q_PROPERTY( QString pathA READ pathA WRITE setPathA NOTIFY pathAChanged )
-    Q_PROPERTY( QString pathB READ pathB WRITE setPathB NOTIFY pathBChanged )
-    Q_PROPERTY( GeoDataPlacemark placemarkA READ placemarkA WRITE setPlacemarkA NOTIFY placemarkAChanged )
-    Q_PROPERTY( GeoDataPlacemark placemarkB READ placemarkB WRITE setPlacemarkB NOTIFY placemarkBChanged )
-    Q_PROPERTY( QString nameA READ nameA NOTIFY nameAChanged() )
-    Q_PROPERTY( QString nameB READ nameB NOTIFY nameBChanged() )
-    Q_PROPERTY( QString descriptionA READ descriptionA NOTIFY descriptionAChanged() )
-    Q_PROPERTY( QString descriptionB READ descriptionB NOTIFY descriptionBChanged() )
-    Q_PROPERTY( MergeItem::Action actionA READ actionA WRITE setActionA NOTIFY actionAChanged )
-    Q_PROPERTY( MergeItem::Action actionB READ actionB WRITE setActionB NOTIFY actionBChanged )
-    Q_PROPERTY( MergeItem::Resolution resolution READ resolution WRITE setResolution NOTIFY resolutionChanged )
+    Q_PROPERTY(QString pathA READ pathA WRITE setPathA NOTIFY pathAChanged)
+    Q_PROPERTY(QString pathB READ pathB WRITE setPathB NOTIFY pathBChanged)
+    Q_PROPERTY(GeoDataPlacemark placemarkA READ placemarkA WRITE setPlacemarkA NOTIFY placemarkAChanged)
+    Q_PROPERTY(GeoDataPlacemark placemarkB READ placemarkB WRITE setPlacemarkB NOTIFY placemarkBChanged)
+    Q_PROPERTY(QString nameA READ nameA NOTIFY nameAChanged())
+    Q_PROPERTY(QString nameB READ nameB NOTIFY nameBChanged())
+    Q_PROPERTY(QString descriptionA READ descriptionA NOTIFY descriptionAChanged())
+    Q_PROPERTY(QString descriptionB READ descriptionB NOTIFY descriptionBChanged())
+    Q_PROPERTY(MergeItem::Action actionA READ actionA WRITE setActionA NOTIFY actionAChanged)
+    Q_PROPERTY(MergeItem::Action actionB READ actionB WRITE setActionB NOTIFY actionBChanged)
+    Q_PROPERTY(MergeItem::Resolution resolution READ resolution WRITE setResolution NOTIFY resolutionChanged)
 
     enum Resolution {
         None,
@@ -45,16 +45,16 @@ public:
     };
 
     QString pathA() const;
-    void setPathA( const QString &path );
+    void setPathA(const QString &path);
 
     QString pathB() const;
-    void setPathB( const QString &path );
+    void setPathB(const QString &path);
 
     GeoDataPlacemark placemarkA() const;
-    void setPlacemarkA( const GeoDataPlacemark &placemark );
+    void setPlacemarkA(const GeoDataPlacemark &placemark);
 
     GeoDataPlacemark placemarkB() const;
-    void setPlacemarkB( const GeoDataPlacemark &placemark );
+    void setPlacemarkB(const GeoDataPlacemark &placemark);
 
     QString nameA() const;
     QString nameB() const;
@@ -62,14 +62,14 @@ public:
     QString descriptionA() const;
     QString descriptionB() const;
 
-    MergeItem::Action actionA();
-    void setActionA( MergeItem::Action action );
+    MergeItem::Action actionA() const;
+    void setActionA(MergeItem::Action action);
 
     MergeItem::Action actionB() const;
-    void setActionB( MergeItem::Action action );
+    void setActionB(MergeItem::Action action);
 
     MergeItem::Resolution resolution() const;
-    void setResolution( MergeItem::Resolution resolution );
+    void setResolution(MergeItem::Resolution resolution);
 
 Q_SIGNALS:
     void pathAChanged();
@@ -92,7 +92,6 @@ private:
     MergeItem::Action m_actionA;
     MergeItem::Action m_actionB;
     MergeItem::Resolution m_resolution;
-
 };
 
 }
