@@ -7,21 +7,24 @@
 #define MARBLE_DECLARATIVE_OBJECT_H
 
 #include <QObject>
+#include <qqmlintegration.h>
 
 class MarbleDeclarativeObjectPrivate;
 
 /**
-  * Provides access to global Marble related properties and methods
-  * to QML (intended to be registered as a global QML object)
-  */
+ * Provides access to global Marble related properties and methods
+ * to QML (intended to be registered as a global QML object)
+ */
 class MarbleDeclarativeObject : public QObject
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(Marble)
+    QML_SINGLETON
 
     Q_PROPERTY(QString version READ version CONSTANT)
 
 public:
-    explicit MarbleDeclarativeObject( QObject* parent = nullptr );
+    explicit MarbleDeclarativeObject(QObject *parent = nullptr);
 
     ~MarbleDeclarativeObject() override;
 
@@ -36,7 +39,7 @@ public Q_SLOTS:
      * relative path cannot be resolved
      * @see MarbleDirs
      */
-    QString resolvePath( const QString &path ) const;
+    QString resolvePath(const QString &path) const;
 
     /**
      * @brief canExecute Check whether a given program is found in the path
@@ -45,10 +48,10 @@ public Q_SLOTS:
      * directories defined by the PATH environment variable (as reported by
      * QProcessEnvironment) and has the executable bit set
      */
-    bool canExecute( const QString &program ) const;
+    bool canExecute(const QString &program) const;
 
 private:
-    MarbleDeclarativeObjectPrivate* const d;
+    MarbleDeclarativeObjectPrivate *const d;
 };
 
 #endif
