@@ -10,17 +10,20 @@
 #include "RouteRelationModel.h"
 
 #include <QObject>
-#include <QtQml>
 #include <QStringListModel>
+#include <QUrl>
+#include <qqmlregistration.h>
 
-namespace Marble {
+namespace Marble
+{
 
 /**
-  * Wraps a GeoDataPlacemark for QML access
-  */
+ * Wraps a GeoDataPlacemark for QML access
+ */
 class Placemark : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
 
     Q_PROPERTY(QString name WRITE setName READ name NOTIFY nameChanged)
     Q_PROPERTY(QString description READ description NOTIFY descriptionChanged)
@@ -36,16 +39,16 @@ class Placemark : public QObject
     Q_PROPERTY(double latitude READ latitude NOTIFY coordinatesChanged)
     Q_PROPERTY(QStringList tags READ tags NOTIFY tagsChanged)
 
-    Q_PROPERTY(RouteRelationModel* routeRelationModel READ routeRelationModel CONSTANT)
+    Q_PROPERTY(RouteRelationModel *routeRelationModel READ routeRelationModel CONSTANT)
 
 public:
     /** Constructor */
-    explicit Placemark( QObject *parent = nullptr );
+    explicit Placemark(QObject *parent = nullptr);
 
-    void setGeoDataPlacemark( const Marble::GeoDataPlacemark &placemark );
+    void setGeoDataPlacemark(const Marble::GeoDataPlacemark &placemark);
 
-    Marble::GeoDataPlacemark & placemark();
-    const Marble::GeoDataPlacemark & placemark() const;
+    Marble::GeoDataPlacemark &placemark();
+    const Marble::GeoDataPlacemark &placemark() const;
 
     QString name() const;
     QString description() const;
@@ -59,9 +62,9 @@ public:
     QString phone() const;
     double longitude() const;
     double latitude() const;
-    const QStringList & tags() const;
+    const QStringList &tags() const;
 
-    RouteRelationModel* routeRelationModel();
+    RouteRelationModel *routeRelationModel();
 
 public Q_SLOTS:
     void setName(const QString &name);
@@ -82,7 +85,7 @@ Q_SIGNALS:
     void routeRelationModelChanged();
 
 private:
-    bool addTagValue(QString &target, const QString &key, const QString &format=QString(), const QString& separator = QStringLiteral(" · ")) const;
+    bool addTagValue(QString &target, const QString &key, const QString &format = QString(), const QString &separator = QStringLiteral(" · ")) const;
     void addFirstTagValueOf(QString &target, const QStringList &keys) const;
     void addTagDescription(QString &target, const QString &key, const QString &value, const QString &description) const;
     static void append(QString &target, const QString &value);
@@ -107,6 +110,4 @@ private:
 
 }
 
-QML_DECLARE_TYPE(Marble::Placemark)
-
 #endif // MARBLE_DECLARATIVE_PLACEMARK_H
