@@ -15,18 +15,17 @@ class GeoDataDeletePrivate : public GeoDataContainerPrivate
 {
 };
 
-
 GeoDataDelete::GeoDataDelete()
-  : GeoDataContainer(new GeoDataDeletePrivate)
+    : GeoDataContainer(new GeoDataDeletePrivate)
 {
 }
 
 GeoDataDelete::GeoDataDelete(const GeoDataDelete &other)
-  : GeoDataContainer(other, new GeoDataDeletePrivate(*other.d_func()))
+    : GeoDataContainer(other, new GeoDataDeletePrivate(*other.d_func()))
 {
 }
 
-GeoDataDelete &GeoDataDelete::operator=( const GeoDataDelete &other )
+GeoDataDelete &GeoDataDelete::operator=(const GeoDataDelete &other)
 {
     if (this != &other) {
         Q_D(GeoDataDelete);
@@ -36,21 +35,19 @@ GeoDataDelete &GeoDataDelete::operator=( const GeoDataDelete &other )
     return *this;
 }
 
-bool GeoDataDelete::operator==( const GeoDataDelete &other ) const
+bool GeoDataDelete::operator==(const GeoDataDelete &other) const
 {
     return GeoDataContainer::equals(other);
 }
 
-bool GeoDataDelete::operator!=( const GeoDataDelete &other ) const
+bool GeoDataDelete::operator!=(const GeoDataDelete &other) const
 {
-    return !this->operator==( other );
+    return !this->operator==(other);
 }
 
-GeoDataDelete::~GeoDataDelete()
-{
-}
+GeoDataDelete::~GeoDataDelete() = default;
 
-GeoDataFeature * GeoDataDelete::clone() const
+GeoDataFeature *GeoDataDelete::clone() const
 {
     return new GeoDataDelete(*this);
 }
