@@ -4,19 +4,19 @@
 // SPDX-FileCopyrightText: 2009 Patrick Spendrin <ps_ml@gmx.de>
 //
 
-
 #include "GeoDataFeature.h"
 #include "GeoDataFeature_p.h"
 
 #include <QDataStream>
 #include <QSize>
 
-#include "MarbleDirs.h"
 #include "MarbleDebug.h"
+#include "MarbleDirs.h"
 
 #include "GeoDataStyle.h"
 #include "GeoDataStyleMap.h"
 
+#include "GeoDataCamera.h"
 #include "GeoDataContainer.h"
 #include "GeoDataDocument.h"
 #include "GeoDataFolder.h"
@@ -25,10 +25,9 @@
 #include "GeoDataNetworkLinkControl.h"
 #include "GeoDataPhotoOverlay.h"
 #include "GeoDataPlacemark.h"
+#include "GeoDataRegion.h"
 #include "GeoDataScreenOverlay.h"
 #include "GeoDataTour.h"
-#include "GeoDataRegion.h"
-#include "GeoDataCamera.h"
 
 namespace Marble
 {
@@ -38,27 +37,27 @@ GeoDataFeature::GeoDataFeature()
 {
 }
 
-GeoDataFeature::GeoDataFeature( const GeoDataFeature& other )
-    : GeoDataObject(),
-      d_ptr(new GeoDataFeaturePrivate(*other.d_ptr))
+GeoDataFeature::GeoDataFeature(const GeoDataFeature &other)
+    : GeoDataObject()
+    , d_ptr(new GeoDataFeaturePrivate(*other.d_ptr))
 {
 }
 
-GeoDataFeature::GeoDataFeature( const QString& name )
+GeoDataFeature::GeoDataFeature(const QString &name)
     : d_ptr(new GeoDataFeaturePrivate())
 {
     d_ptr->m_name = name;
 }
 
 GeoDataFeature::GeoDataFeature(GeoDataFeaturePrivate *dd)
-    : GeoDataObject(),
-      d_ptr(dd)
+    : GeoDataObject()
+    , d_ptr(dd)
 {
 }
 
-GeoDataFeature::GeoDataFeature(const GeoDataFeature& other, GeoDataFeaturePrivate *dd)
-    : GeoDataObject(),
-      d_ptr(dd)
+GeoDataFeature::GeoDataFeature(const GeoDataFeature &other, GeoDataFeaturePrivate *dd)
+    : GeoDataObject()
+    , d_ptr(dd)
 {
     Q_UNUSED(other);
     // TODO: some classes pass "other" on and thus get duplicated id, also in operator=. Align behaviour
@@ -69,7 +68,7 @@ GeoDataFeature::~GeoDataFeature()
     delete d_ptr;
 }
 
-GeoDataFeature& GeoDataFeature::operator=( const GeoDataFeature& other )
+GeoDataFeature &GeoDataFeature::operator=(const GeoDataFeature &other)
 {
     if (this != &other) {
         *d_ptr = *other.d_ptr;
@@ -85,48 +84,48 @@ bool GeoDataFeature::operator==(const GeoDataFeature &other) const
     }
 
     if (nodeType() == GeoDataTypes::GeoDataDocumentType) {
-        const GeoDataDocument &thisDoc = static_cast<const GeoDataDocument &>(*this);
-        const GeoDataDocument &otherDoc = static_cast<const GeoDataDocument &>(other);
+        const auto &thisDoc = static_cast<const GeoDataDocument &>(*this);
+        const auto &otherDoc = static_cast<const GeoDataDocument &>(other);
 
         return thisDoc == otherDoc;
     } else if (nodeType() == GeoDataTypes::GeoDataFolderType) {
-        const GeoDataFolder &thisFolder = static_cast<const GeoDataFolder &>(*this);
-        const GeoDataFolder &otherFolder = static_cast<const GeoDataFolder &>(other);
+        const auto &thisFolder = static_cast<const GeoDataFolder &>(*this);
+        const auto &otherFolder = static_cast<const GeoDataFolder &>(other);
 
         return thisFolder == otherFolder;
     } else if (nodeType() == GeoDataTypes::GeoDataGroundOverlayType) {
-        const GeoDataGroundOverlay &thisGO = static_cast<const GeoDataGroundOverlay &>(*this);
-        const GeoDataGroundOverlay &otherGO = static_cast<const GeoDataGroundOverlay &>(other);
+        const auto &thisGO = static_cast<const GeoDataGroundOverlay &>(*this);
+        const auto &otherGO = static_cast<const GeoDataGroundOverlay &>(other);
 
         return thisGO == otherGO;
     } else if (nodeType() == GeoDataTypes::GeoDataNetworkLinkType) {
-        const GeoDataNetworkLink &thisNetLink = static_cast<const GeoDataNetworkLink &>(*this);
-        const GeoDataNetworkLink &otherNetLink = static_cast<const GeoDataNetworkLink &>(other);
+        const auto &thisNetLink = static_cast<const GeoDataNetworkLink &>(*this);
+        const auto &otherNetLink = static_cast<const GeoDataNetworkLink &>(other);
 
         return thisNetLink == otherNetLink;
     } else if (nodeType() == GeoDataTypes::GeoDataNetworkLinkControlType) {
-        const GeoDataNetworkLinkControl &thisNLC = static_cast<const GeoDataNetworkLinkControl &>(*this);
-        const GeoDataNetworkLinkControl &otherNLC = static_cast<const GeoDataNetworkLinkControl &>(other);
+        const auto &thisNLC = static_cast<const GeoDataNetworkLinkControl &>(*this);
+        const auto &otherNLC = static_cast<const GeoDataNetworkLinkControl &>(other);
 
         return thisNLC == otherNLC;
     } else if (nodeType() == GeoDataTypes::GeoDataPhotoOverlayType) {
-        const GeoDataPhotoOverlay &thisPO = static_cast<const GeoDataPhotoOverlay &>(*this);
-        const GeoDataPhotoOverlay &otherPO = static_cast<const GeoDataPhotoOverlay &>(other);
+        const auto &thisPO = static_cast<const GeoDataPhotoOverlay &>(*this);
+        const auto &otherPO = static_cast<const GeoDataPhotoOverlay &>(other);
 
         return thisPO == otherPO;
     } else if (nodeType() == GeoDataTypes::GeoDataPlacemarkType) {
-        const GeoDataPlacemark &thisPM = static_cast<const GeoDataPlacemark &>(*this);
-        const GeoDataPlacemark &otherPM = static_cast<const GeoDataPlacemark &>(other);
+        const auto &thisPM = static_cast<const GeoDataPlacemark &>(*this);
+        const auto &otherPM = static_cast<const GeoDataPlacemark &>(other);
 
         return thisPM == otherPM;
     } else if (nodeType() == GeoDataTypes::GeoDataScreenOverlayType) {
-        const GeoDataScreenOverlay &thisSO = static_cast<const GeoDataScreenOverlay &>(*this);
-        const GeoDataScreenOverlay &otherSO = static_cast<const GeoDataScreenOverlay &>(other);
+        const auto &thisSO = static_cast<const GeoDataScreenOverlay &>(*this);
+        const auto &otherSO = static_cast<const GeoDataScreenOverlay &>(other);
 
         return thisSO == otherSO;
     } else if (nodeType() == GeoDataTypes::GeoDataTourType) {
-        const GeoDataTour &thisTour = static_cast<const GeoDataTour &>(*this);
-        const GeoDataTour &otherTour = static_cast<const GeoDataTour &>(other);
+        const auto &thisTour = static_cast<const GeoDataTour &>(*this);
+        const auto &otherTour = static_cast<const GeoDataTour &>(other);
 
         return thisTour == otherTour;
     }
@@ -134,40 +133,31 @@ bool GeoDataFeature::operator==(const GeoDataFeature &other) const
     return false;
 }
 
-bool GeoDataFeature::equals( const GeoDataFeature &other ) const
+bool GeoDataFeature::equals(const GeoDataFeature &other) const
 {
     Q_D(const GeoDataFeature);
-    const GeoDataFeaturePrivate* const other_d = other.d_func();
+    const GeoDataFeaturePrivate *const other_d = other.d_func();
 
-    if (!GeoDataObject::equals(other) ||
-        d->m_name != other_d->m_name ||
-        d->m_styleUrl != other_d->m_styleUrl ||
-        d->m_popularity != other_d->m_popularity ||
-        d->m_zoomLevel != other_d->m_zoomLevel ||
-        d->m_visible != other_d->m_visible ||
-        d->m_role != other_d->m_role ||
-        d->m_extendedData != other_d->m_extendedData ||
-        *style() != *other.style()) {
+    if (!GeoDataObject::equals(other) || d->m_name != other_d->m_name || d->m_styleUrl != other_d->m_styleUrl || d->m_popularity != other_d->m_popularity
+        || d->m_zoomLevel != other_d->m_zoomLevel || d->m_visible != other_d->m_visible || d->m_role != other_d->m_role
+        || d->m_extendedData != other_d->m_extendedData || *style() != *other.style()) {
         return false;
     }
 
-    if ((!d->m_styleMap && other_d->m_styleMap) ||
-        (d->m_styleMap && !other_d->m_styleMap)) {
+    if ((!d->m_styleMap && other_d->m_styleMap) || (d->m_styleMap && !other_d->m_styleMap)) {
         return false;
     }
 
-    if ((d->m_styleMap && other_d->m_styleMap) &&
-        (*d->m_styleMap != *other_d->m_styleMap)) {
+    if ((d->m_styleMap && other_d->m_styleMap) && (*d->m_styleMap != *other_d->m_styleMap)) {
         return false;
     }
 
-    if ((!d->m_featureExtendedData && other_d->m_featureExtendedData && other_d->m_featureExtendedData->m_abstractView) ||
-        (d->m_featureExtendedData && d->m_featureExtendedData->m_abstractView && !other_d->m_featureExtendedData)) {
+    if ((!d->m_featureExtendedData && other_d->m_featureExtendedData && other_d->m_featureExtendedData->m_abstractView)
+        || (d->m_featureExtendedData && d->m_featureExtendedData->m_abstractView && !other_d->m_featureExtendedData)) {
         return false;
     }
 
-    if ((d->m_featureExtendedData && other_d->m_featureExtendedData) &&
-        (*d->m_featureExtendedData != *other_d->m_featureExtendedData)) {
+    if ((d->m_featureExtendedData && other_d->m_featureExtendedData) && (*d->m_featureExtendedData != *other_d->m_featureExtendedData)) {
         return false;
     }
 
@@ -186,7 +176,7 @@ QString GeoDataFeature::name() const
     return d->m_name;
 }
 
-void GeoDataFeature::setName( const QString &value )
+void GeoDataFeature::setName(const QString &value)
 {
     Q_D(GeoDataFeature);
     d->m_name = value;
@@ -198,7 +188,7 @@ GeoDataSnippet GeoDataFeature::snippet() const
     return d->featureExtendedData().m_snippet;
 }
 
-void GeoDataFeature::setSnippet( const GeoDataSnippet &snippet )
+void GeoDataFeature::setSnippet(const GeoDataSnippet &snippet)
 {
     Q_D(GeoDataFeature);
     d->featureExtendedData().m_snippet = snippet;
@@ -208,13 +198,13 @@ QString GeoDataFeature::address() const
 {
     Q_D(const GeoDataFeature);
     if (!d->m_featureExtendedData) {
-        return QString();
+        return {};
     }
 
     return d->featureExtendedData().m_address;
 }
 
-void GeoDataFeature::setAddress( const QString &value)
+void GeoDataFeature::setAddress(const QString &value)
 {
     Q_D(GeoDataFeature);
     if (value.isEmpty() && !d->m_featureExtendedData) {
@@ -228,13 +218,13 @@ QString GeoDataFeature::phoneNumber() const
 {
     Q_D(const GeoDataFeature);
     if (!d->m_featureExtendedData) {
-        return QString();
+        return {};
     }
 
     return d->featureExtendedData().m_phoneNumber;
 }
 
-void GeoDataFeature::setPhoneNumber( const QString &value)
+void GeoDataFeature::setPhoneNumber(const QString &value)
 {
     Q_D(GeoDataFeature);
     if (value.isEmpty() && !d->m_featureExtendedData) {
@@ -248,13 +238,13 @@ QString GeoDataFeature::description() const
 {
     Q_D(const GeoDataFeature);
     if (!d->m_featureExtendedData) {
-        return QString();
+        return {};
     }
 
     return d->featureExtendedData().m_description;
 }
 
-void GeoDataFeature::setDescription( const QString &value)
+void GeoDataFeature::setDescription(const QString &value)
 {
     Q_D(GeoDataFeature);
     if (value.isEmpty() && !d->m_featureExtendedData) {
@@ -274,13 +264,13 @@ bool GeoDataFeature::descriptionIsCDATA() const
     return d->featureExtendedData().m_descriptionCDATA;
 }
 
-void GeoDataFeature::setDescriptionCDATA( bool cdata )
+void GeoDataFeature::setDescriptionCDATA(bool cdata)
 {
     Q_D(GeoDataFeature);
     d->featureExtendedData().m_descriptionCDATA = cdata;
 }
 
-const GeoDataAbstractView* GeoDataFeature::abstractView() const
+const GeoDataAbstractView *GeoDataFeature::abstractView() const
 {
     Q_D(const GeoDataFeature);
     if (!d->m_featureExtendedData) {
@@ -300,7 +290,7 @@ GeoDataAbstractView *GeoDataFeature::abstractView()
     return d->featureExtendedData().m_abstractView;
 }
 
-void GeoDataFeature::setAbstractView( GeoDataAbstractView *abstractView )
+void GeoDataFeature::setAbstractView(GeoDataAbstractView *abstractView)
 {
     Q_D(GeoDataFeature);
     if (abstractView == nullptr && !d->m_featureExtendedData) {
@@ -316,12 +306,12 @@ QString GeoDataFeature::styleUrl() const
     return d->m_styleUrl;
 }
 
-void GeoDataFeature::setStyleUrl( const QString &value )
+void GeoDataFeature::setStyleUrl(const QString &value)
 {
     Q_D(GeoDataFeature);
     d->m_styleUrl = value;
 
-    if ( value.isEmpty() ) {
+    if (value.isEmpty()) {
         d->m_style = GeoDataStyle::Ptr();
         return;
     }
@@ -330,8 +320,8 @@ void GeoDataFeature::setStyleUrl( const QString &value )
     styleUrl.remove(QLatin1Char('#'));
 
     for (auto object = parent(); object != nullptr; object = object->parent()) {
-        if (GeoDataDocument *doc = geodata_cast<GeoDataDocument>(object)) {
-            GeoDataStyleMap &styleMap = doc->styleMap( styleUrl );
+        if (auto doc = geodata_cast<GeoDataDocument>(object)) {
+            GeoDataStyleMap &styleMap = doc->styleMap(styleUrl);
             const QString normalStyleUrl = styleMap.value(QStringLiteral("normal"));
             if (!normalStyleUrl.isEmpty()) {
                 styleUrl = normalStyleUrl;
@@ -339,7 +329,7 @@ void GeoDataFeature::setStyleUrl( const QString &value )
             }
             // Not calling setStyle here because we don't want
             // re-parenting of the style
-            d->m_style = doc->style( styleUrl );
+            d->m_style = doc->style(styleUrl);
             break;
         }
     }
@@ -351,7 +341,7 @@ bool GeoDataFeature::isVisible() const
     return d->m_visible;
 }
 
-void GeoDataFeature::setVisible( bool value )
+void GeoDataFeature::setVisible(bool value)
 {
     Q_D(GeoDataFeature);
     d->m_visible = value;
@@ -360,14 +350,13 @@ void GeoDataFeature::setVisible( bool value )
 bool GeoDataFeature::isGloballyVisible() const
 {
     Q_D(const GeoDataFeature);
-    if ( parent() == nullptr ) {
+    if (parent() == nullptr) {
         return d->m_visible;
     }
-    const GeoDataContainer *container = static_cast<const GeoDataContainer*>(parent());
+    const auto container = static_cast<const GeoDataContainer *>(parent());
     return d->m_visible && container->isGloballyVisible();
 }
 
-
 const GeoDataTimeSpan &GeoDataFeature::timeSpan() const
 {
     Q_D(const GeoDataFeature);
@@ -380,7 +369,7 @@ GeoDataTimeSpan &GeoDataFeature::timeSpan()
     return d->featureExtendedData().m_timeSpan;
 }
 
-void GeoDataFeature::setTimeSpan( const GeoDataTimeSpan &timeSpan )
+void GeoDataFeature::setTimeSpan(const GeoDataTimeSpan &timeSpan)
 {
     Q_D(GeoDataFeature);
     d->featureExtendedData().m_timeSpan = timeSpan;
@@ -398,7 +387,7 @@ GeoDataTimeStamp &GeoDataFeature::timeStamp()
     return d->featureExtendedData().m_timeStamp;
 }
 
-void GeoDataFeature::setTimeStamp( const GeoDataTimeStamp &timeStamp )
+void GeoDataFeature::setTimeStamp(const GeoDataTimeStamp &timeStamp)
 {
     Q_D(GeoDataFeature);
     d->featureExtendedData().m_timeStamp = timeStamp;
@@ -427,39 +416,39 @@ GeoDataStyle::ConstPtr GeoDataFeature::customStyle() const
     return d->m_style;
 }
 
-void GeoDataFeature::setStyle( const GeoDataStyle::Ptr &style )
+void GeoDataFeature::setStyle(const GeoDataStyle::Ptr &style)
 {
     Q_D(GeoDataFeature);
     if (style)
-        style->setParent( this );
+        style->setParent(this);
     d->m_style = style;
 }
 
-GeoDataExtendedData& GeoDataFeature::extendedData()
+GeoDataExtendedData &GeoDataFeature::extendedData()
 {
     Q_D(GeoDataFeature);
     return d->m_extendedData;
 }
 
-void GeoDataFeature::setExtendedData( const GeoDataExtendedData& extendedData )
+void GeoDataFeature::setExtendedData(const GeoDataExtendedData &extendedData)
 {
     Q_D(GeoDataFeature);
     d->m_extendedData = extendedData;
 }
 
-const GeoDataRegion& GeoDataFeature::region() const
+const GeoDataRegion &GeoDataFeature::region() const
 {
     Q_D(const GeoDataFeature);
     return d->featureExtendedData().m_region;
 }
 
-GeoDataRegion& GeoDataFeature::region()
+GeoDataRegion &GeoDataFeature::region()
 {
     Q_D(GeoDataFeature);
     return d->featureExtendedData().m_region;
 }
 
-void GeoDataFeature::setRegion( const GeoDataRegion& region )
+void GeoDataFeature::setRegion(const GeoDataRegion &region)
 {
     Q_D(GeoDataFeature);
     d->featureExtendedData().m_region = region;
@@ -471,19 +460,19 @@ const QString GeoDataFeature::role() const
     return d->m_role;
 }
 
-void GeoDataFeature::setRole( const QString &role )
+void GeoDataFeature::setRole(const QString &role)
 {
     Q_D(GeoDataFeature);
     d->m_role = role;
 }
 
-const GeoDataStyleMap* GeoDataFeature::styleMap() const
+const GeoDataStyleMap *GeoDataFeature::styleMap() const
 {
     Q_D(const GeoDataFeature);
     return d->m_styleMap;
 }
 
-void GeoDataFeature::setStyleMap( const GeoDataStyleMap* styleMap )
+void GeoDataFeature::setStyleMap(const GeoDataStyleMap *styleMap)
 {
     Q_D(GeoDataFeature);
     d->m_styleMap = styleMap;
@@ -495,7 +484,7 @@ int GeoDataFeature::zoomLevel() const
     return d->m_zoomLevel;
 }
 
-void GeoDataFeature::setZoomLevel( int zoomLevel )
+void GeoDataFeature::setZoomLevel(int zoomLevel)
 {
     Q_D(GeoDataFeature);
     d->m_zoomLevel = zoomLevel;
@@ -507,40 +496,40 @@ qint64 GeoDataFeature::popularity() const
     return d->m_popularity;
 }
 
-void GeoDataFeature::setPopularity( qint64 popularity )
+void GeoDataFeature::setPopularity(qint64 popularity)
 {
     Q_D(GeoDataFeature);
     d->m_popularity = popularity;
 }
 
-void GeoDataFeature::pack( QDataStream& stream ) const
+void GeoDataFeature::pack(QDataStream &stream) const
 {
     Q_D(const GeoDataFeature);
 
-    GeoDataObject::pack( stream );
+    GeoDataObject::pack(stream);
 
     stream << d->m_name;
     stream << d->featureExtendedData().m_address;
     stream << d->featureExtendedData().m_phoneNumber;
     stream << d->featureExtendedData().m_description;
     stream << d->m_visible;
-//    stream << d->m_visualCategory;
+    //    stream << d->m_visualCategory;
     stream << d->m_role;
     stream << d->m_popularity;
     stream << d->m_zoomLevel;
 }
 
-void GeoDataFeature::unpack( QDataStream& stream )
+void GeoDataFeature::unpack(QDataStream &stream)
 {
     Q_D(GeoDataFeature);
-    GeoDataObject::unpack( stream );
+    GeoDataObject::unpack(stream);
 
     stream >> d->m_name;
     stream >> d->featureExtendedData().m_address;
     stream >> d->featureExtendedData().m_phoneNumber;
     stream >> d->featureExtendedData().m_description;
     stream >> d->m_visible;
-//    stream >> (int)d->m_visualCategory;
+    //    stream >> (int)d->m_visualCategory;
     stream >> d->m_role;
     stream >> d->m_popularity;
     stream >> d->m_zoomLevel;
