@@ -18,22 +18,19 @@ class GeoDataFolderPrivate : public GeoDataContainerPrivate
 {
 };
 
-
 GeoDataFolder::GeoDataFolder()
-        : GeoDataContainer( new GeoDataFolderPrivate )
+    : GeoDataContainer(new GeoDataFolderPrivate)
 {
 }
 
-GeoDataFolder::GeoDataFolder( const GeoDataFolder& other )
+GeoDataFolder::GeoDataFolder(const GeoDataFolder &other)
     : GeoDataContainer(other, new GeoDataFolderPrivate(*other.d_func()))
 {
 }
 
-GeoDataFolder::~GeoDataFolder()
-{
-}
+GeoDataFolder::~GeoDataFolder() = default;
 
-GeoDataFolder& GeoDataFolder::operator=(const GeoDataFolder& other)
+GeoDataFolder &GeoDataFolder::operator=(const GeoDataFolder &other)
 {
     if (this != &other) {
         Q_D(GeoDataFolder);
@@ -43,22 +40,22 @@ GeoDataFolder& GeoDataFolder::operator=(const GeoDataFolder& other)
     return *this;
 }
 
-bool GeoDataFolder::operator==( const GeoDataFolder &other ) const
+bool GeoDataFolder::operator==(const GeoDataFolder &other) const
 {
-    return GeoDataContainer::equals( other );
+    return GeoDataContainer::equals(other);
 }
 
-bool GeoDataFolder::operator!=( const GeoDataFolder &other ) const
+bool GeoDataFolder::operator!=(const GeoDataFolder &other) const
 {
-    return !this->operator==( other );
+    return !this->operator==(other);
 }
 
-const char* GeoDataFolder::nodeType() const
+const char *GeoDataFolder::nodeType() const
 {
     return GeoDataTypes::GeoDataFolderType;
 }
 
-GeoDataFeature * GeoDataFolder::clone() const
+GeoDataFeature *GeoDataFolder::clone() const
 {
     return new GeoDataFolder(*this);
 }
