@@ -4,36 +4,35 @@
 // SPDX-FileCopyrightText: 2009 Patrick Spendrin <ps_ml@gmx.de>
 //
 
-
 #include "GeoDataLineString.h"
 #include "GeoDataLineString_p.h"
 
 #include "GeoDataLinearRing.h"
 #include "GeoDataTypes.h"
-#include "Quaternion.h"
 #include "MarbleDebug.h"
+#include "Quaternion.h"
 
 #include <QDataStream>
-
+#include <QVariant>
 
 namespace Marble
 {
-GeoDataLineString::GeoDataLineString( TessellationFlags f )
-  : GeoDataGeometry( new GeoDataLineStringPrivate( f ) )
+GeoDataLineString::GeoDataLineString(TessellationFlags f)
+    : GeoDataGeometry(new GeoDataLineStringPrivate(f))
 {
-//    mDebug() << "1) GeoDataLineString created:" << p();
+    //    mDebug() << "1) GeoDataLineString created:" << p();
 }
 
-GeoDataLineString::GeoDataLineString( GeoDataLineStringPrivate* priv )
-  : GeoDataGeometry( priv )
+GeoDataLineString::GeoDataLineString(GeoDataLineStringPrivate *priv)
+    : GeoDataGeometry(priv)
 {
-//    mDebug() << "2) GeoDataLineString created:" << p();
+    //    mDebug() << "2) GeoDataLineString created:" << p();
 }
 
-GeoDataLineString::GeoDataLineString( const GeoDataGeometry & other )
-  : GeoDataGeometry( other )
+GeoDataLineString::GeoDataLineString(const GeoDataGeometry &other)
+    : GeoDataGeometry(other)
 {
-//    mDebug() << "3) GeoDataLineString created:" << p();
+    //    mDebug() << "3) GeoDataLineString created:" << p();
 }
 
 GeoDataLineString::~GeoDataLineString()
@@ -58,92 +57,107 @@ GeoDataGeometry *GeoDataLineString::copy() const
     return new GeoDataLineString(*this);
 }
 
-void GeoDataLineStringPrivate::interpolateDateLine( const GeoDataCoordinates & previousCoords,
-                                                    const GeoDataCoordinates & currentCoords,
-                                                    GeoDataCoordinates & previousAtDateLine,
-                                                    GeoDataCoordinates & currentAtDateLine,
-                                                    TessellationFlags f ) const
+void GeoDataLineStringPrivate::interpolateDateLine(const GeoDataCoordinates &previousCoords,
+                                                   const GeoDataCoordinates &currentCoords,
+                                                   GeoDataCoordinates &previousAtDateLine,
+                                                   GeoDataCoordinates &currentAtDateLine,
+                                                   TessellationFlags f) const
 {
     GeoDataCoordinates dateLineCoords;
 
-//    mDebug();
+    //    mDebug();
 
-    if ( f.testFlag( RespectLatitudeCircle ) && previousCoords.latitude() == currentCoords.latitude() ) {
+    if (f.testFlag(RespectLatitudeCircle) && previousCoords.latitude() == currentCoords.latitude()) {
         dateLineCoords = currentCoords;
-    }
-    else {
+    } else {
         int recursionCounter = 0;
-        dateLineCoords = findDateLine( previousCoords, currentCoords, recursionCounter );
+        dateLineCoords = findDateLine(previousCoords, currentCoords, recursionCounter);
     }
 
     previousAtDateLine = dateLineCoords;
     currentAtDateLine = dateLineCoords;
 
-    if ( previousCoords.longitude() < 0 ) {
-        previousAtDateLine.setLongitude( -M_PI );
-        currentAtDateLine.setLongitude( +M_PI );
-    }
-    else {
-        previousAtDateLine.setLongitude( +M_PI );
-        currentAtDateLine.setLongitude( -M_PI );
+    if (previousCoords.longitude() < 0) {
+        previousAtDateLine.setLongitude(-M_PI);
+        currentAtDateLine.setLongitude(+M_PI);
+    } else {
+        previousAtDateLine.setLongitude(+M_PI);
+        currentAtDateLine.setLongitude(-M_PI);
     }
 }
 
-GeoDataCoordinates GeoDataLineStringPrivate::findDateLine( const GeoDataCoordinates & previousCoords,
-                                             const GeoDataCoordinates & currentCoords,
-                                             int recursionCounter ) const
+GeoDataCoordinates
+GeoDataLineStringPrivate::findDateLine(const GeoDataCoordinates &previousCoords, const GeoDataCoordinates &currentCoords, int recursionCounter) const
 {
-    int currentSign = ( currentCoords.longitude() < 0.0 ) ? -1 : +1 ;
-    int previousSign = ( previousCoords.longitude() < 0.0 ) ? -1 : +1 ;
+    int currentSign = (currentCoords.longitude() < 0.0) ? -1 : +1;
+    int previousSign = (previousCoords.longitude() < 0.0) ? -1 : +1;
 
-    qreal longitudeDiff =   fabs( previousSign * M_PI  - previousCoords.longitude() )
-                          + fabs( currentSign * M_PI - currentCoords.longitude() );
+    qreal longitudeDiff = fabs(previousSign * M_PI - previousCoords.longitude()) + fabs(currentSign * M_PI - currentCoords.longitude());
 
-    if ( longitudeDiff < 0.001 || recursionCounter == 100 ) {
-//        mDebug() << "stopped at recursion" << recursionCounter << " and longitude difference " << longitudeDiff;
+    if (longitudeDiff < 0.001 || recursionCounter == 100) {
+        //        mDebug() << "stopped at recursion" << recursionCounter << " and longitude difference " << longitudeDiff;
         return currentCoords;
     }
     ++recursionCounter;
 
     const GeoDataCoordinates interpolatedCoords = previousCoords.nlerp(currentCoords, 0.5);
 
-    int interpolatedSign = ( interpolatedCoords.longitude() < 0.0 ) ? -1 : +1 ;
+    int interpolatedSign = (interpolatedCoords.longitude() < 0.0) ? -1 : +1;
 
-/*
-    mDebug() << "SRC" << previousCoords.toString();
-    mDebug() << "TAR" << currentCoords.toString();
-    mDebug() << "IPC" << interpolatedCoords.toString();
-*/
+    /*
+        mDebug() << "SRC" << previousCoords.toString();
+        mDebug() << "TAR" << currentCoords.toString();
+        mDebug() << "IPC" << interpolatedCoords.toString();
+    */
 
-    if ( interpolatedSign != currentSign ) {
-        return findDateLine( interpolatedCoords, currentCoords, recursionCounter );
+    if (interpolatedSign != currentSign) {
+        return findDateLine(interpolatedCoords, currentCoords, recursionCounter);
     }
 
-    return findDateLine( previousCoords, interpolatedCoords, recursionCounter );
+    return findDateLine(previousCoords, interpolatedCoords, recursionCounter);
 }
 
-quint8 GeoDataLineStringPrivate::levelForResolution(qreal resolution) const {
-    if (m_previousResolution == resolution) return m_level;
+quint8 GeoDataLineStringPrivate::levelForResolution(qreal resolution) const
+{
+    if (m_previousResolution == resolution)
+        return m_level;
 
     m_previousResolution = resolution;
 
-    if (resolution < 0.0000005) m_level = 17;
-    else if (resolution < 0.0000010) m_level = 16;
-    else if (resolution < 0.0000020) m_level = 15;
-    else if (resolution < 0.0000040) m_level = 14;
-    else if (resolution < 0.0000080) m_level = 13;
-    else if (resolution < 0.0000160) m_level = 12;
-    else if (resolution < 0.0000320) m_level = 11;
-    else if (resolution < 0.0000640) m_level = 10;
-    else if (resolution < 0.0001280) m_level = 9;
-    else if (resolution < 0.0002560) m_level = 8;
-    else if (resolution < 0.0005120) m_level = 7;
-    else if (resolution < 0.0010240) m_level = 6;
-    else if (resolution < 0.0020480) m_level = 5;
-    else if (resolution < 0.0040960) m_level = 4;
-    else if (resolution < 0.0081920) m_level = 3;
-    else if (resolution < 0.0163840) m_level = 2;
-    else m_level =  1;
+    if (resolution < 0.0000005)
+        m_level = 17;
+    else if (resolution < 0.0000010)
+        m_level = 16;
+    else if (resolution < 0.0000020)
+        m_level = 15;
+    else if (resolution < 0.0000040)
+        m_level = 14;
+    else if (resolution < 0.0000080)
+        m_level = 13;
+    else if (resolution < 0.0000160)
+        m_level = 12;
+    else if (resolution < 0.0000320)
+        m_level = 11;
+    else if (resolution < 0.0000640)
+        m_level = 10;
+    else if (resolution < 0.0001280)
+        m_level = 9;
+    else if (resolution < 0.0002560)
+        m_level = 8;
+    else if (resolution < 0.0005120)
+        m_level = 7;
+    else if (resolution < 0.0010240)
+        m_level = 6;
+    else if (resolution < 0.0020480)
+        m_level = 5;
+    else if (resolution < 0.0040960)
+        m_level = 4;
+    else if (resolution < 0.0081920)
+        m_level = 3;
+    else if (resolution < 0.0163840)
+        m_level = 2;
+    else
+        m_level = 1;
 
     return m_level;
 }
@@ -151,56 +165,56 @@ quint8 GeoDataLineStringPrivate::levelForResolution(qreal resolution) const {
 qreal GeoDataLineStringPrivate::resolutionForLevel(int level)
 {
     switch (level) {
-        case 0:
-            return 0.0655360;
-        case 1:
-            return 0.0327680;
-        case 2:
-            return 0.0163840;
-        case 3:
-            return 0.0081920;
-        case 4:
-            return 0.0040960;
-        case 5:
-            return 0.0020480;
-        case 6:
-            return 0.0010240;
-        case 7:
-            return 0.0005120;
-        case 8:
-            return 0.0002560;
-        case 9:
-            return 0.0001280;
-        case 10:
-            return 0.0000640;
-        case 11:
-            return 0.0000320;
-        case 12:
-            return 0.0000160;
-        case 13:
-            return 0.0000080;
-        case 14:
-            return 0.0000040;
-        case 15:
-            return 0.0000020;
-        case 16:
-            return 0.0000010;
-        default:
-        case 17:
-            return 0.0000005;
+    case 0:
+        return 0.0655360;
+    case 1:
+        return 0.0327680;
+    case 2:
+        return 0.0163840;
+    case 3:
+        return 0.0081920;
+    case 4:
+        return 0.0040960;
+    case 5:
+        return 0.0020480;
+    case 6:
+        return 0.0010240;
+    case 7:
+        return 0.0005120;
+    case 8:
+        return 0.0002560;
+    case 9:
+        return 0.0001280;
+    case 10:
+        return 0.0000640;
+    case 11:
+        return 0.0000320;
+    case 12:
+        return 0.0000160;
+    case 13:
+        return 0.0000080;
+    case 14:
+        return 0.0000040;
+    case 15:
+        return 0.0000020;
+    case 16:
+        return 0.0000010;
+    default:
+    case 17:
+        return 0.0000005;
     }
 }
 
-void GeoDataLineStringPrivate::optimize (GeoDataLineString& lineString) const
+void GeoDataLineStringPrivate::optimize(GeoDataLineString &lineString) const
 {
+    QList<GeoDataCoordinates>::iterator itCoords = lineString.begin();
+    QList<GeoDataCoordinates>::const_iterator itEnd = lineString.constEnd();
 
-    QVector<GeoDataCoordinates>::iterator itCoords = lineString.begin();
-    QVector<GeoDataCoordinates>::const_iterator itEnd = lineString.constEnd();
-
-    if (lineString.size() < 2) return;
+    if (lineString.size() < 2)
+        return;
 
     // Calculate the least non-zero detail-level by checking the bounding box
-    quint8 startLevel = levelForResolution( ( lineString.latLonAltBox().width() + lineString.latLonAltBox().height() ) / 2 );
+    quint8 startLevel = levelForResolution((lineString.latLonAltBox().width() + lineString.latLonAltBox().height()) / 2);
 
     quint8 currentLevel = startLevel;
     quint8 maxLevel = startLevel;
@@ -220,17 +234,19 @@ void GeoDataLineStringPrivate::optimize (GeoDataLineString& lineString) const
     // We do as many iterations through the lineString as needed and bump up the
     // current level until all nodes have a non-zero detail level assigned.
 
-    while ( currentLevel  < 16 && currentLevel <= maxLevel + 1 ) {
+    while (currentLevel < 16 && currentLevel <= maxLevel + 1) {
         itCoords = lineString.begin();
 
         currentCoords = *itCoords;
         ++itCoords;
 
-        for( ; itCoords != itEnd; ++itCoords) {
-            if (itCoords->detail() != 0 && itCoords->detail() < currentLevel) continue;
+        for (; itCoords != itEnd; ++itCoords) {
+            if (itCoords->detail() != 0 && itCoords->detail() < currentLevel)
+                continue;
 
-            if ( currentLevel == startLevel && (itCoords->longitude() == -M_PI || itCoords->longitude() == M_PI
-                || itCoords->latitude() < -89 * DEG2RAD || itCoords->latitude() > 89 * DEG2RAD)) {
+            if (currentLevel == startLevel
+                && (itCoords->longitude() == -M_PI || itCoords->longitude() == M_PI || itCoords->latitude() < -89 * DEG2RAD
+                    || itCoords->latitude() > 89 * DEG2RAD)) {
                 itCoords->setDetail(startLevel);
                 currentCoords = *itCoords;
                 maxLevel = currentLevel;
@@ -238,8 +254,7 @@ void GeoDataLineStringPrivate::optimize (GeoDataLineString& lineString) const
             }
             if (currentCoords.sphericalDistanceTo(*itCoords) < resolutionForLevel(currentLevel + 1)) {
                 itCoords->setDetail(currentLevel + 1);
-            }
-            else {
+            } else {
                 itCoords->setDetail(currentLevel);
                 currentCoords = *itCoords;
                 maxLevel = currentLevel;
@@ -262,7 +277,7 @@ int GeoDataLineString::size() const
     return d->m_vector.size();
 }
 
-GeoDataCoordinates& GeoDataLineString::at( int pos )
+GeoDataCoordinates &GeoDataLineString::at(int pos)
 {
     detach();
 
@@ -272,13 +287,13 @@ GeoDataCoordinates& GeoDataLineString::at( int pos )
     return d->m_vector[pos];
 }
 
-const GeoDataCoordinates& GeoDataLineString::at( int pos ) const
+const GeoDataCoordinates &GeoDataLineString::at(int pos) const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector.at(pos);
 }
 
-GeoDataCoordinates& GeoDataLineString::operator[]( int pos )
+GeoDataCoordinates &GeoDataLineString::operator[](int pos)
 {
     detach();
 
@@ -300,13 +315,13 @@ GeoDataLineString GeoDataLineString::mid(int pos, int length) const
     return substring;
 }
 
-const GeoDataCoordinates& GeoDataLineString::operator[]( int pos ) const
+const GeoDataCoordinates &GeoDataLineString::operator[](int pos) const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector[pos];
 }
 
-GeoDataCoordinates& GeoDataLineString::last()
+GeoDataCoordinates &GeoDataLineString::last()
 {
     detach();
 
@@ -316,7 +331,7 @@ GeoDataCoordinates& GeoDataLineString::last()
     return d->m_vector.last();
 }
 
-GeoDataCoordinates& GeoDataLineString::first()
+GeoDataCoordinates &GeoDataLineString::first()
 {
     detach();
 
@@ -324,19 +339,19 @@ GeoDataCoordinates& GeoDataLineString::first()
     return d->m_vector.first();
 }
 
-const GeoDataCoordinates& GeoDataLineString::last() const
+const GeoDataCoordinates &GeoDataLineString::last() const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector.last();
 }
 
-const GeoDataCoordinates& GeoDataLineString::first() const
+const GeoDataCoordinates &GeoDataLineString::first() const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector.first();
 }
 
-QVector<GeoDataCoordinates>::Iterator GeoDataLineString::begin()
+QList<GeoDataCoordinates>::Iterator GeoDataLineString::begin()
 {
     detach();
 
@@ -344,13 +359,13 @@ QVector<GeoDataCoordinates>::Iterator GeoDataLineString::begin()
     return d->m_vector.begin();
 }
 
-QVector<GeoDataCoordinates>::ConstIterator GeoDataLineString::begin() const
+QList<GeoDataCoordinates>::ConstIterator GeoDataLineString::begin() const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector.constBegin();
 }
 
-QVector<GeoDataCoordinates>::Iterator GeoDataLineString::end()
+QList<GeoDataCoordinates>::Iterator GeoDataLineString::end()
 {
     detach();
 
@@ -358,25 +373,25 @@ QVector<GeoDataCoordinates>::Iterator GeoDataLineString::end()
     return d->m_vector.end();
 }
 
-QVector<GeoDataCoordinates>::ConstIterator GeoDataLineString::end() const
+QList<GeoDataCoordinates>::ConstIterator GeoDataLineString::end() const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector.constEnd();
 }
 
-QVector<GeoDataCoordinates>::ConstIterator GeoDataLineString::constBegin() const
+QList<GeoDataCoordinates>::ConstIterator GeoDataLineString::constBegin() const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector.constBegin();
 }
 
-QVector<GeoDataCoordinates>::ConstIterator GeoDataLineString::constEnd() const
+QList<GeoDataCoordinates>::ConstIterator GeoDataLineString::constEnd() const
 {
     Q_D(const GeoDataLineString);
     return d->m_vector.constEnd();
 }
 
-void GeoDataLineString::insert( int index, const GeoDataCoordinates& value )
+void GeoDataLineString::insert(int index, const GeoDataCoordinates &value)
 {
     detach();
 
@@ -385,10 +400,10 @@ void GeoDataLineString::insert( int index, const GeoDataCoordinates& value )
     d->m_rangeCorrected = nullptr;
     d->m_dirtyRange = true;
     d->m_dirtyBox = true;
-    d->m_vector.insert( index, value );
+    d->m_vector.insert(index, value);
 }
 
-void GeoDataLineString::append ( const GeoDataCoordinates& value )
+void GeoDataLineString::append(const GeoDataCoordinates &value)
 {
     detach();
 
@@ -397,7 +412,7 @@ void GeoDataLineString::append ( const GeoDataCoordinates& value )
     d->m_rangeCorrected = nullptr;
     d->m_dirtyRange = true;
     d->m_dirtyBox = true;
-    d->m_vector.append( value );
+    d->m_vector.append(value);
 }
 
 void GeoDataLineString::reserve(int size)
@@ -406,7 +421,7 @@ void GeoDataLineString::reserve(int size)
     d->m_vector.reserve(size);
 }
 
-void GeoDataLineString::append(const QVector<GeoDataCoordinates>& values)
+void GeoDataLineString::append(const QList<GeoDataCoordinates> &values)
 {
     detach();
 
@@ -419,7 +434,7 @@ void GeoDataLineString::append(const QVector<GeoDataCoordinates>& values)
     d->m_vector.append(values);
 }
 
-GeoDataLineString& GeoDataLineString::operator << ( const GeoDataCoordinates& value )
+GeoDataLineString &GeoDataLineString::operator<<(const GeoDataCoordinates &value)
 {
     detach();
 
@@ -428,11 +443,11 @@ GeoDataLineString& GeoDataLineString::operator << ( const GeoDataCoordinates& va
     d->m_rangeCorrected = nullptr;
     d->m_dirtyRange = true;
     d->m_dirtyBox = true;
-    d->m_vector.append( value );
+    d->m_vector.append(value);
     return *this;
 }
 
-GeoDataLineString& GeoDataLineString::operator << ( const GeoDataLineString& value )
+GeoDataLineString &GeoDataLineString::operator<<(const GeoDataLineString &value)
 {
     detach();
 
@@ -442,44 +457,42 @@ GeoDataLineString& GeoDataLineString::operator << ( const GeoDataLineString& val
     d->m_dirtyRange = true;
     d->m_dirtyBox = true;
 
-    QVector<GeoDataCoordinates>::const_iterator itCoords = value.constBegin();
-    QVector<GeoDataCoordinates>::const_iterator itEnd = value.constEnd();
+    QList<GeoDataCoordinates>::const_iterator itCoords = value.constBegin();
+    QList<GeoDataCoordinates>::const_iterator itEnd = value.constEnd();
 
     d->m_vector.reserve(d->m_vector.size() + value.size());
-    for( ; itCoords != itEnd; ++itCoords ) {
-        d->m_vector.append( *itCoords );
+    for (; itCoords != itEnd; ++itCoords) {
+        d->m_vector.append(*itCoords);
     }
 
     return *this;
 }
 
-bool GeoDataLineString::operator==( const GeoDataLineString &other ) const
+bool GeoDataLineString::operator==(const GeoDataLineString &other) const
 {
-    if ( !GeoDataGeometry::equals(other) ||
-          size() != other.size() ||
-          tessellate() != other.tessellate() ) {
+    if (!GeoDataGeometry::equals(other) || size() != other.size() || tessellate() != other.tessellate()) {
         return false;
     }
 
     Q_D(const GeoDataLineString);
-    const GeoDataLineStringPrivate* other_d = other.d_func();
+    const GeoDataLineStringPrivate *other_d = other.d_func();
 
-    QVector<GeoDataCoordinates>::const_iterator itCoords = d->m_vector.constBegin();
-    QVector<GeoDataCoordinates>::const_iterator otherItCoords = other_d->m_vector.constBegin();
-    QVector<GeoDataCoordinates>::const_iterator itEnd = d->m_vector.constEnd();
-    QVector<GeoDataCoordinates>::const_iterator otherItEnd = other_d->m_vector.constEnd();
+    QList<GeoDataCoordinates>::const_iterator itCoords = d->m_vector.constBegin();
+    QList<GeoDataCoordinates>::const_iterator otherItCoords = other_d->m_vector.constBegin();
+    QList<GeoDataCoordinates>::const_iterator itEnd = d->m_vector.constEnd();
+    QList<GeoDataCoordinates>::const_iterator otherItEnd = other_d->m_vector.constEnd();
 
-    for ( ; itCoords != itEnd && otherItCoords != otherItEnd; ++itCoords, ++otherItCoords ) {
-        if ( *itCoords != *otherItCoords ) {
+    for (; itCoords != itEnd && otherItCoords != otherItEnd; ++itCoords, ++otherItCoords) {
+        if (*itCoords != *otherItCoords) {
             return false;
         }
     }
 
-    Q_ASSERT ( itCoords == itEnd && otherItCoords == otherItEnd );
+    Q_ASSERT(itCoords == itEnd && otherItCoords == otherItEnd);
     return true;
 }
 
-bool GeoDataLineString::operator!=( const GeoDataLineString &other ) const
+bool GeoDataLineString::operator!=(const GeoDataLineString &other) const
 {
     return !this->operator==(other);
 }
@@ -508,7 +521,7 @@ bool GeoDataLineString::tessellate() const
     return d->m_tessellationFlags.testFlag(Tessellate);
 }
 
-void GeoDataLineString::setTessellate( bool tessellate )
+void GeoDataLineString::setTessellate(bool tessellate)
 {
     detach();
 
@@ -531,7 +544,7 @@ TessellationFlags GeoDataLineString::tessellationFlags() const
     return d->m_tessellationFlags;
 }
 
-void GeoDataLineString::setTessellationFlags( TessellationFlags f )
+void GeoDataLineString::setTessellationFlags(TessellationFlags f)
 {
     detach();
 
@@ -557,25 +570,21 @@ GeoDataLineString GeoDataLineString::toNormalized() const
 
     GeoDataLineString normalizedLineString;
 
-    normalizedLineString.setTessellationFlags( tessellationFlags() );
+    normalizedLineString.setTessellationFlags(tessellationFlags());
 
     qreal lon;
     qreal lat;
 
     // FIXME: Think about how we can avoid unnecessary copies
     //        if the linestring stays the same.
-    QVector<GeoDataCoordinates>::const_iterator end = d->m_vector.constEnd();
-    for( QVector<GeoDataCoordinates>::const_iterator itCoords
-          = d->m_vector.constBegin();
-         itCoords != end;
-         ++itCoords ) {
-
-        itCoords->geoCoordinates( lon, lat );
+    QList<GeoDataCoordinates>::const_iterator end = d->m_vector.constEnd();
+    for (QList<GeoDataCoordinates>::const_iterator itCoords = d->m_vector.constBegin(); itCoords != end; ++itCoords) {
+        itCoords->geoCoordinates(lon, lat);
         qreal alt = itCoords->altitude();
-        GeoDataCoordinates::normalizeLonLat( lon, lat );
+        GeoDataCoordinates::normalizeLonLat(lon, lat);
 
-        GeoDataCoordinates normalizedCoords( *itCoords );
-        normalizedCoords.set( lon, lat, alt );
+        GeoDataCoordinates normalizedCoords(*itCoords);
+        normalizedCoords.set(lon, lat, alt);
         normalizedLineString << normalizedCoords;
     }
 
@@ -587,10 +596,9 @@ GeoDataLineString GeoDataLineString::toRangeCorrected() const
     Q_D(const GeoDataLineString);
 
     if (d->m_dirtyRange) {
-
         delete d->m_rangeCorrected;
 
-        if( isClosed() ) {
+        if (isClosed()) {
             d->m_rangeCorrected = new GeoDataLinearRing(toPoleCorrected());
         } else {
             d->m_rangeCorrected = new GeoDataLineString(toPoleCorrected());
@@ -601,11 +609,11 @@ GeoDataLineString GeoDataLineString::toRangeCorrected() const
     return *d->m_rangeCorrected;
 }
 
-QVector<GeoDataLineString*> GeoDataLineString::toDateLineCorrected() const
+QList<GeoDataLineString *> GeoDataLineString::toDateLineCorrected() const
 {
     Q_D(const GeoDataLineString);
 
-    QVector<GeoDataLineString*> lineStrings;
+    QList<GeoDataLineString *> lineStrings;
 
     d->toDateLineCorrected(*this, lineStrings);
 
@@ -616,7 +624,7 @@ GeoDataLineString GeoDataLineString::toPoleCorrected() const
 {
     Q_D(const GeoDataLineString);
 
-    if( isClosed() ) {
+    if (isClosed()) {
         GeoDataLinearRing poleCorrected;
         d->toPoleCorrected(*this, poleCorrected);
         return poleCorrected;
@@ -627,54 +635,49 @@ GeoDataLineString GeoDataLineString::toPoleCorrected() const
     }
 }
 
-void GeoDataLineStringPrivate::toPoleCorrected( const GeoDataLineString& q, GeoDataLineString& poleCorrected ) const
+void GeoDataLineStringPrivate::toPoleCorrected(const GeoDataLineString &q, GeoDataLineString &poleCorrected) const
 {
-    poleCorrected.setTessellationFlags( q.tessellationFlags() );
+    poleCorrected.setTessellationFlags(q.tessellationFlags());
 
     GeoDataCoordinates previousCoords;
     GeoDataCoordinates currentCoords;
 
-    if ( q.isClosed() ) {
-        if ( !( m_vector.first().isPole() ) &&
-              ( m_vector.last().isPole() ) ) {
-                qreal firstLongitude = ( m_vector.first() ).longitude();
-                GeoDataCoordinates modifiedCoords( m_vector.last() );
-                modifiedCoords.setLongitude( firstLongitude );
-                poleCorrected << modifiedCoords;
+    if (q.isClosed()) {
+        if (!(m_vector.first().isPole()) && (m_vector.last().isPole())) {
+            qreal firstLongitude = (m_vector.first()).longitude();
+            GeoDataCoordinates modifiedCoords(m_vector.last());
+            modifiedCoords.setLongitude(firstLongitude);
+            poleCorrected << modifiedCoords;
         }
     }
 
-    QVector<GeoDataCoordinates>::const_iterator itCoords = m_vector.constBegin();
-    QVector<GeoDataCoordinates>::const_iterator itEnd = m_vector.constEnd();
+    QList<GeoDataCoordinates>::const_iterator itCoords = m_vector.constBegin();
+    QList<GeoDataCoordinates>::const_iterator itEnd = m_vector.constEnd();
 
-    for( ; itCoords != itEnd; ++itCoords ) {
+    for (; itCoords != itEnd; ++itCoords) {
+        currentCoords = *itCoords;
 
-        currentCoords  = *itCoords;
-
-        if ( itCoords == m_vector.constBegin() ) {
+        if (itCoords == m_vector.constBegin()) {
             previousCoords = currentCoords;
         }
 
-        if ( currentCoords.isPole() ) {
-            if ( previousCoords.isPole() ) {
+        if (currentCoords.isPole()) {
+            if (previousCoords.isPole()) {
                 continue;
-            }
-            else {
+            } else {
                 qreal previousLongitude = previousCoords.longitude();
-                GeoDataCoordinates currentModifiedCoords( currentCoords );
-                currentModifiedCoords.setLongitude( previousLongitude );
+                GeoDataCoordinates currentModifiedCoords(currentCoords);
+                currentModifiedCoords.setLongitude(previousLongitude);
                 poleCorrected << currentModifiedCoords;
             }
-        }
-        else {
-            if ( previousCoords.isPole() ) {
+        } else {
+            if (previousCoords.isPole()) {
                 qreal currentLongitude = currentCoords.longitude();
-                GeoDataCoordinates previousModifiedCoords( previousCoords );
-                previousModifiedCoords.setLongitude( currentLongitude );
+                GeoDataCoordinates previousModifiedCoords(previousCoords);
+                previousModifiedCoords.setLongitude(currentLongitude);
                 poleCorrected << previousModifiedCoords;
                 poleCorrected << currentCoords;
-            }
-            else {
+            } else {
                 // No poles at all. Nothing special to handle
                 poleCorrected << currentCoords;
             }
@@ -682,108 +685,97 @@ void GeoDataLineStringPrivate::toPoleCorrected( const GeoDataLineString& q, GeoD
         previousCoords = currentCoords;
     }
 
-    if ( q.isClosed() ) {
-        if (  ( m_vector.first().isPole() ) &&
-             !( m_vector.last().isPole() ) ) {
-                qreal lastLongitude = ( m_vector.last() ).longitude();
-                GeoDataCoordinates modifiedCoords( m_vector.first() );
-                modifiedCoords.setLongitude( lastLongitude );
-                poleCorrected << modifiedCoords;
+    if (q.isClosed()) {
+        if ((m_vector.first().isPole()) && !(m_vector.last().isPole())) {
+            qreal lastLongitude = (m_vector.last()).longitude();
+            GeoDataCoordinates modifiedCoords(m_vector.first());
+            modifiedCoords.setLongitude(lastLongitude);
+            poleCorrected << modifiedCoords;
         }
     }
 }
 
-void GeoDataLineStringPrivate::toDateLineCorrected(
-                           const GeoDataLineString & q,
-                           QVector<GeoDataLineString*> & lineStrings
-                           ) const
+void GeoDataLineStringPrivate::toDateLineCorrected(const GeoDataLineString &q, QList<GeoDataLineString *> &lineStrings) const
 {
     const bool isClosed = q.isClosed();
 
-    const QVector<GeoDataCoordinates>::const_iterator itStartPoint = q.constBegin();
-    const QVector<GeoDataCoordinates>::const_iterator itEndPoint = q.constEnd();
-    QVector<GeoDataCoordinates>::const_iterator itPoint = itStartPoint;
-    QVector<GeoDataCoordinates>::const_iterator itPreviousPoint = itPoint;
+    const QList<GeoDataCoordinates>::const_iterator itStartPoint = q.constBegin();
+    const QList<GeoDataCoordinates>::const_iterator itEndPoint = q.constEnd();
+    QList<GeoDataCoordinates>::const_iterator itPoint = itStartPoint;
+    QList<GeoDataCoordinates>::const_iterator itPreviousPoint = itPoint;
 
     TessellationFlags f = q.tessellationFlags();
 
-    GeoDataLineString * unfinishedLineString = nullptr;
+    GeoDataLineString *unfinishedLineString = nullptr;
 
-    GeoDataLineString * dateLineCorrected = isClosed ? new GeoDataLinearRing( f )
-                                                     : new GeoDataLineString( f );
+    GeoDataLineString *dateLineCorrected = isClosed ? new GeoDataLinearRing(f) : new GeoDataLineString(f);
 
     qreal previousLon = 0.0;
     int previousSign = 1;
 
     bool unfinished = false;
 
-    for (; itPoint != itEndPoint; ++itPoint ) {
+    for (; itPoint != itEndPoint; ++itPoint) {
         const qreal currentLon = itPoint->longitude();
 
-        int currentSign = ( currentLon < 0.0 ) ? -1 : +1 ;
+        int currentSign = (currentLon < 0.0) ? -1 : +1;
 
-        if( itPoint == q.constBegin() ) {
+        if (itPoint == q.constBegin()) {
             previousSign = currentSign;
-            previousLon  = currentLon;
+            previousLon = currentLon;
         }
 
         // If we are crossing the date line ...
-        if ( previousSign != currentSign && fabs(previousLon) + fabs(currentLon) > M_PI ) {
-
+        if (previousSign != currentSign && fabs(previousLon) + fabs(currentLon) > M_PI) {
             unfinished = !unfinished;
 
             GeoDataCoordinates previousTemp;
             GeoDataCoordinates currentTemp;
 
-            interpolateDateLine( *itPreviousPoint, *itPoint,
-                                 previousTemp, currentTemp, q.tessellationFlags() );
+            interpolateDateLine(*itPreviousPoint, *itPoint, previousTemp, currentTemp, q.tessellationFlags());
 
             *dateLineCorrected << previousTemp;
 
-            if ( isClosed && unfinished ) {
+            if (isClosed && unfinished) {
                 // If it's a linear ring and if it crossed the IDL only once then
                 // store the current string inside the unfinishedLineString for later use ...
                 unfinishedLineString = dateLineCorrected;
                 // ... and start a new linear ring for now.
-                dateLineCorrected = new GeoDataLinearRing( f );
-            }
-            else {
+                dateLineCorrected = new GeoDataLinearRing(f);
+            } else {
                 // Now it can only be a (finished) line string or a finished linear ring.
                 // Store it in the vector  if the size is not zero.
-                if ( dateLineCorrected->size() > 0 ) {
+                if (dateLineCorrected->size() > 0) {
                     lineStrings << dateLineCorrected;
-                }
-                else {
+                } else {
                     // Or delete it.
                     delete dateLineCorrected;
                 }
 
                 // If it's a finished linear ring restore the "remembered" unfinished String
-                if ( isClosed && !unfinished && unfinishedLineString ) {
+                if (isClosed && !unfinished && unfinishedLineString) {
                     dateLineCorrected = unfinishedLineString;
-                }
-                else {
+                } else {
                     // if it's a line string just create a new line string.
-                    dateLineCorrected = new GeoDataLineString( f );
+                    dateLineCorrected = new GeoDataLineString(f);
                 }
             }
 
             *dateLineCorrected << currentTemp;
             *dateLineCorrected << *itPoint;
 
-        }
-        else {
+        } else {
             *dateLineCorrected << *itPoint;
         }
 
         previousSign = currentSign;
-        previousLon  = currentLon;
+        previousLon = currentLon;
         itPreviousPoint = itPoint;
     }
 
     // If the line string doesn't cross the dateline an even number of times
     // then need to take care of the data stored in the unfinishedLineString
-    if ( unfinished && unfinishedLineString && !unfinishedLineString->isEmpty() ) {
+    if (unfinished && unfinishedLineString && !unfinishedLineString->isEmpty()) {
         *dateLineCorrected << *unfinishedLineString;
         delete unfinishedLineString;
     }
@@ -791,7 +783,7 @@ void GeoDataLineStringPrivate::toDateLineCorrected(
     lineStrings << dateLineCorrected;
 }
 
-const GeoDataLatLonAltBox& GeoDataLineString::latLonAltBox() const
+const GeoDataLatLonAltBox &GeoDataLineString::latLonAltBox() const
 {
     Q_D(const GeoDataLineString);
 
@@ -807,26 +799,25 @@ const GeoDataLatLonAltBox& GeoDataLineString::latLonAltBox() const
     return d->m_latLonAltBox;
 }
 
-qreal GeoDataLineString::length( qreal planetRadius, int offset ) const
+qreal GeoDataLineString::length(qreal planetRadius, int offset) const
 {
-    if( offset < 0 || offset >= size() ) {
+    if (offset < 0 || offset >= size()) {
         return 0;
     }
 
     Q_D(const GeoDataLineString);
     qreal length = 0.0;
-    QVector<GeoDataCoordinates> const & vector = d->m_vector;
-    int const start = qMax(offset+1, 1);
+    QList<GeoDataCoordinates> const &vector = d->m_vector;
+    int const start = qMax(offset + 1, 1);
     int const end = d->m_vector.size();
-    for( int i=start; i<end; ++i )
-    {
-        length += vector[i-1].sphericalDistanceTo(vector[i]);
+    for (int i = start; i < end; ++i) {
+        length += vector[i - 1].sphericalDistanceTo(vector[i]);
     }
 
     return planetRadius * length;
 }
 
-QVector<GeoDataCoordinates>::Iterator GeoDataLineString::erase ( const QVector<GeoDataCoordinates>::Iterator& pos )
+QList<GeoDataCoordinates>::Iterator GeoDataLineString::erase(const QList<GeoDataCoordinates>::Iterator &pos)
 {
     detach();
 
@@ -835,11 +826,10 @@ QVector<GeoDataCoordinates>::Iterator GeoDataLineString::erase ( const QVector<G
     d->m_rangeCorrected = nullptr;
     d->m_dirtyRange = true;
     d->m_dirtyBox = true;
-    return d->m_vector.erase( pos );
+    return d->m_vector.erase(pos);
 }
 
-QVector<GeoDataCoordinates>::Iterator GeoDataLineString::erase ( const QVector<GeoDataCoordinates>::Iterator& begin,
-                                                                 const QVector<GeoDataCoordinates>::Iterator& end )
+QList<GeoDataCoordinates>::Iterator GeoDataLineString::erase(const QList<GeoDataCoordinates>::Iterator &begin, const QList<GeoDataCoordinates>::Iterator &end)
 {
     detach();
 
@@ -848,24 +838,24 @@ QVector<GeoDataCoordinates>::Iterator GeoDataLineString::erase ( const QVector<G
     d->m_rangeCorrected = nullptr;
     d->m_dirtyRange = true;
     d->m_dirtyBox = true;
-    return d->m_vector.erase( begin, end );
+    return d->m_vector.erase(begin, end);
 }
 
-void GeoDataLineString::remove ( int i )
+void GeoDataLineString::remove(int i)
 {
     detach();
 
     Q_D(GeoDataLineString);
     d->m_dirtyRange = true;
     d->m_dirtyBox = true;
-    d->m_vector.remove( i );
+    d->m_vector.remove(i);
 }
 
-GeoDataLineString GeoDataLineString::optimized () const
+GeoDataLineString GeoDataLineString::optimized() const
 {
     Q_D(const GeoDataLineString);
 
-    if( isClosed() ) {
+    if (isClosed()) {
         GeoDataLinearRing linearRing(*this);
         d->optimize(linearRing);
         return linearRing;
@@ -881,52 +871,48 @@ QVariantList GeoDataLineString::toVariantList() const
     Q_D(const GeoDataLineString);
 
     QVariantList variantList;
-    for( const GeoDataCoordinates & itCoords : qAsConst(d->m_vector) ) {
+    for (const GeoDataCoordinates &itCoords : std::as_const(d->m_vector)) {
         QVariantMap map;
-        map.insert("lon", itCoords.longitude(GeoDataCoordinates::Degree));
-        map.insert("lat", itCoords.latitude(GeoDataCoordinates::Degree));
-        map.insert("alt", itCoords.altitude());
+        map.insert(QLatin1StringView("lon"), itCoords.longitude(GeoDataCoordinates::Degree));
+        map.insert(QLatin1StringView("lat"), itCoords.latitude(GeoDataCoordinates::Degree));
+        map.insert(QLatin1StringView("alt"), itCoords.altitude());
         variantList << map;
     }
 
     if (isClosed()) {
         QVariantMap map;
-        map.insert("lon", d->m_vector.first().longitude(GeoDataCoordinates::Degree));
-        map.insert("lat", d->m_vector.first().latitude(GeoDataCoordinates::Degree));
-        map.insert("alt", d->m_vector.first().altitude());
+        map.insert(QLatin1StringView("lon"), d->m_vector.first().longitude(GeoDataCoordinates::Degree));
+        map.insert(QLatin1StringView("lat"), d->m_vector.first().latitude(GeoDataCoordinates::Degree));
+        map.insert(QLatin1StringView("alt"), d->m_vector.first().altitude());
         variantList << map;
     }
 
     return variantList;
 }
 
-void GeoDataLineString::pack( QDataStream& stream ) const
+void GeoDataLineString::pack(QDataStream &stream) const
 {
     Q_D(const GeoDataLineString);
 
-    GeoDataGeometry::pack( stream );
+    GeoDataGeometry::pack(stream);
 
     stream << size();
     stream << (qint32)(d->m_tessellationFlags);
 
-    for( QVector<GeoDataCoordinates>::const_iterator iterator
-          = d->m_vector.constBegin();
-         iterator != d->m_vector.constEnd();
-         ++iterator ) {
+    for (QList<GeoDataCoordinates>::const_iterator iterator = d->m_vector.constBegin(); iterator != d->m_vector.constEnd(); ++iterator) {
         mDebug() << "innerRing: size" << d->m_vector.size();
-        GeoDataCoordinates coord = ( *iterator );
-        coord.pack( stream );
+        GeoDataCoordinates coord = (*iterator);
+        coord.pack(stream);
     }
-
 }
 
-void GeoDataLineString::unpack( QDataStream& stream )
+void GeoDataLineString::unpack(QDataStream &stream)
 {
     detach();
 
     Q_D(GeoDataLineString);
 
-    GeoDataGeometry::unpack( stream );
+    GeoDataGeometry::unpack(stream);
     qint32 size;
     qint32 tessellationFlags;
 
@@ -937,10 +923,10 @@ void GeoDataLineString::unpack( QDataStream& stream )
 
     d->m_vector.reserve(d->m_vector.size() + size);
 
-    for(qint32 i = 0; i < size; i++ ) {
+    for (qint32 i = 0; i < size; i++) {
         GeoDataCoordinates coord;
-        coord.unpack( stream );
-        d->m_vector.append( coord );
+        coord.unpack(stream);
+        d->m_vector.append(coord);
     }
 }
 
