@@ -12,40 +12,37 @@
 // Marble
 #include "GeoDataTypes.h"
 
-
 namespace Marble
 {
 
 class GeoDataSimpleFieldPrivate
 {
-  public:
+public:
     QString m_name;
     GeoDataSimpleField::SimpleFieldType m_type;
     QString m_displayName;
 };
 
 GeoDataSimpleField::GeoDataSimpleField()
-    : GeoNode(),
-      d( new GeoDataSimpleFieldPrivate )
+    : GeoNode()
+    , d(new GeoDataSimpleFieldPrivate)
 {
 }
 
-GeoDataSimpleField::GeoDataSimpleField( const GeoDataSimpleField& other )
-    : GeoNode(),
-      d( new GeoDataSimpleFieldPrivate( *other.d ) )
+GeoDataSimpleField::GeoDataSimpleField(const GeoDataSimpleField &other)
+    : GeoNode()
+    , d(new GeoDataSimpleFieldPrivate(*other.d))
 {
 }
 
-bool GeoDataSimpleField::operator==(const GeoDataSimpleField& other) const
+bool GeoDataSimpleField::operator==(const GeoDataSimpleField &other) const
 {
-    return d->m_name == other.d->m_name && 
-           d->m_type == other.d->m_type && 
-           d->m_displayName == other.d->m_displayName;
+    return d->m_name == other.d->m_name && d->m_type == other.d->m_type && d->m_displayName == other.d->m_displayName;
 }
 
-bool GeoDataSimpleField::operator!=(const GeoDataSimpleField& other) const
+bool GeoDataSimpleField::operator!=(const GeoDataSimpleField &other) const
 {
-    return !this->operator==( other );
+    return !this->operator==(other);
 }
 
 GeoDataSimpleField::~GeoDataSimpleField()
@@ -68,7 +65,7 @@ QString GeoDataSimpleField::name() const
     return d->m_name;
 }
 
-void GeoDataSimpleField::setName( const QString& value )
+void GeoDataSimpleField::setName(const QString &value)
 {
     d->m_name = value;
 }
@@ -78,33 +75,32 @@ QString GeoDataSimpleField::displayName() const
     return d->m_displayName;
 }
 
-void GeoDataSimpleField::setDisplayName( const QString& displayName )
+void GeoDataSimpleField::setDisplayName(const QString &displayName)
 {
     d->m_displayName = displayName;
 }
 
-GeoDataSimpleField& GeoDataSimpleField::operator=( const GeoDataSimpleField& other )
+GeoDataSimpleField &GeoDataSimpleField::operator=(const GeoDataSimpleField &other)
 {
     *d = *other.d;
     return *this;
 }
 
-const char* GeoDataSimpleField::nodeType() const
+const char *GeoDataSimpleField::nodeType() const
 {
     return GeoDataTypes::GeoDataSimpleFieldType;
 }
 
-void GeoDataSimpleField::pack( QDataStream& stream ) const
+void GeoDataSimpleField::pack(QDataStream &stream) const
 {
     stream << d->m_name;
     stream << d->m_displayName;
 }
 
-void GeoDataSimpleField::unpack( QDataStream& stream )
+void GeoDataSimpleField::unpack(QDataStream &stream)
 {
     stream >> d->m_name;
     stream >> d->m_displayName;
 }
 
-
 }
