@@ -16,7 +16,7 @@ namespace Marble
 
 class GeoDataTimeStampPrivate
 {
-  public:
+public:
     QDateTime m_when;
 
     GeoDataTimeStamp::TimeResolution m_resolution;
@@ -24,13 +24,12 @@ class GeoDataTimeStampPrivate
     GeoDataTimeStampPrivate();
 };
 
-GeoDataTimeStampPrivate::GeoDataTimeStampPrivate() :
-  m_resolution( GeoDataTimeStamp::SecondResolution )
+GeoDataTimeStampPrivate::GeoDataTimeStampPrivate()
+    : m_resolution(GeoDataTimeStamp::SecondResolution)
 {
-  // nothing to do
+    // nothing to do
 }
 
 } // namespace Marble
 
-#endif //GEODATATIMESTAMPPRIVATE_H
-
+#endif // GEODATATIMESTAMPPRIVATE_H
