@@ -6,19 +6,18 @@
 #include "GeoDataTour.h"
 #include "GeoDataTour_p.h"
 
-
 namespace Marble
 {
 
 const GeoDataTour GeoDataTour::null;
 
 GeoDataTour::GeoDataTour()
-    : GeoDataFeature( new GeoDataTourPrivate )
+    : GeoDataFeature(new GeoDataTourPrivate)
 {
     // nothing to do
 }
 
-GeoDataTour::GeoDataTour(const GeoDataTour& other)
+GeoDataTour::GeoDataTour(const GeoDataTour &other)
     : GeoDataFeature(other, new GeoDataTourPrivate(*other.d_func()))
 {
 }
@@ -28,7 +27,7 @@ GeoDataTour::~GeoDataTour()
     // nothing to do;
 }
 
-GeoDataTour& GeoDataTour::operator=(const GeoDataTour& other)
+GeoDataTour &GeoDataTour::operator=(const GeoDataTour &other)
 {
     if (this != &other) {
         Q_D(GeoDataTour);
@@ -38,32 +37,29 @@ GeoDataTour& GeoDataTour::operator=(const GeoDataTour& other)
     return *this;
 }
 
-
-bool GeoDataTour::operator==(const GeoDataTour& other) const
+bool GeoDataTour::operator==(const GeoDataTour &other) const
 {
     Q_D(const GeoDataTour);
-    return equals( other ) &&
-           *d->m_playlist == *other.d_func()->m_playlist;
+    return equals(other) && *d->m_playlist == *other.d_func()->m_playlist;
 }
 
-bool GeoDataTour::operator!=(const GeoDataTour& other) const
+bool GeoDataTour::operator!=(const GeoDataTour &other) const
 {
     return !this->operator==(other);
 }
 
-GeoDataFeature * GeoDataTour::clone() const
+GeoDataFeature *GeoDataTour::clone() const
 {
     return new GeoDataTour(*this);
 }
 
-
-GeoDataPlaylist* GeoDataTour::playlist()
+GeoDataPlaylist *GeoDataTour::playlist()
 {
     Q_D(GeoDataTour);
     return d->m_playlist;
 }
 
-const GeoDataPlaylist* GeoDataTour::playlist() const
+const GeoDataPlaylist *GeoDataTour::playlist() const
 {
     Q_D(const GeoDataTour);
     return d->m_playlist;
