@@ -6,39 +6,44 @@
 #ifndef GEODATAVEC2_H
 #define GEODATAVEC2_H
 
-#include <QPointF>
 #include "geodata_export.h"
+#include <QPointF>
 
 class QString;
 
-namespace Marble {
+namespace Marble
+{
 
 class GeoDataVec2Private;
 
 class GEODATA_EXPORT GeoDataVec2 : public QPointF
 {
 public:
-    enum Unit {Fraction, Pixels, InsetPixels};
+    enum Unit {
+        Fraction,
+        Pixels,
+        InsetPixels
+    };
 
     GeoDataVec2();
 
     GeoDataVec2(qreal x, qreal y, const QString &xunit, const QString &yunit);
 
-    GeoDataVec2( const GeoDataVec2 &other );
+    GeoDataVec2(const GeoDataVec2 &other);
 
-    GeoDataVec2& operator=( const GeoDataVec2 &other );
-    bool operator==( const GeoDataVec2 &other ) const;
-    bool operator!=( const GeoDataVec2 &other ) const;
+    GeoDataVec2 &operator=(const GeoDataVec2 &other);
+    bool operator==(const GeoDataVec2 &other) const;
+    bool operator!=(const GeoDataVec2 &other) const;
     ~GeoDataVec2();
 
     Unit xunit() const;
-    void setXunits( Unit xunit );
+    void setXunits(Unit xunit);
 
     Unit yunit() const;
-    void setYunits( Unit yunit );
+    void setYunits(Unit yunit);
 
 private:
-    GeoDataVec2Private* const d;
+    GeoDataVec2Private *const d;
 };
 
 }
