@@ -3,20 +3,20 @@
 // SPDX-FileCopyrightText: 2007 Murad Tagirov <tmurad@gmail.com>
 //
 
-
 #ifndef MARBLE_SERIALIZABLE_H
 #define MARBLE_SERIALIZABLE_H
 
 class QDataStream;
 
-namespace Marble {
+namespace Marble
+{
 
 class Serializable
 {
- public:
-    virtual ~Serializable(){}
-    virtual void pack( QDataStream& stream ) const = 0;
-    virtual void unpack( QDataStream& stream ) = 0;
+public:
+    virtual ~Serializable() = default;
+    virtual void pack(QDataStream &stream) const = 0;
+    virtual void unpack(QDataStream &stream) = 0;
 };
 
 /* the next two id's are needed to get unpacking working - this cannot be
