@@ -19,9 +19,9 @@ namespace dgml
 {
 DGML_DEFINE_TAG_HANDLER(Head)
 
-GeoNode* DgmlHeadTagHandler::parse(GeoParser& parser) const
+GeoNode *DgmlHeadTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(dgmlTag_Head)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(dgmlTag_Head)));
 
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
