@@ -5,8 +5,8 @@
 
 #include "DgmlRenderOrderTagHandler.h"
 
-#include "DgmlElementDictionary.h"
 #include "DgmlAttributeDictionary.h"
+#include "DgmlElementDictionary.h"
 #include "GeoParser.h"
 #include "GeoSceneGeodata.h"
 
@@ -16,18 +16,17 @@ namespace dgml
 {
 DGML_DEFINE_TAG_HANDLER(RenderOrder)
 
-GeoNode* DgmlRenderOrderTagHandler::parse(GeoParser& parser) const
+GeoNode *DgmlRenderOrderTagHandler::parse(GeoParser &parser) const
 {
     // Check whether the tag is valid
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(dgmlTag_RenderOrder)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(dgmlTag_RenderOrder)));
 
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
-    if ( parentItem.represents( dgmlTag_Vector )
-         || parentItem.represents( dgmlTag_Geodata ) ) {
+    if (parentItem.represents(dgmlTag_Vector) || parentItem.represents(dgmlTag_Geodata)) {
         GeoSceneGeodata *dataSource = nullptr;
         dataSource = parentItem.nodeAs<GeoSceneGeodata>();
-        dataSource->setRenderOrder( parser.readElementText().trimmed().toInt() );
+        dataSource->setRenderOrder(parser.readElementText().trimmed().toInt());
     }
 
     return nullptr;
