@@ -19,9 +19,9 @@ namespace dgml
 {
 DGML_DEFINE_TAG_HANDLER(Settings)
 
-GeoNode* DgmlSettingsTagHandler::parse(GeoParser& parser) const
+GeoNode *DgmlSettingsTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(dgmlTag_Settings)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(dgmlTag_Settings)));
 
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
