@@ -6,8 +6,8 @@
 
 #include "DgmlVisibleTagHandler.h"
 
-#include "DgmlElementDictionary.h"
 #include "DgmlAuxillaryDictionary.h"
+#include "DgmlElementDictionary.h"
 #include "GeoParser.h"
 #include "GeoSceneHead.h"
 
@@ -17,16 +17,16 @@ namespace dgml
 {
 DGML_DEFINE_TAG_HANDLER(Visible)
 
-GeoNode* DgmlVisibleTagHandler::parse(GeoParser& parser) const
+GeoNode *DgmlVisibleTagHandler::parse(GeoParser &parser) const
 {
     // Check whether the tag is valid
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(dgmlTag_Visible)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(dgmlTag_Visible)));
 
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
-    if ( parentItem.represents( dgmlTag_Head ) ) {
+    if (parentItem.represents(dgmlTag_Head)) {
         QString parsedText = parser.readElementText().toLower().trimmed();
-        parentItem.nodeAs<GeoSceneHead>()->setVisible(parsedText == dgmlValue_true || parsedText == dgmlValue_on);
+        parentItem.nodeAs<GeoSceneHead>()->setVisible(parsedText == QString::fromLatin1(dgmlValue_true) || parsedText == QString::fromLatin1(dgmlValue_on));
     }
 
     return nullptr;
