@@ -6,9 +6,9 @@
 
 #include "KmlAddressTagHandler.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataFeature.h"
 #include "GeoParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
@@ -18,7 +18,7 @@ KML_DEFINE_TAG_HANDLER(address)
 
 GeoNode *KmladdressTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_address)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_address)));
 
     GeoStackItem parentItem = parser.parentElement();
     if (parentItem.is<GeoDataFeature>()) {
