@@ -5,11 +5,8 @@
 
 #include "KmlBalloonStyleTagHandler.h"
 
-#include "MarbleDebug.h"
-
 #include "GeoDataBalloonStyle.h"
 #include "GeoDataStyle.h"
-#include "GeoDataParser.h"
 #include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
 
@@ -17,19 +14,19 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( BalloonStyle )
+KML_DEFINE_TAG_HANDLER(BalloonStyle)
 
-GeoNode* KmlBalloonStyleTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlBalloonStyleTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_BalloonStyle)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_BalloonStyle)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.represents( kmlTag_Style ) ) {
+    if (parentItem.represents(kmlTag_Style)) {
         GeoDataBalloonStyle style;
-        KmlObjectTagHandler::parseIdentifiers( parser, &style );
+        KmlObjectTagHandler::parseIdentifiers(parser, &style);
 
-        parentItem.nodeAs<GeoDataStyle>()->setBalloonStyle( style );
+        parentItem.nodeAs<GeoDataStyle>()->setBalloonStyle(style);
         return &parentItem.nodeAs<GeoDataStyle>()->balloonStyle();
     }
     return nullptr;
