@@ -5,7 +5,6 @@
 #include "KmlBalloonVisibilityTagHandler.h"
 #include "GeoDataPlacemark.h"
 #include "GeoParser.h"
-#include "MarbleDebug.h"
 #include "KmlElementDictionary.h"
 
 #include <QDebug>
@@ -16,20 +15,20 @@ namespace kml
 {
 namespace gx
 {
-KML_DEFINE_TAG_HANDLER_GX22( balloonVisibility )
+KML_DEFINE_TAG_HANDLER_GX22(balloonVisibility)
 
-GeoNode* KmlballoonVisibilityTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlballoonVisibilityTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_balloonVisibility)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_balloonVisibility)));
 
     QString content = parser.readElementText().trimmed();
 
-    const bool visible = (content == QLatin1String("1"));
+    const bool visible = (content == QLatin1StringView("1"));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if( parentItem.is<GeoDataPlacemark>() ){
-        parentItem.nodeAs<GeoDataPlacemark>()->setBalloonVisible( visible );
+    if (parentItem.is<GeoDataPlacemark>()) {
+        parentItem.nodeAs<GeoDataPlacemark>()->setBalloonVisible(visible);
     }
 
     return nullptr;
