@@ -5,28 +5,27 @@
 
 #include "KmlChangeTagHandler.h"
 
-#include "KmlElementDictionary.h"
-#include "GeoDataUpdate.h"
 #include "GeoDataChange.h"
-#include "GeoDataParser.h"
+#include "GeoDataUpdate.h"
+#include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( Change )
+KML_DEFINE_TAG_HANDLER(Change)
 
-GeoNode* KmlChangeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlChangeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Change)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_Change)));
 
-    GeoDataChange *change = new GeoDataChange;
-    KmlObjectTagHandler::parseIdentifiers( parser, change );
+    auto change = new GeoDataChange;
+    KmlObjectTagHandler::parseIdentifiers(parser, change);
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.represents( kmlTag_Update ) ) {
-        parentItem.nodeAs<GeoDataUpdate>()->setChange( change );
+    if (parentItem.represents(kmlTag_Update)) {
+        parentItem.nodeAs<GeoDataUpdate>()->setChange(change);
         return change;
     } else {
         delete change;
