@@ -7,8 +7,6 @@
 #if KML_LAZY_IMP
 #include "KmlCountryNameCodeTagHandler.h"
 
-#include "MarbleDebug.h"
-
 #include "KmlElementDictionary.h"
 
 #include "GeoDataPlacemark.h"
@@ -18,18 +16,18 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( CountryNameCode )
+KML_DEFINE_TAG_HANDLER(CountryNameCode)
 
-GeoNode* KmlCountryNameCodeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlCountryNameCodeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_CountryNameCode)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_CountryNameCode)));
 
     GeoStackItem parentItem = parser.parentElement();
-    
-    if( parentItem.nodeAs<GeoDataPlacemark>() ) {
+
+    if (parentItem.nodeAs<GeoDataPlacemark>()) {
         QString countrycode = parser.readElementText().trimmed();
-        
-        parentItem.nodeAs<GeoDataPlacemark>()->setCountryCode( countrycode );
+
+        parentItem.nodeAs<GeoDataPlacemark>()->setCountryCode(countrycode);
     }
 
     return nullptr;
