@@ -7,8 +7,6 @@
 #if KML_LAZY_IMP
 #include "KmlCountrycodeTagHandler.h"
 
-#include "MarbleDebug.h"
-
 #include "KmlElementDictionary.h"
 
 #include "GeoDataPlacemark.h"
@@ -18,18 +16,18 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( countrycode )
+KML_DEFINE_TAG_HANDLER(countrycode)
 
-GeoNode* KmlcountrycodeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlcountrycodeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_countrycode)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_countrycode)));
 
     GeoStackItem parentItem = parser.parentElement();
-    
-    if( parentItem.is<GeoDataPlacemark>() ) {
+
+    if (parentItem.is<GeoDataPlacemark>()) {
         QString countrycode = parser.readElementText().trimmed();
-        
-        parentItem.nodeAs<GeoDataPlacemark>()->setCountryCode( countrycode );
+
+        parentItem.nodeAs<GeoDataPlacemark>()->setCountryCode(countrycode);
     }
 
     return nullptr;
@@ -38,4 +36,4 @@ GeoNode* KmlcountrycodeTagHandler::parse( GeoParser& parser ) const
 }
 }
 
-#endif //KML_LAZY_IMP
+#endif // KML_LAZY_IMP
