@@ -5,29 +5,27 @@
 
 #include "KmlEndTagHandler.h"
 
-#include "MarbleDebug.h"
-
-#include "KmlWhenTagHandler.h"
-#include "KmlElementDictionary.h"
 #include "GeoDataTimeSpan.h"
 #include "GeoParser.h"
+#include "KmlElementDictionary.h"
+#include "KmlWhenTagHandler.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( end )
+KML_DEFINE_TAG_HANDLER(end)
 
-GeoNode* KmlendTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlendTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_end)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_end)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if( parentItem.represents( kmlTag_TimeSpan ) ) {
+    if (parentItem.represents(kmlTag_TimeSpan)) {
         QString endString = parser.readElementText().trimmed();
-        GeoDataTimeStamp endStamp = KmlwhenTagHandler::parseTimestamp( endString );
-        parentItem.nodeAs<GeoDataTimeSpan>()->setEnd( endStamp );
+        GeoDataTimeStamp endStamp = KmlwhenTagHandler::parseTimestamp(endString);
+        parentItem.nodeAs<GeoDataTimeSpan>()->setEnd(endStamp);
     }
 
     return nullptr;
