@@ -6,15 +6,14 @@
 */
 
 #include "KmlExtrudeTagHandler.h"
-#include "MarbleDebug.h"
 #include "KmlElementDictionary.h"
 
 #include "GeoDataGeometry.h"
-#include "GeoDataPoint.h"
-#include "GeoDataPolygon.h"
 #include "GeoDataLineString.h"
 #include "GeoDataLinearRing.h"
 #include "GeoDataPlacemark.h"
+#include "GeoDataPoint.h"
+#include "GeoDataPolygon.h"
 
 #include "GeoParser.h"
 
@@ -22,38 +21,38 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( extrude )
+KML_DEFINE_TAG_HANDLER(extrude)
 
-GeoNode* KmlextrudeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlextrudeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_extrude)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_extrude)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    GeoDataGeometry* geometry;
+    GeoDataGeometry *geometry;
     bool validParents = false;
 
-    if( parentItem.is<GeoDataPoint>() ) {
+    if (parentItem.is<GeoDataPoint>()) {
         geometry = parentItem.nodeAs<GeoDataPoint>();
         validParents = true;
-    } else if( parentItem.is<GeoDataPlacemark>() ) {
+    } else if (parentItem.is<GeoDataPlacemark>()) {
         geometry = parentItem.nodeAs<GeoDataPlacemark>()->geometry();
         validParents = true;
-    } else if( parentItem.is<GeoDataPolygon>() ) {
+    } else if (parentItem.is<GeoDataPolygon>()) {
         geometry = parentItem.nodeAs<GeoDataPolygon>();
         validParents = true;
-    } else if( parentItem.is<GeoDataLineString>() ) {
+    } else if (parentItem.is<GeoDataLineString>()) {
         geometry = parentItem.nodeAs<GeoDataLineString>();
         validParents = true;
-    } else if( parentItem.is<GeoDataLinearRing>() ) {
+    } else if (parentItem.is<GeoDataLinearRing>()) {
         geometry = parentItem.nodeAs<GeoDataLinearRing>();
         validParents = true;
     }
 
-    if( validParents ) {
+    if (validParents) {
         QString content = parser.readElementText().trimmed();
 
-        const bool extrude = (content == QLatin1String("1"));
+        const bool extrude = (content == QLatin1StringView("1"));
         geometry->setExtrude(extrude);
     }
 
