@@ -13,17 +13,17 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( flyToView )
+KML_DEFINE_TAG_HANDLER(flyToView)
 
-GeoNode* KmlflyToViewTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlflyToViewTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_flyToView)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_flyToView)));
 
     GeoStackItem parentItem = parser.parentElement();
-    if( parentItem.is<GeoDataNetworkLink>() ) {
+    if (parentItem.is<GeoDataNetworkLink>()) {
         QString content = parser.readElementText().trimmed();
-        GeoDataNetworkLink* networkLink = parentItem.nodeAs<GeoDataNetworkLink>();
-        networkLink->setFlyToView(content == QLatin1String("1"));
+        auto networkLink = parentItem.nodeAs<GeoDataNetworkLink>();
+        networkLink->setFlyToView(content == QLatin1StringView("1"));
     }
 
     return nullptr;
