@@ -18,11 +18,11 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( innerBoundaryIs )
+KML_DEFINE_TAG_HANDLER(innerBoundaryIs)
 
-GeoNode* KmlinnerBoundaryIsTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlinnerBoundaryIsTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_innerBoundaryIs)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_innerBoundaryIs)));
 
     GeoStackItem parentItem = parser.parentElement();
 
