@@ -5,26 +5,25 @@
 
 #include "KmlLatLonQuadTagHandler.h"
 
+#include "GeoDataGroundOverlay.h"
+#include "GeoDataLatLonQuad.h"
+#include "GeoParser.h"
 #include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
-#include "GeoParser.h"
-#include "GeoDataLatLonQuad.h"
-#include "GeoDataGroundOverlay.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER_GX22( LatLonQuad )
+KML_DEFINE_TAG_HANDLER_GX22(LatLonQuad)
 
-GeoNode* KmlLatLonQuadTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlLatLonQuadTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_LatLonQuad)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_LatLonQuad)));
     GeoStackItem parentItem = parser.parentElement();
-    if( parentItem.represents( kmlTag_GroundOverlay ) )
-    {
-        GeoDataLatLonQuad* quad = &parentItem.nodeAs<GeoDataGroundOverlay>()->latLonQuad();
-        KmlObjectTagHandler::parseIdentifiers( parser, quad );
+    if (parentItem.represents(kmlTag_GroundOverlay)) {
+        GeoDataLatLonQuad *quad = &parentItem.nodeAs<GeoDataGroundOverlay>()->latLonQuad();
+        KmlObjectTagHandler::parseIdentifiers(parser, quad);
         return quad;
     }
 
