@@ -7,32 +7,32 @@
 
 #include "MarbleDebug.h"
 
+#include "GeoDataLink.h"
+#include "GeoDataModel.h"
+#include "GeoDataNetworkLink.h"
+#include "GeoDataParser.h"
 #include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
-#include "GeoDataLink.h"
-#include "GeoDataNetworkLink.h"
-#include "GeoDataModel.h"
-#include "GeoDataParser.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( Link )
+KML_DEFINE_TAG_HANDLER(Link)
 
-GeoNode* KmlLinkTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlLinkTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Link)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_Link)));
     GeoDataLink link;
-    KmlObjectTagHandler::parseIdentifiers( parser, &link );
+    KmlObjectTagHandler::parseIdentifiers(parser, &link);
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.represents( kmlTag_NetworkLink )) {
+    if (parentItem.represents(kmlTag_NetworkLink)) {
         return &parentItem.nodeAs<GeoDataNetworkLink>()->link();
-    } else if( parentItem.represents( kmlTag_Model ) ) {
+    } else if (parentItem.represents(kmlTag_Model)) {
         parentItem.nodeAs<GeoDataModel>()->setLink(link);
         return &parentItem.nodeAs<GeoDataModel>()->link();
-    }else{
+    } else {
         return nullptr;
     }
 }
