@@ -7,41 +7,38 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataListStyle.h"
 #include "GeoDataParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( listItemType )
+KML_DEFINE_TAG_HANDLER(listItemType)
 
-GeoNode* KmllistItemTypeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmllistItemTypeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_listItemType)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_listItemType)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.represents( kmlTag_ListStyle ) )
-    {
+    if (parentItem.represents(kmlTag_ListStyle)) {
         QString typeText = parser.readElementText().trimmed();
         GeoDataListStyle::ListItemType type = GeoDataListStyle::Check;
-        if (typeText == QLatin1String("check")) {
+        if (typeText == QLatin1StringView("check")) {
             type = GeoDataListStyle::Check;
-        } else if (typeText == QLatin1String("radioFolder")) {
+        } else if (typeText == QLatin1StringView("radioFolder")) {
             type = GeoDataListStyle::RadioFolder;
-        } else if (typeText == QLatin1String("checkOffOnly")) {
+        } else if (typeText == QLatin1StringView("checkOffOnly")) {
             type = GeoDataListStyle::CheckOffOnly;
-        } else if (typeText == QLatin1String("checkHideChildren")) {
+        } else if (typeText == QLatin1StringView("checkHideChildren")) {
             type = GeoDataListStyle::CheckHideChildren;
-        }
-        else
-        {
+        } else {
             mDebug() << "listItemType value is invalid"
                      << "falling back to default - check";
         }
-        parentItem.nodeAs<GeoDataListStyle>()->setListItemType( type );
+        parentItem.nodeAs<GeoDataListStyle>()->setListItemType(type);
     }
     return nullptr;
 }
