@@ -8,8 +8,8 @@
 #include "MarbleDebug.h"
 
 #include "GeoDataListStyle.h"
-#include "GeoDataStyle.h"
 #include "GeoDataParser.h"
+#include "GeoDataStyle.h"
 #include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
 
@@ -17,19 +17,19 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( ListStyle )
+KML_DEFINE_TAG_HANDLER(ListStyle)
 
-GeoNode* KmlListStyleTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlListStyleTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_ListStyle)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_ListStyle)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.represents( kmlTag_Style ) ) {
+    if (parentItem.represents(kmlTag_Style)) {
         GeoDataListStyle style;
-        KmlObjectTagHandler::parseIdentifiers( parser, &style );
+        KmlObjectTagHandler::parseIdentifiers(parser, &style);
 
-        parentItem.nodeAs<GeoDataStyle>()->setListStyle( style );
+        parentItem.nodeAs<GeoDataStyle>()->setListStyle(style);
         return &parentItem.nodeAs<GeoDataStyle>()->listStyle();
     }
     return nullptr;
