@@ -7,26 +7,26 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataLatLonAltBox.h"
 #include "GeoParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( maxAltitude )
+KML_DEFINE_TAG_HANDLER(maxAltitude)
 
-GeoNode* KmlmaxAltitudeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlmaxAltitudeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_maxAltitude)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_maxAltitude)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if( parentItem.represents( kmlTag_LatLonAltBox ) ) {
+    if (parentItem.represents(kmlTag_LatLonAltBox)) {
         float maxAltitude = parser.readElementText().trimmed().toFloat();
 
-        parentItem.nodeAs<GeoDataLatLonAltBox>()->setMaxAltitude( maxAltitude );
+        parentItem.nodeAs<GeoDataLatLonAltBox>()->setMaxAltitude(maxAltitude);
     }
 
     return nullptr;
