@@ -7,27 +7,26 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataImagePyramid.h"
 #include "GeoDataParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( maxWidth )
+KML_DEFINE_TAG_HANDLER(maxWidth)
 
-GeoNode* KmlmaxWidthTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlmaxWidthTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_maxWidth)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_maxWidth)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if (parentItem.represents( kmlTag_ImagePyramid ))
-    {
+    if (parentItem.represents(kmlTag_ImagePyramid)) {
         int maxWidth = parser.readElementText().toInt();
 
-        parentItem.nodeAs<GeoDataImagePyramid>()->setMaxWidth( maxWidth );
+        parentItem.nodeAs<GeoDataImagePyramid>()->setMaxWidth(maxWidth);
     }
     return nullptr;
 }
