@@ -6,11 +6,11 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
-#include "KmlObjectTagHandler.h"
-#include "GeoDataPlacemark.h"
 #include "GeoDataMultiGeometry.h"
 #include "GeoDataMultiTrack.h"
+#include "GeoDataPlacemark.h"
+#include "KmlElementDictionary.h"
+#include "KmlObjectTagHandler.h"
 
 #include "GeoParser.h"
 
@@ -19,22 +19,22 @@ namespace Marble
 namespace kml
 {
 
-KML_DEFINE_TAG_HANDLER_GX22( MultiTrack )
+KML_DEFINE_TAG_HANDLER_GX22(MultiTrack)
 
-GeoNode* KmlMultiTrackTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlMultiTrackTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_MultiTrack)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_MultiTrack)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    GeoDataMultiTrack *geom = new GeoDataMultiTrack;
-    KmlObjectTagHandler::parseIdentifiers( parser, geom );
-    if( parentItem.represents( kmlTag_Placemark ) ) {
-        parentItem.nodeAs<GeoDataPlacemark>()->setGeometry( geom );
+    auto geom = new GeoDataMultiTrack;
+    KmlObjectTagHandler::parseIdentifiers(parser, geom);
+    if (parentItem.represents(kmlTag_Placemark)) {
+        parentItem.nodeAs<GeoDataPlacemark>()->setGeometry(geom);
         return parentItem.nodeAs<GeoDataPlacemark>()->geometry();
 
-    } else if( parentItem.represents( kmlTag_MultiGeometry ) ) {
-        parentItem.nodeAs<GeoDataMultiGeometry>()->append( geom );
+    } else if (parentItem.represents(kmlTag_MultiGeometry)) {
+        parentItem.nodeAs<GeoDataMultiGeometry>()->append(geom);
         return geom;
     } else {
         delete geom;
