@@ -17,20 +17,20 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( open )
+KML_DEFINE_TAG_HANDLER(open)
 
-GeoNode* KmlopenTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlopenTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_open)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_open)));
 
     GeoStackItem parentItem = parser.parentElement();
-    
-    if( parentItem.is<GeoDataFeature>() ) {
+
+    if (parentItem.is<GeoDataFeature>()) {
         QString open = parser.readElementText().trimmed();
-/*        if (open == QLatin1String("1"))
-            parentItem.nodeAs<GeoDataFeature>()->setOpen( true );
-        else
-            parentItem.nodeAs<GeoDataFeature>()->setOpen( false );*/
+        /*        if (open == QLatin1StringView("1"))
+                    parentItem.nodeAs<GeoDataFeature>()->setOpen( true );
+                else
+                    parentItem.nodeAs<GeoDataFeature>()->setOpen( false );*/
     }
 
     return nullptr;
