@@ -7,32 +7,31 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
-#include "KmlObjectTagHandler.h"
-#include "GeoDataOrientation.h"
 #include "GeoDataGeometry.h"
 #include "GeoDataModel.h"
+#include "GeoDataOrientation.h"
 #include "GeoDataParser.h"
+#include "KmlElementDictionary.h"
+#include "KmlObjectTagHandler.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( Orientation )
+KML_DEFINE_TAG_HANDLER(Orientation)
 
-GeoNode* KmlOrientationTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlOrientationTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Orientation)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_Orientation)));
 
     GeoDataOrientation orientation;
-    KmlObjectTagHandler::parseIdentifiers( parser, &orientation );
+    KmlObjectTagHandler::parseIdentifiers(parser, &orientation);
     GeoStackItem parentItem = parser.parentElement();
 
-    if( parentItem.represents( kmlTag_Model ) ) {
+    if (parentItem.represents(kmlTag_Model)) {
         parentItem.nodeAs<GeoDataModel>()->setOrientation(orientation);
         return &parentItem.nodeAs<GeoDataModel>()->orientation();
-    }
-    else{
+    } else {
         return nullptr;
     }
 }
