@@ -7,28 +7,28 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
-#include "KmlObjectTagHandler.h"
-#include "GeoDataScale.h"
 #include "GeoDataGeometry.h"
 #include "GeoDataModel.h"
 #include "GeoDataParser.h"
+#include "GeoDataScale.h"
+#include "KmlElementDictionary.h"
+#include "KmlObjectTagHandler.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( Scale )
+KML_DEFINE_TAG_HANDLER(Scale)
 
-GeoNode* KmlScaleTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlScaleTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Scale)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_Scale)));
 
     GeoDataScale scale;
-    KmlObjectTagHandler::parseIdentifiers( parser, &scale );
+    KmlObjectTagHandler::parseIdentifiers(parser, &scale);
     GeoStackItem parentItem = parser.parentElement();
 
-    if( parentItem.represents( kmlTag_Model ) ) {
+    if (parentItem.represents(kmlTag_Model)) {
         parentItem.nodeAs<GeoDataModel>()->setScale(scale);
         return &parentItem.nodeAs<GeoDataModel>()->scale();
     } else {
