@@ -5,27 +5,27 @@
 
 #include "KmlSnippetTagHandler.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataFeature.h"
 #include "GeoDataParser.h"
 #include "GeoDataSnippet.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( Snippet )
+KML_DEFINE_TAG_HANDLER(Snippet)
 
-GeoNode* KmlSnippetTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlSnippetTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Snippet)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_Snippet)));
 
     GeoStackItem parentItem = parser.parentElement();
-    if( parentItem.is<GeoDataFeature>() ) {
+    if (parentItem.is<GeoDataFeature>()) {
         QString text = parser.readElementText().trimmed();
-        int maxLines = parser.attribute( "maxLines" ).trimmed().toInt();
+        int maxLines = parser.attribute("maxLines").trimmed().toInt();
 
-        parentItem.nodeAs<GeoDataFeature>()->setSnippet( GeoDataSnippet(text, maxLines) );
+        parentItem.nodeAs<GeoDataFeature>()->setSnippet(GeoDataSnippet(text, maxLines));
     }
 
     return nullptr;
