@@ -7,27 +7,26 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
-#include "KmlColorTagHandler.h"
 #include "GeoDataBalloonStyle.h"
 #include "GeoDataParser.h"
+#include "KmlColorTagHandler.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( textColor )
+KML_DEFINE_TAG_HANDLER(textColor)
 
-GeoNode* KmltextColorTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmltextColorTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_textColor)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_textColor)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.represents( kmlTag_BalloonStyle ) )
-    {
-        QColor const color = KmlcolorTagHandler::parseColor( parser.readElementText().trimmed() );
-        parentItem.nodeAs<GeoDataBalloonStyle>()->setTextColor( color );
+    if (parentItem.represents(kmlTag_BalloonStyle)) {
+        QColor const color = KmlcolorTagHandler::parseColor(parser.readElementText().trimmed());
+        parentItem.nodeAs<GeoDataBalloonStyle>()->setTextColor(color);
     }
     return nullptr;
 }
