@@ -7,27 +7,26 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
 #include "GeoDataImagePyramid.h"
 #include "GeoDataParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( tileSize )
+KML_DEFINE_TAG_HANDLER(tileSize)
 
-GeoNode* KmltileSizeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmltileSizeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_tileSize)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_tileSize)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if (parentItem.represents( kmlTag_ImagePyramid ))
-    {
+    if (parentItem.represents(kmlTag_ImagePyramid)) {
         int tileSize = parser.readElementText().toInt();
 
-        parentItem.nodeAs<GeoDataImagePyramid>()->setTileSize( tileSize );
+        parentItem.nodeAs<GeoDataImagePyramid>()->setTileSize(tileSize);
     }
     return nullptr;
 }
