@@ -7,30 +7,30 @@
 
 #include "MarbleDebug.h"
 
+#include "GeoDataFeature.h"
+#include "GeoDataTimeSpan.h"
+#include "GeoParser.h"
 #include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
-#include "GeoDataTimeSpan.h"
-#include "GeoDataFeature.h"
-#include "GeoParser.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( TimeSpan )
+KML_DEFINE_TAG_HANDLER(TimeSpan)
 
-GeoNode* KmlTimeSpanTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlTimeSpanTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_TimeSpan)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_TimeSpan)));
 
     GeoStackItem parentItem = parser.parentElement();
-    if ( parentItem.is<GeoDataFeature>() ) {
+    if (parentItem.is<GeoDataFeature>()) {
         GeoDataTimeSpan timeSpan;
-        KmlObjectTagHandler::parseIdentifiers( parser, &timeSpan );
-        parentItem.nodeAs<GeoDataFeature>()->setTimeSpan( timeSpan );
+        KmlObjectTagHandler::parseIdentifiers(parser, &timeSpan);
+        parentItem.nodeAs<GeoDataFeature>()->setTimeSpan(timeSpan);
         return &parentItem.nodeAs<GeoDataFeature>()->timeSpan();
     }
-    
+
     return nullptr;
 }
 
