@@ -14,11 +14,11 @@ namespace Marble
 namespace kml
 {
 
-KML_DEFINE_TAG_HANDLER( viewFormat )
+KML_DEFINE_TAG_HANDLER(viewFormat)
 
-GeoNode* KmlviewFormatTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlviewFormatTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_viewFormat)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_viewFormat)));
 
     GeoStackItem parentItem = parser.parentElement();
     if (parentItem.represents(kmlTag_Link)) {
