@@ -14,26 +14,26 @@ namespace Marble
 namespace kml
 {
 
-KML_DEFINE_TAG_HANDLER( viewRefreshMode )
+KML_DEFINE_TAG_HANDLER(viewRefreshMode)
 
-GeoNode* KmlviewRefreshModeTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlviewRefreshModeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_viewRefreshMode)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_viewRefreshMode)));
 
     GeoStackItem parentItem = parser.parentElement();
-    if ( parentItem.is<GeoDataLink>() ) {
+    if (parentItem.is<GeoDataLink>()) {
         QString content = parser.readElementText().trimmed();
 
         GeoDataLink::ViewRefreshMode mode = GeoDataLink::Never;
-        if (content == QLatin1String("onStop")) {
+        if (content == QLatin1StringView("onStop")) {
             mode = GeoDataLink::OnStop;
-        } else if (content == QLatin1String("onRegion")) {
+        } else if (content == QLatin1StringView("onRegion")) {
             mode = GeoDataLink::OnRegion;
-        } else if (content == QLatin1String("onRequest")) {
+        } else if (content == QLatin1StringView("onRequest")) {
             mode = GeoDataLink::OnRequest;
         }
 
-        parentItem.nodeAs<GeoDataLink>()->setViewRefreshMode( mode );
+        parentItem.nodeAs<GeoDataLink>()->setViewRefreshMode(mode);
     }
 
     return nullptr;
