@@ -6,26 +6,26 @@
 #include "KmlWaitTagHandler.h"
 #include "KmlPlaylistTagHandler.h"
 
-#include "KmlElementDictionary.h"
-#include "KmlObjectTagHandler.h"
-#include "GeoParser.h"
 #include "GeoDataPlaylist.h"
 #include "GeoDataWait.h"
+#include "GeoParser.h"
+#include "KmlElementDictionary.h"
+#include "KmlObjectTagHandler.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER_GX22( Wait )
+KML_DEFINE_TAG_HANDLER_GX22(Wait)
 
-GeoNode* KmlWaitTagHandler::parse(GeoParser &parser) const
+GeoNode *KmlWaitTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Wait)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_Wait)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    GeoDataWait *wait = new GeoDataWait;
-    KmlObjectTagHandler::parseIdentifiers( parser, wait );
+    auto wait = new GeoDataWait;
+    KmlObjectTagHandler::parseIdentifiers(parser, wait);
 
     if (parentItem.is<GeoDataPlaylist>()) {
         parentItem.nodeAs<GeoDataPlaylist>()->addPrimitive(wait);
