@@ -7,26 +7,25 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
-#include "GeoParser.h"
 #include "GeoDataScale.h"
-
+#include "GeoParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( y )
+KML_DEFINE_TAG_HANDLER(y)
 
-GeoNode* KmlyTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlyTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_y)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_y)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.is<GeoDataScale>() ){
+    if (parentItem.is<GeoDataScale>()) {
         double y = parser.readElementText().trimmed().toDouble();
-	parentItem.nodeAs<GeoDataScale>()->setY( y );
+        parentItem.nodeAs<GeoDataScale>()->setY(y);
     }
     return nullptr;
 }
