@@ -7,26 +7,25 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
-#include "GeoParser.h"
 #include "GeoDataScale.h"
-
+#include "GeoParser.h"
+#include "KmlElementDictionary.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( z )
+KML_DEFINE_TAG_HANDLER(z)
 
-GeoNode* KmlzTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlzTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_z)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_z)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if ( parentItem.is<GeoDataScale>() ){
+    if (parentItem.is<GeoDataScale>()) {
         double z = parser.readElementText().trimmed().toDouble();
-    parentItem.nodeAs<GeoDataScale>()->setZ( z );
+        parentItem.nodeAs<GeoDataScale>()->setZ(z);
     }
     return nullptr;
 }
