@@ -4,17 +4,12 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
 // Own
 #include "GeoSceneParser.h"
 
-// Marble
-#include "MarbleDebug.h"
-
 // Geodata
 #include "GeoDocument.h"
 #include "GeoSceneDocument.h"
-#include "GeoTagHandler.h"
 
 // DGML support
 #include "DgmlElementDictionary.h"
@@ -34,23 +29,23 @@ GeoSceneParser::~GeoSceneParser()
 
 bool GeoSceneParser::isValidRootElement()
 {
-    switch ((GeoSceneSourceType) m_source) {
+    switch ((GeoSceneSourceType)m_source) {
     case GeoScene_DGML:
-        return isValidElement(dgml::dgmlTag_Dgml);
+        return isValidElement(QString::fromLatin1(dgml::dgmlTag_Dgml));
     default:
         Q_ASSERT(false);
         return false;
     }
 }
 
-bool GeoSceneParser::isValidElement(const QString& tagName) const
+bool GeoSceneParser::isValidElement(const QString &tagName) const
 {
     if (!GeoParser::isValidElement(tagName))
         return false;
 
-    switch ((GeoSceneSourceType) m_source) {
+    switch ((GeoSceneSourceType)m_source) {
     case GeoScene_DGML:
-        return (namespaceUri() == QLatin1String(dgml::dgmlTag_nameSpace20));
+        return (namespaceUri() == QLatin1StringView(dgml::dgmlTag_nameSpace20));
     default:
         break;
     }
@@ -60,17 +55,17 @@ bool GeoSceneParser::isValidElement(const QString& tagName) const
     return false;
 }
 
-GeoDocument* GeoSceneParser::createDocument() const
+GeoDocument *GeoSceneParser::createDocument() const
 {
     return new GeoSceneDocument;
 }
 
 // Global helper function for the tag handlers
-GeoSceneDocument* geoSceneDoc(GeoParser& parser)
+GeoSceneDocument *geoSceneDoc(GeoParser &parser)
 {
-    GeoDocument* document = parser.activeDocument();
+    GeoDocument *document = parser.activeDocument();
     Q_ASSERT(document->isGeoSceneDocument());
-    return static_cast<GeoSceneDocument*>(document);
+    return static_cast<GeoSceneDocument *>(document);
 }
 
 }
