@@ -29,7 +29,10 @@ class TileId;
 class GEODATA_EXPORT GeoSceneAbstractTileProjection
 {
 public:
-    enum Type { Equirectangular, Mercator };
+    enum Type {
+        Equirectangular,
+        Mercator
+    };
 
     /**
      * @brief Construct a new GeoSceneAbstractTileProjection.
@@ -76,7 +79,7 @@ public:
      *
      * @return range of tile indexes covering given geographical box at given zoom level
      */
-     virtual QRect tileIndexes(const GeoDataLatLonBox &latLonBox, int zoomLevel) const = 0;
+    virtual QRect tileIndexes(const GeoDataLatLonBox &latLonBox, int zoomLevel) const = 0;
 
     /**
      * @brief Get the boundary geo coordinates corresponding to a tile.
@@ -100,9 +103,9 @@ public:
      */
     GeoDataLatLonBox geoCoordinates(const TileId &tileId) const;
 
- private:
-     Q_DISABLE_COPY(GeoSceneAbstractTileProjection)
-     const QScopedPointer<GeoSceneAbstractTileProjectionPrivate> d_ptr;
+private:
+    Q_DISABLE_COPY(GeoSceneAbstractTileProjection)
+    const QScopedPointer<GeoSceneAbstractTileProjectionPrivate> d_ptr;
 };
 
 }
