@@ -10,8 +10,8 @@
 
 // Marble
 #include "GeoSceneHead.h"
-#include "GeoSceneMap.h"
 #include "GeoSceneLegend.h"
+#include "GeoSceneMap.h"
 #include "GeoSceneSettings.h"
 #include "GeoSceneTypes.h"
 
@@ -20,12 +20,12 @@ namespace Marble
 
 class GeoSceneDocumentPrivate
 {
-  public:
+public:
     GeoSceneDocumentPrivate()
-        : m_head(new GeoSceneHead),
-          m_map(new GeoSceneMap),
-          m_settings(new GeoSceneSettings),
-          m_legend(new GeoSceneLegend)
+        : m_head(new GeoSceneHead)
+        , m_map(new GeoSceneMap)
+        , m_settings(new GeoSceneSettings)
+        , m_legend(new GeoSceneLegend)
     {
     }
 
@@ -37,20 +37,18 @@ class GeoSceneDocumentPrivate
         delete m_legend;
     }
 
-    GeoSceneHead*     m_head;
-    GeoSceneMap*      m_map;
-    GeoSceneSettings* m_settings;
-    GeoSceneLegend*   m_legend;
+    GeoSceneHead *const m_head;
+    GeoSceneMap *const m_map;
+    GeoSceneSettings *const m_settings;
+    GeoSceneLegend *const m_legend;
 };
 
-
 GeoSceneDocument::GeoSceneDocument()
-    : GeoDocument(),
-      d( new GeoSceneDocumentPrivate )
+    : GeoDocument()
+    , d(new GeoSceneDocumentPrivate)
 {
     // Establish connection of property changes to the outside, e.g. the LegendBrowser
-    connect ( d->m_settings, SIGNAL(valueChanged(QString,bool)), 
-                          SIGNAL(valueChanged(QString,bool)) );
+    connect(d->m_settings, SIGNAL(valueChanged(QString, bool)), SIGNAL(valueChanged(QString, bool)));
 }
 
 GeoSceneDocument::~GeoSceneDocument()
@@ -58,47 +56,47 @@ GeoSceneDocument::~GeoSceneDocument()
     delete d;
 }
 
-const char* GeoSceneDocument::nodeType() const
+const char *GeoSceneDocument::nodeType() const
 {
     return GeoSceneTypes::GeoSceneDocumentType;
 }
 
-const GeoSceneHead* GeoSceneDocument::head() const
+const GeoSceneHead *GeoSceneDocument::head() const
 {
     return d->m_head;
 }
 
-GeoSceneHead* GeoSceneDocument::head()
+GeoSceneHead *GeoSceneDocument::head()
 {
     return d->m_head;
 }
 
-const GeoSceneMap* GeoSceneDocument::map() const
+const GeoSceneMap *GeoSceneDocument::map() const
 {
     return d->m_map;
 }
 
-GeoSceneMap* GeoSceneDocument::map()
+GeoSceneMap *GeoSceneDocument::map()
 {
     return d->m_map;
 }
 
-const GeoSceneSettings* GeoSceneDocument::settings() const
+const GeoSceneSettings *GeoSceneDocument::settings() const
 {
     return d->m_settings;
 }
 
-GeoSceneSettings* GeoSceneDocument::settings()
+GeoSceneSettings *GeoSceneDocument::settings()
 {
     return d->m_settings;
 }
 
-const GeoSceneLegend* GeoSceneDocument::legend() const
+const GeoSceneLegend *GeoSceneDocument::legend() const
 {
     return d->m_legend;
 }
 
-GeoSceneLegend* GeoSceneDocument::legend()
+GeoSceneLegend *GeoSceneDocument::legend()
 {
     return d->m_legend;
 }
