@@ -12,15 +12,15 @@
 namespace Marble
 {
 
-GeoSceneFilter::GeoSceneFilter( const QString& name )
-    : m_name( name ),
-      m_type( "none" )
+GeoSceneFilter::GeoSceneFilter(const QString &name)
+    : m_name(name)
+    , m_type(QStringLiteral("none"))
 {
 }
 
 GeoSceneFilter::~GeoSceneFilter()
 {
-   qDeleteAll( m_palette );
+    qDeleteAll(m_palette);
 }
 
 QString GeoSceneFilter::name() const
@@ -28,7 +28,7 @@ QString GeoSceneFilter::name() const
     return m_name;
 }
 
-void GeoSceneFilter::setName( const QString& name )
+void GeoSceneFilter::setName(const QString &name)
 {
     m_name = name;
 }
@@ -38,24 +38,24 @@ QString GeoSceneFilter::type() const
     return m_type;
 }
 
-void GeoSceneFilter::setType( const QString& type )
+void GeoSceneFilter::setType(const QString &type)
 {
     m_type = type;
 }
 
-QList<const GeoScenePalette*> GeoSceneFilter::palette() const
+QList<const GeoScenePalette *> GeoSceneFilter::palette() const
 {
     return m_palette;
 }
 
-void GeoSceneFilter::addPalette( const GeoScenePalette *palette )
+void GeoSceneFilter::addPalette(const GeoScenePalette *palette)
 {
-    m_palette.append( palette );
+    m_palette.append(palette);
 }
 
-int GeoSceneFilter::removePalette( const GeoScenePalette *palette )
+int GeoSceneFilter::removePalette(const GeoScenePalette *palette)
 {
-    return m_palette.removeAll( palette );
+    return m_palette.removeAll(palette);
 }
 
 const char *GeoSceneFilter::nodeType() const
