@@ -11,10 +11,9 @@
 namespace Marble
 {
 
-GeoScenePalette::GeoScenePalette( const QString& type,
-                                  const QString& file )
-    : m_type( type ),
-      m_file( file )
+GeoScenePalette::GeoScenePalette(const QString &type, const QString &file)
+    : m_type(type)
+    , m_file(file)
 {
 }
 
@@ -23,7 +22,7 @@ QString GeoScenePalette::type() const
     return m_type;
 }
 
-void GeoScenePalette::setType( const QString& type )
+void GeoScenePalette::setType(const QString &type)
 {
     m_type = type;
 }
@@ -33,12 +32,12 @@ QString GeoScenePalette::file() const
     return m_file;
 }
 
-void GeoScenePalette::setFile( const QString& file )
+void GeoScenePalette::setFile(const QString &file)
 {
     m_file = file;
 }
 
-bool GeoScenePalette::operator==( const GeoScenePalette& rhs ) const
+bool GeoScenePalette::operator==(const GeoScenePalette &rhs) const
 {
     return m_file == rhs.m_file && m_type == rhs.m_type;
 }
