@@ -7,9 +7,9 @@
 */
 
 #include "GeoSceneTileDataset.h"
-#include "GeoSceneTypes.h"
 #include "GeoSceneEquirectTileProjection.h"
 #include "GeoSceneMercatorTileProjection.h"
+#include "GeoSceneTypes.h"
 
 #include "DownloadPolicy.h"
 #include "MarbleDebug.h"
@@ -23,20 +23,20 @@
 namespace Marble
 {
 
-GeoSceneTileDataset::GeoSceneTileDataset( const QString& name )
-    : GeoSceneAbstractDataset( name ),
-      m_sourceDir(),
-      m_installMap(),
-      m_storageLayoutMode(Marble),
-      m_serverLayout( new MarbleServerLayout( this ) ),
-      m_levelZeroColumns( defaultLevelZeroColumns ),
-      m_levelZeroRows( defaultLevelZeroRows ),
-      m_minimumTileLevel(0),
-      m_maximumTileLevel( -1 ),
-      m_tileProjection(new GeoSceneEquirectTileProjection()),
-      m_blending(),
-      m_downloadUrls(),
-      m_nextUrl( m_downloadUrls.constEnd() )
+GeoSceneTileDataset::GeoSceneTileDataset(const QString &name)
+    : GeoSceneAbstractDataset(name)
+    , m_sourceDir()
+    , m_installMap()
+    , m_storageLayoutMode(Marble)
+    , m_serverLayout(new MarbleServerLayout(this))
+    , m_levelZeroColumns(defaultLevelZeroColumns)
+    , m_levelZeroRows(defaultLevelZeroRows)
+    , m_minimumTileLevel(0)
+    , m_maximumTileLevel(-1)
+    , m_tileProjection(new GeoSceneEquirectTileProjection())
+    , m_blending()
+    , m_downloadUrls()
+    , m_nextUrl(m_downloadUrls.constEnd())
 {
     m_tileProjection->setLevelZeroColumns(m_levelZeroColumns);
     m_tileProjection->setLevelZeroRows(m_levelZeroRows);
@@ -44,12 +44,12 @@ GeoSceneTileDataset::GeoSceneTileDataset( const QString& name )
 
 GeoSceneTileDataset::~GeoSceneTileDataset()
 {
-    qDeleteAll( m_downloadPolicies );
+    qDeleteAll(m_downloadPolicies);
     delete m_serverLayout;
     delete m_tileProjection;
 }
 
-const char* GeoSceneTileDataset::nodeType() const
+const char *GeoSceneTileDataset::nodeType() const
 {
     return GeoSceneTypes::GeoSceneTileDatasetType;
 }
@@ -59,7 +59,7 @@ QString GeoSceneTileDataset::sourceDir() const
     return m_sourceDir;
 }
 
-void GeoSceneTileDataset::setSourceDir( const QString& sourceDir )
+void GeoSceneTileDataset::setSourceDir(const QString &sourceDir)
 {
     m_sourceDir = sourceDir;
 }
@@ -69,7 +69,7 @@ QString GeoSceneTileDataset::installMap() const
     return m_installMap;
 }
 
-void GeoSceneTileDataset::setInstallMap( const QString& installMap )
+void GeoSceneTileDataset::setInstallMap(const QString &installMap)
 {
     m_installMap = installMap;
 }
@@ -79,28 +79,28 @@ GeoSceneTileDataset::StorageLayout GeoSceneTileDataset::storageLayout() const
     return m_storageLayoutMode;
 }
 
-void GeoSceneTileDataset::setStorageLayout( const StorageLayout layout )
+void GeoSceneTileDataset::setStorageLayout(const StorageLayout layout)
 {
     m_storageLayoutMode = layout;
 }
 
-void GeoSceneTileDataset::setServerLayout( const ServerLayout *layout )
+void GeoSceneTileDataset::setServerLayout(const ServerLayout *layout)
 {
     delete m_serverLayout;
     m_serverLayout = layout;
 }
 
-const ServerLayout* GeoSceneTileDataset::serverLayout() const
+const ServerLayout *GeoSceneTileDataset::serverLayout() const
 {
     return m_serverLayout;
 }
 
 int GeoSceneTileDataset::levelZeroColumns() const
 {
-   return m_levelZeroColumns;
+    return m_levelZeroColumns;
 }
 
-void GeoSceneTileDataset::setLevelZeroColumns( const int columns )
+void GeoSceneTileDataset::setLevelZeroColumns(const int columns)
 {
     m_levelZeroColumns = columns;
     m_tileProjection->setLevelZeroColumns(m_levelZeroColumns);
@@ -111,7 +111,7 @@ int GeoSceneTileDataset::levelZeroRows() const
     return m_levelZeroRows;
 }
 
-void GeoSceneTileDataset::setLevelZeroRows( const int rows )
+void GeoSceneTileDataset::setLevelZeroRows(const int rows)
 {
     m_levelZeroRows = rows;
     m_tileProjection->setLevelZeroRows(m_levelZeroRows);
@@ -122,7 +122,7 @@ int GeoSceneTileDataset::maximumTileLevel() const
     return m_maximumTileLevel;
 }
 
-void GeoSceneTileDataset::setMaximumTileLevel( const int maximumTileLevel )
+void GeoSceneTileDataset::setMaximumTileLevel(const int maximumTileLevel)
 {
     m_maximumTileLevel = maximumTileLevel;
 }
@@ -145,7 +145,7 @@ void GeoSceneTileDataset::setTileLevels(const QString &tileLevels)
     }
 
     const QStringList values = tileLevels.split(QLatin1Char(','));
-    for(const QString &value: values) {
+    for (const QString &value : values) {
         bool canParse(false);
         int const tileLevel = value.trimmed().toInt(&canParse);
         if (canParse && tileLevel >= 0 && tileLevel < 100) {
@@ -162,47 +162,57 @@ void GeoSceneTileDataset::setTileLevels(const QString &tileLevels)
     }
 }
 
-QVector<int> GeoSceneTileDataset::tileLevels() const
+QList<int> GeoSceneTileDataset::tileLevels() const
 {
     return m_tileLevels;
 }
 
-QVector<QUrl> GeoSceneTileDataset::downloadUrls() const
+QList<QUrl> GeoSceneTileDataset::downloadUrls() const
 {
     return m_downloadUrls;
 }
 
 const QSize GeoSceneTileDataset::tileSize() const
 {
-    if ( m_tileSize.isEmpty() ) {
-        const TileId id( 0, 0, 0, 0 );
-        QString const fileName = relativeTileFileName( id );
-        QFileInfo const dirInfo( fileName );
-        QString const path = dirInfo.isAbsolute() ? fileName : MarbleDirs::path( fileName );
+    if (m_tileSize.isEmpty()) {
+        const TileId id(0, 0, 0, 0);
+        QString const fileName = relativeTileFileName(id);
+        QFileInfo const dirInfo(fileName);
+        QString const path = dirInfo.isAbsolute() ? fileName : MarbleDirs::path(fileName);
 
-        QImage testTile( path );
+        QImage testTile(path);
 
-        if ( testTile.isNull() ) {
+        if (testTile.isNull()) {
             mDebug() << "Tile size is missing in dgml and no base tile found in " << themeStr();
             mDebug() << "Using default tile size " << c_defaultTileSize;
-            m_tileSize = QSize( c_defaultTileSize, c_defaultTileSize );
+            m_tileSize = QSize(c_defaultTileSize, c_defaultTileSize);
         } else {
             m_tileSize = testTile.size();
         }
 
-        if ( m_tileSize.isEmpty() ) {
+        if (m_tileSize.isEmpty()) {
             mDebug() << "Tile width or height cannot be 0. Falling back to default tile size.";
-            m_tileSize = QSize( c_defaultTileSize, c_defaultTileSize );
+            m_tileSize = QSize(c_defaultTileSize, c_defaultTileSize);
         }
     }
 
-    Q_ASSERT( !m_tileSize.isEmpty() );
+    Q_ASSERT(!m_tileSize.isEmpty());
     return m_tileSize;
 }
 
-void GeoSceneTileDataset::setTileSize( const QSize &tileSize )
+GeoDataLatLonBox GeoSceneTileDataset::latLonBox() const
 {
-    if ( tileSize.isEmpty() ) {
+    return m_latLonBox;
+}
+
+void GeoSceneTileDataset::setLatLonBox(const GeoDataLatLonBox &box)
+{
+    m_latLonBox = box;
+}
+
+void GeoSceneTileDataset::setTileSize(const QSize &tileSize)
+{
+    if (tileSize.isEmpty()) {
         mDebug() << "Ignoring invalid tile size " << tileSize;
     } else {
         m_tileSize = tileSize;
@@ -226,7 +236,7 @@ void GeoSceneTileDataset::setTileProjection(GeoSceneAbstractTileProjection::Type
     m_tileProjection->setLevelZeroRows(m_levelZeroRows);
 }
 
-const GeoSceneAbstractTileProjection * GeoSceneTileDataset::tileProjection() const
+const GeoSceneAbstractTileProjection *GeoSceneTileDataset::tileProjection() const
 {
     return m_tileProjection;
 }
@@ -238,13 +248,12 @@ GeoSceneAbstractTileProjection::Type GeoSceneTileDataset::tileProjectionType() c
 
 // Even though this method changes the internal state, it may be const
 // because the compiler is forced to invoke this method for different TileIds.
-QUrl GeoSceneTileDataset::downloadUrl( const TileId &id ) const
+QUrl GeoSceneTileDataset::downloadUrl(const TileId &id) const
 {
     // default download url
-    if ( m_downloadUrls.empty() ) {
-        QUrl const defaultUrl = QUrl(QLatin1String("https://maps.kde.org/") + m_serverLayout->sourceDir());
-        mDebug() << "No download URL specified for tiles stored in "
-                 << m_sourceDir << ", falling back to " << defaultUrl.toString();
+    if (m_downloadUrls.empty()) {
+        QUrl const defaultUrl = QUrl(QLatin1StringView("https://maps.kde.org/") + m_serverLayout->sourceDir());
+        mDebug() << "No download URL specified for tiles stored in " << m_sourceDir << ", falling back to " << defaultUrl.toString();
         return m_serverLayout->downloadUrl(defaultUrl, id);
     } else if (m_downloadUrls.size() == 1) {
         return m_serverLayout->downloadUrl(*m_nextUrl, id);
@@ -258,43 +267,38 @@ QUrl GeoSceneTileDataset::downloadUrl( const TileId &id ) const
     }
 }
 
-void GeoSceneTileDataset::addDownloadUrl( const QUrl & url )
+void GeoSceneTileDataset::addDownloadUrl(const QUrl &url)
 {
-    m_downloadUrls.append( url );
+    m_downloadUrls.append(url);
     // FIXME: this could be done only once
     m_nextUrl = m_downloadUrls.constBegin();
 }
 
-QString GeoSceneTileDataset::relativeTileFileName( const TileId &id ) const
+QString GeoSceneTileDataset::relativeTileFileName(const TileId &id) const
 {
     const QString suffix = fileFormat().toLower();
 
     QString relFileName;
 
-    switch ( m_storageLayoutMode ) {
+    switch (m_storageLayoutMode) {
     case GeoSceneTileDataset::Marble:
-        relFileName = QString( "%1/%2/%3/%3_%4.%5" )
-            .arg( themeStr() )
-            .arg( id.zoomLevel() )
-            .arg(id.y(), tileDigits, 10, QLatin1Char('0'))
-            .arg(id.x(), tileDigits, 10, QLatin1Char('0'))
-            .arg( suffix );
+        relFileName = QStringLiteral("%1/%2/%3/%3_%4.%5")
+                          .arg(themeStr())
+                          .arg(id.zoomLevel())
+                          .arg(id.y(), tileDigits, 10, QLatin1Char('0'))
+                          .arg(id.x(), tileDigits, 10, QLatin1Char('0'))
+                          .arg(suffix);
         break;
     case GeoSceneTileDataset::OpenStreetMap:
-        relFileName = QString( "%1/%2/%3/%4.%5" )
-            .arg( themeStr() )
-            .arg( id.zoomLevel() )
-            .arg( id.x() )
-            .arg( id.y() )
-            .arg( suffix );
+        relFileName = QStringLiteral("%1/%2/%3/%4.%5").arg(themeStr()).arg(id.zoomLevel()).arg(id.x()).arg(id.y()).arg(suffix);
         break;
     case GeoSceneTileDataset::TileMapService:
-        relFileName = QString( "%1/%2/%3/%4.%5" )
-            .arg( themeStr() )
-            .arg( id.zoomLevel() )
-            .arg( id.x() )
-            .arg( ( 1<<id.zoomLevel() ) - id.y() - 1 )  //Y coord in TMS runs from bottom to top
-            .arg( suffix );
+        relFileName = QStringLiteral("%1/%2/%3/%4.%5")
+                          .arg(themeStr())
+                          .arg(id.zoomLevel())
+                          .arg(id.x())
+                          .arg((1 << id.zoomLevel()) - id.y() - 1) // Y coord in TMS runs from bottom to top
+                          .arg(suffix);
         break;
     }
 
@@ -303,8 +307,8 @@ QString GeoSceneTileDataset::relativeTileFileName( const TileId &id ) const
 
 QString GeoSceneTileDataset::themeStr() const
 {
-    QFileInfo const dirInfo( sourceDir() );
-    return dirInfo.isAbsolute() ? sourceDir() : QLatin1String("maps/") + sourceDir();
+    QFileInfo const dirInfo(sourceDir());
+    return dirInfo.isAbsolute() ? sourceDir() : QLatin1StringView("maps/") + sourceDir();
 }
 
 QList<const DownloadPolicy *> GeoSceneTileDataset::downloadPolicies() const
@@ -312,11 +316,11 @@ QList<const DownloadPolicy *> GeoSceneTileDataset::downloadPolicies() const
     return m_downloadPolicies;
 }
 
-void GeoSceneTileDataset::addDownloadPolicy( const DownloadUsage usage, const int maximumConnections )
+void GeoSceneTileDataset::addDownloadPolicy(const DownloadUsage usage, const int maximumConnections)
 {
-    DownloadPolicy * const policy = new DownloadPolicy( DownloadPolicyKey( hostNames(), usage ));
-    policy->setMaximumConnections( maximumConnections );
-    m_downloadPolicies.append( policy );
+    auto const policy = new DownloadPolicy(DownloadPolicyKey(hostNames(), usage));
+    policy->setMaximumConnections(maximumConnections);
+    m_downloadPolicies.append(policy);
     mDebug() << "added download policy" << hostNames() << usage << maximumConnections;
 }
 
@@ -325,10 +329,10 @@ QStringList GeoSceneTileDataset::hostNames() const
     QStringList result;
     result.reserve(m_downloadUrls.size());
 
-    QVector<QUrl>::const_iterator pos = m_downloadUrls.constBegin();
-    QVector<QUrl>::const_iterator const end = m_downloadUrls.constEnd();
-    for (; pos != end; ++pos )
-        result.append( (*pos).host() );
+    QList<QUrl>::const_iterator pos = m_downloadUrls.constBegin();
+    QList<QUrl>::const_iterator const end = m_downloadUrls.constEnd();
+    for (; pos != end; ++pos)
+        result.append((*pos).host());
     return result;
 }
 
