@@ -28,7 +28,7 @@ public:
      * @param document A GeoDataDocument with content to write
      * @return True if the content is successfully written to the device, false otherwise
      */
-    virtual bool write(QIODevice* device, const GeoDataDocument &document) = 0;
+    virtual bool write(QIODevice *device, const GeoDataDocument &document) = 0;
 };
 
 /**
@@ -37,17 +37,16 @@ public:
 class MARBLE_EXPORT GeoWriterBackendRegistrar
 {
 public:
-    GeoWriterBackendRegistrar(GeoWriterBackend* writer, const QString &fileExtension);
+    GeoWriterBackendRegistrar(GeoWriterBackend *writer, const QString &fileExtension);
     ~GeoWriterBackendRegistrar();
 
 private:
-    GeoWriterBackend* m_writer;
+    GeoWriterBackend *m_writer;
     QString m_fileExtension;
 };
 
 #ifndef STATIC_BUILD
-#define MARBLE_ADD_WRITER(Class, fileExtension) \
-    static GeoWriterBackendRegistrar s_##Class##Registrar(new Class, fileExtension);
+#define MARBLE_ADD_WRITER(Class, fileExtension) static GeoWriterBackendRegistrar s_##Class##Registrar(new Class, fileExtension);
 #else
 #define MARBLE_ADD_WRITER(Class, fileExtension)
 #endif
