@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2009      Bastian Holst <bastianholst@gmx.de>
+// SPDX-FileCopyrightText: 2009 Bastian Holst <bastianholst@gmx.de>
 //
 
 #ifndef MARBLE_MARBLEGRAPHICSITEM_H
@@ -13,6 +8,8 @@
 
 #include "marble_export.h"
 
+#include <QtGlobal>
+
 class QEvent;
 class QObject;
 class QPainter;
@@ -30,9 +27,7 @@ class MarbleGraphicsItemPrivate;
 
 class MARBLE_EXPORT MarbleGraphicsItem
 {
-    friend class MarbleGraphicsItemPrivate;
-
- public:
+public:
     enum CacheMode {
         NoCache,
         ItemCoordinateCache,
@@ -45,12 +40,12 @@ class MARBLE_EXPORT MarbleGraphicsItem
      * Paints the item on the screen in view coordinates.
      * It is not safe to call this function from a thread other than the gui thread.
      */
-    bool paintEvent( QPainter *painter, const ViewportParams *viewport );
+    bool paintEvent(QPainter *painter, const ViewportParams *viewport);
 
     /**
      * Returns true if the Item contains @p point in parent coordinates.
      */
-    bool contains( const QPointF& point ) const;
+    bool contains(const QPointF &point) const;
 
     /**
      * Returns the layout of the MarbleGraphicsItem.
@@ -61,7 +56,7 @@ class MARBLE_EXPORT MarbleGraphicsItem
      * Set the layout of the graphics item. The layout will now handle positions of added child
      * items. The MarbleGraphicsItem takes ownership of the layout.
      */
-    void setLayout( AbstractMarbleGraphicsLayout *layout );
+    void setLayout(AbstractMarbleGraphicsLayout *layout);
 
     /**
      * Returns the cache mode of the item
@@ -71,7 +66,7 @@ class MARBLE_EXPORT MarbleGraphicsItem
     /**
      * Set the cache mode of the item
      */
-    void setCacheMode( CacheMode mode );
+    void setCacheMode(CacheMode mode);
 
     /**
      * Returns if the item is visible.
@@ -81,7 +76,7 @@ class MARBLE_EXPORT MarbleGraphicsItem
     /**
      * Makes the item visible or invisible, depending on @p visible.
      */
-    void setVisible( bool visible );
+    void setVisible(bool visible);
 
     /**
      * Hides the item. Equivalent to setVisible( false )
@@ -101,7 +96,7 @@ class MARBLE_EXPORT MarbleGraphicsItem
     /**
      * Set the size of the item
      */
-    void setSize( const QSizeF& size );
+    void setSize(const QSizeF &size);
 
     /**
      * Returns the size of the content of the MarbleGraphicsItem.
@@ -112,25 +107,25 @@ class MARBLE_EXPORT MarbleGraphicsItem
     /**
      * Set the size of the content of the item.
      */
-    virtual void setContentSize( const QSizeF& size );
+    virtual void setContentSize(const QSizeF &size);
 
     /**
      * Returns the rect of the content in item coordinates.
      */
     virtual QRectF contentRect() const;
 
-    virtual void setProjection(const ViewportParams *viewport );
+    virtual void setProjection(const ViewportParams *viewport);
 
- protected:
-    explicit MarbleGraphicsItem( MarbleGraphicsItemPrivate *d_ptr );
+protected:
+    explicit MarbleGraphicsItem(MarbleGraphicsItemPrivate *dd);
 
     /**
      * Paints the item in item coordinates. This has to be reimplemented by the subclass
      * This function will be called by paintEvent().
      */
-    virtual void paint( QPainter *painter );
+    virtual void paint(QPainter *painter);
 
-    virtual bool eventFilter( QObject *object, QEvent *e );
+    virtual bool eventFilter(QObject *object, QEvent *e);
 
     /**
      * Marks the item and all parent items as invalid. If caching is enabled, the next paintEvent()
@@ -138,11 +133,12 @@ class MARBLE_EXPORT MarbleGraphicsItem
      */
     void update();
 
-    MarbleGraphicsItemPrivate * const d;
+protected:
+    MarbleGraphicsItemPrivate *const d_ptr;
 
- private:
-    MarbleGraphicsItemPrivate* p();
-    const MarbleGraphicsItemPrivate* p() const;
+private:
+    Q_DISABLE_COPY(MarbleGraphicsItem)
+    Q_DECLARE_PRIVATE(MarbleGraphicsItem)
 };
 
 } // Namespace Marble
