@@ -21,12 +21,13 @@ class FogLayer : public LayerInterface
 public:
     QStringList renderPosition() const override;
 
-    bool render( GeoPainter *painter, ViewportParams *viewport,
-                         const QString& renderPos = QLatin1String("NONE"),
-                         GeoSceneLayer * layer = nullptr ) override;
+    bool render(GeoPainter *painter, ViewportParams *viewport, const QString &renderPos = QLatin1String("NONE"), GeoSceneLayer *layer = nullptr) override;
 
     RenderState renderState() const override;
-    QString runtimeTrace() const override { return QStringLiteral("FogLayer"); }
+    QString runtimeTrace() const override
+    {
+        return QStringLiteral("FogLayer");
+    }
 };
 
 }
