@@ -9,8 +9,9 @@
 namespace Marble
 {
 
-RoutingProfile::RoutingProfile( const QString &name ) :
-    m_name( name ), m_transportType( Motorcar )
+RoutingProfile::RoutingProfile(const QString &name)
+    : m_name(name)
+    , m_transportType(Motorcar)
 {
     // nothing to do
 }
@@ -20,22 +21,22 @@ QString RoutingProfile::name() const
     return m_name;
 }
 
-void RoutingProfile::setName( const QString &name )
+void RoutingProfile::setName(const QString &name)
 {
     m_name = name;
 }
 
-const QHash<QString, QHash<QString, QVariant> >& RoutingProfile::pluginSettings() const
+const QHash<QString, QHash<QString, QVariant>> &RoutingProfile::pluginSettings() const
 {
     return m_pluginSettings;
 }
 
-QHash<QString, QHash<QString, QVariant> >& RoutingProfile::pluginSettings()
+QHash<QString, QHash<QString, QVariant>> &RoutingProfile::pluginSettings()
 {
     return m_pluginSettings;
 }
 
-void RoutingProfile::setTransportType( RoutingProfile::TransportType transportType )
+void RoutingProfile::setTransportType(RoutingProfile::TransportType transportType)
 {
     m_transportType = transportType;
 }
@@ -45,7 +46,7 @@ RoutingProfile::TransportType RoutingProfile::transportType() const
     return m_transportType;
 }
 
-bool RoutingProfile::operator==( const RoutingProfile &other ) const
+bool RoutingProfile::operator==(const RoutingProfile &other) const
 {
     return m_name == other.name() && m_pluginSettings == other.pluginSettings();
 }
