@@ -8,11 +8,9 @@
 
 #include <QFlags>
 
-
-
 namespace GeoCute
 {
-    
+
 enum VelocityFieldFlag {
     VelocityFieldsNone = 0,
     VelocityFieldsSpeed = 1 << 0,
@@ -23,16 +21,13 @@ enum VelocityFieldFlag {
 Q_DECLARE_FLAGS(VelocityFields, VelocityFieldFlag)
 Q_DECLARE_OPERATORS_FOR_FLAGS(VelocityFields)
 
-struct Velocity
-{
+struct Velocity {
     VelocityFields fields;
     qreal speed;
     qreal direction;
     qreal climb;
 };
-    
+
 }
 
-
-
 #endif
