@@ -8,29 +8,24 @@
 
 #include "VelocityProvider.h"
 
-#include <QString>
 #include <QDBusMessage>
+#include <QString>
 
 #include "SimpleDBusInterface.h"
 
-
-
 static const QString interfaceName = "org.freedesktop.Geoclue.Velocity";
 
 class GeoCute::VelocityProvider::Private
 {
-    public:
-        Private(VelocityProvider& parent, const QString& service,
-            const QString& path);
-        void velocityChangedCall(QDBusMessage message);
-        
-        SimpleDBusInterface interface;
-        Velocity currentVelocity;
-        
-    private:
-        VelocityProvider& parent;
+public:
+    Private(VelocityProvider &parent, const QString &service, const QString &path);
+    void velocityChangedCall(QDBusMessage message);
+
+    SimpleDBusInterface interface;
+    Velocity currentVelocity;
+
+private:
+    VelocityProvider &parent;
 };
 
-
-
 #endif
