@@ -11,8 +11,8 @@
 
 #include "GeoDataCoordinates.h"
 
-
-namespace Marble {
+namespace Marble
+{
 
 class AreaAnnotation;
 class GeoDataLinearRing;
@@ -22,7 +22,7 @@ class MergingPolygonNodesAnimation : public QObject
     Q_OBJECT
 
 public:
-    explicit MergingPolygonNodesAnimation( AreaAnnotation *polygon );
+    explicit MergingPolygonNodesAnimation(AreaAnnotation *polygon);
     ~MergingPolygonNodesAnimation() override;
 
     enum NodesBoundary {
@@ -49,11 +49,11 @@ private:
     const int second_i;
     const int second_j;
 
-    QTimer         *m_timer;
-    NodesBoundary   m_boundary;
+    QTimer *const m_timer;
+    NodesBoundary m_boundary;
 
     GeoDataLinearRing &outerRing;
-    QVector<GeoDataLinearRing> &innerRings;
+    QList<GeoDataLinearRing> &innerRings;
 
     GeoDataCoordinates m_firstInitialCoords;
     GeoDataCoordinates m_secondInitialCoords;
