@@ -13,7 +13,7 @@
 
 namespace Ui
 {
-    class EarthquakeConfigWidget;
+class EarthquakeConfigWidget;
 }
 
 namespace Marble
@@ -24,15 +24,16 @@ class EarthquakePlugin : public AbstractDataPlugin, public DialogConfigurationIn
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.kde.marble.EarthquakePlugin")
 
-    Q_INTERFACES( Marble::RenderPluginInterface )
-    Q_INTERFACES( Marble::DialogConfigurationInterface )
+    Q_INTERFACES(Marble::RenderPluginInterface)
+    Q_INTERFACES(Marble::DialogConfigurationInterface)
 
-    MARBLE_PLUGIN( EarthquakePlugin )
+    MARBLE_PLUGIN(EarthquakePlugin)
 
 public:
     EarthquakePlugin();
 
-    explicit EarthquakePlugin( const MarbleModel *marbleModel );
+    explicit EarthquakePlugin(const MarbleModel *marbleModel);
+    ~EarthquakePlugin() override;
 
     void initialize() override;
 
@@ -48,7 +49,7 @@ public:
 
     QString copyrightYears() const override;
 
-    QVector<PluginAuthor> pluginAuthors() const override;
+    QList<PluginAuthor> pluginAuthors() const override;
 
     QIcon icon() const override;
 
@@ -57,12 +58,12 @@ public:
     /**
      * @return: The settings of the item.
      */
-    QHash<QString,QVariant> settings() const override;
+    QHash<QString, QVariant> settings() const override;
 
     /**
      * Set the settings of the item.
      */
-    void setSettings( const QHash<QString,QVariant> &settings ) override;
+    void setSettings(const QHash<QString, QVariant> &settings) override;
 
 public Q_SLOTS:
     void readSettings();
@@ -70,8 +71,8 @@ public Q_SLOTS:
     void updateModel();
 
 private:
-    Ui::EarthquakeConfigWidget *m_ui;
-    QDialog *m_configDialog;
+    Ui::EarthquakeConfigWidget *m_ui = nullptr;
+    QDialog *m_configDialog = nullptr;
     qreal m_minMagnitude;
     QDateTime m_startDate;
     QDateTime m_endDate;
@@ -79,7 +80,7 @@ private:
     bool m_timeRangeNPastDays;
     int m_numResults;
     int m_maximumNumberOfItems;
-    
+
 private Q_SLOTS:
     void validateDateRange();
 };
