@@ -15,7 +15,7 @@
 
 namespace Ui
 {
-    class Navigation;
+class Navigation;
 }
 
 namespace Marble
@@ -28,17 +28,17 @@ class WidgetGraphicsItem;
  * @short Provides a float item with zoom and move controls
  *
  */
-class NavigationFloatItem: public AbstractFloatItem
+class NavigationFloatItem : public AbstractFloatItem
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.kde.marble.NavigationFloatItem")
 
-    Q_INTERFACES( Marble::RenderPluginInterface )
+    Q_INTERFACES(Marble::RenderPluginInterface)
 
-MARBLE_PLUGIN( NavigationFloatItem )
+    MARBLE_PLUGIN(NavigationFloatItem)
 
- public:
-    explicit NavigationFloatItem( const MarbleModel *marbleModel = nullptr );
+public:
+    explicit NavigationFloatItem(const MarbleModel *marbleModel = nullptr);
     ~NavigationFloatItem() override;
 
     QStringList backendTypes() const override;
@@ -55,48 +55,48 @@ MARBLE_PLUGIN( NavigationFloatItem )
 
     QString copyrightYears() const override;
 
-    QVector<PluginAuthor> pluginAuthors() const override;
+    QList<PluginAuthor> pluginAuthors() const override;
 
-    QIcon icon () const override;
+    QIcon icon() const override;
 
-    void initialize () override;
+    void initialize() override;
 
-    bool isInitialized () const override;
+    bool isInitialized() const override;
 
-    void setProjection( const ViewportParams *viewport ) override;
+    void setProjection(const ViewportParams *viewport) override;
 
-    static QPixmap pixmap( const QString &Id );
+    static QPixmap pixmap(const QString &Id);
 
-    QHash<QString,QVariant> settings() const override;
+    QHash<QString, QVariant> settings() const override;
 
-    void setSettings( const QHash<QString, QVariant> &settings ) override;
+    void setSettings(const QHash<QString, QVariant> &settings) override;
 
- protected:
-    bool eventFilter( QObject *object, QEvent *e ) override;
-    void paintContent( QPainter *painter ) override;
-    void contextMenuEvent( QWidget *w, QContextMenuEvent *e ) override;
+protected:
+    bool eventFilter(QObject *object, QEvent *e) override;
+    void paintContent(QPainter *painter) override;
+    void contextMenuEvent(QWidget *w, QContextMenuEvent *e) override;
 
- private Q_SLOTS:
+private Q_SLOTS:
     /** Map theme was changed, adjust controls */
-    void selectTheme( const QString& theme );
+    void selectTheme(const QString &theme);
 
     /** Enable/disable zoom in/out buttons */
-    void updateButtons( int zoomValue );
+    void updateButtons(int zoomValue);
 
     void activateCurrentPositionButton();
     void activateHomeButton();
     void centerOnCurrentLocation();
 
- private:
+private:
     /** MarbleWidget this float item is installed as event filter for */
-    MarbleWidget *m_marbleWidget;
+    MarbleWidget *m_marbleWidget = nullptr;
 
     /** The GraphicsItem presenting the widgets. NavigationFloatItem doesn't take direct ownership
         of this */
-    WidgetGraphicsItem *m_widgetItem;
+    WidgetGraphicsItem *m_widgetItem = nullptr;
 
     /** Navigation controls */
-    Ui::Navigation *m_navigationWidget;
+    Ui::Navigation *m_navigationWidget = nullptr;
 
     /** Used Profile */
     MarbleGlobal::Profiles m_profiles;
@@ -107,9 +107,9 @@ MARBLE_PLUGIN( NavigationFloatItem )
     int m_maxZoom;
     int m_minZoom;
 
-    QMenu *m_contextMenu;
-    QAction *m_activateCurrentPositionButtonAction;
-    QAction *m_activateHomeButtonAction;
+    QMenu *m_contextMenu = nullptr;
+    QAction *m_activateCurrentPositionButtonAction = nullptr;
+    QAction *m_activateHomeButtonAction = nullptr;
 
     bool m_showHomeButton;
 };
