@@ -15,7 +15,7 @@ class QFont;
 
 namespace Ui
 {
-    class OpenCachingCacheDialog;
+class OpenCachingCacheDialog;
 }
 
 namespace Marble
@@ -29,7 +29,7 @@ class OpenCachingItem : public AbstractDataPluginItem
     Q_OBJECT
 
 public:
-    OpenCachingItem( const OpenCachingCache& cache, QObject *parent );
+    OpenCachingItem(const OpenCachingCache &cache, QObject *parent);
 
     ~OpenCachingItem();
 
@@ -40,12 +40,11 @@ public:
     bool initialized();
 
     // Here the item gets painted
-    void paint( GeoPainter *painter, ViewportParams *viewport,
-                const QString& renderPos, GeoSceneLayer * layer = 0 );
+    void paint(GeoPainter *painter, ViewportParams *viewport, const QString &renderPos, GeoSceneLayer *layer = 0);
 
     QAction *action();
 
-    bool operator<( const AbstractDataPluginItem *other ) const;
+    bool operator<(const AbstractDataPluginItem *other) const;
 
 public Q_SLOTS:
     void showInfoDialog();
@@ -55,23 +54,23 @@ private:
 
     QDialog *infoDialog();
 
-    OpenCachingCache m_cache;                             ///< Information about the cache.
+    OpenCachingCache m_cache; ///< Information about the cache.
 
-    Ui::OpenCachingCacheDialog *m_ui;                     ///< Dialog displaying information about the cache.
+    Ui::OpenCachingCacheDialog *m_ui; ///< Dialog displaying information about the cache.
     QDialog *m_infoDialog;
     QAction *m_action;
 
-    int m_logIndex;                                       ///< Index of the currently displayed log entry.
+    int m_logIndex; ///< Index of the currently displayed log entry.
 
     static QFont s_font;
     static QPixmap s_icon;
 
 private Q_SLOTS:
-    void updateDescriptionLanguage( const QString& language );
+    void updateDescriptionLanguage(const QString &language);
 
-    void nextLogEntry();                                  ///< Display next log entry.
+    void nextLogEntry(); ///< Display next log entry.
 
-    void previousLogEntry();                              ///< Display previous log entry.
+    void previousLogEntry(); ///< Display previous log entry.
 };
 
 }
