@@ -13,7 +13,7 @@
 
 namespace Ui
 {
-    class PhotoConfigWidget;
+class PhotoConfigWidget;
 }
 
 namespace Marble
@@ -23,32 +23,32 @@ class PhotoPlugin : public AbstractDataPlugin, public DialogConfigurationInterfa
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.kde.marble.PhotoPlugin")
-    Q_INTERFACES( Marble::RenderPluginInterface )
-    Q_INTERFACES( Marble::DialogConfigurationInterface )
-    MARBLE_PLUGIN( PhotoPlugin )
-    
- public:
+    Q_INTERFACES(Marble::RenderPluginInterface)
+    Q_INTERFACES(Marble::DialogConfigurationInterface)
+    MARBLE_PLUGIN(PhotoPlugin)
+
+public:
     PhotoPlugin();
 
-    explicit PhotoPlugin( const MarbleModel *marbleModel );
+    explicit PhotoPlugin(const MarbleModel *marbleModel);
 
     ~PhotoPlugin() override;
 
     void initialize() override;
 
     QString name() const override;
-    
+
     QString guiString() const override;
 
     QString nameId() const override;
-    
+
     QString version() const override;
 
     QString description() const override;
 
     QString copyrightYears() const override;
 
-    QVector<PluginAuthor> pluginAuthors() const override;
+    QList<PluginAuthor> pluginAuthors() const override;
 
     QIcon icon() const override;
 
@@ -57,30 +57,30 @@ class PhotoPlugin : public AbstractDataPlugin, public DialogConfigurationInterfa
     /**
      * @return: The settings of the item.
      */
-    QHash<QString,QVariant> settings() const override;
+    QHash<QString, QVariant> settings() const override;
 
     /**
      * Set the settings of the item.
      */
-    void setSettings( const QHash<QString,QVariant> &settings ) override;
+    void setSettings(const QHash<QString, QVariant> &settings) override;
 
- protected:
-    bool eventFilter( QObject *object, QEvent *event ) override;
+protected:
+    bool eventFilter(QObject *object, QEvent *event) override;
 
- private Q_SLOTS:
-   void readSettings();
-   void writeSettings();
+private Q_SLOTS:
+    void readSettings();
+    void writeSettings();
 
-   void updateSettings();
-   void checkNumberOfItems( quint32 number );
+    void updateSettings();
+    void checkNumberOfItems(quint32 number);
 
- private:
-    Ui::PhotoConfigWidget *ui_configWidget;
-    QDialog *m_configDialog;
+private:
+    Ui::PhotoConfigWidget *ui_configWidget = nullptr;
+    QDialog *m_configDialog = nullptr;
 
     QStringList m_checkStateList;
 };
 
 }
 
-#endif //PHOTOPLUGIN_H
+#endif // PHOTOPLUGIN_H
