@@ -15,38 +15,35 @@ namespace Marble
 class MarbleWidget;
 
 const quint32 numberOfImagesPerFetch = 15;
-  
+
 class PhotoPluginModel : public AbstractDataPluginModel
 {
     Q_OBJECT
-    
- public:
-    explicit PhotoPluginModel( const MarbleModel *marbleModel, QObject *parent = nullptr );
-    
-    static QUrl generateUrl( const QString& service,
-                             const QString& method,
-                             const QHash<QString,QString>& options );
 
-    void setMarbleWidget( MarbleWidget* widget );
+public:
+    explicit PhotoPluginModel(const MarbleModel *marbleModel, QObject *parent = nullptr);
 
-    void setLicenseValues( const QString &licenses );
- 
- protected:
+    static QUrl generateUrl(const QString &service, const QString &method, const QHash<QString, QString> &options);
+
+    void setMarbleWidget(MarbleWidget *widget);
+
+    void setLicenseValues(const QString &licenses);
+
+protected:
     /**
      * Generates the download url for the description file from the web service depending on
      * the @p box surrounding the view and the @p number of files to show.
      **/
-    void getAdditionalItems( const GeoDataLatLonAltBox& box,
-                             qint32 number = 10 ) override;
-       
+    void getAdditionalItems(const GeoDataLatLonAltBox &box, qint32 number = 10) override;
+
     /**
      * The reimplementation has to parse the @p file and should generate items. This items
      * have to be scheduled to downloadItemData or could be directly added to the list,
      * depending on if they have to download information to be shown.
      **/
-    void parseFile( const QByteArray& file ) override;
+    void parseFile(const QByteArray &file) override;
 
- private:
+private:
     MarbleWidget *m_marbleWidget;
 
     QString m_licenses;
@@ -54,4 +51,4 @@ class PhotoPluginModel : public AbstractDataPluginModel
 
 }
 
-#endif //PHOTOPLUGINMODEL_H
+#endif // PHOTOPLUGINMODEL_H
