@@ -8,32 +8,32 @@
 
 #include "AbstractDataPluginModel.h"
 
-namespace Marble {
+namespace Marble
+{
 
 class PostalCodeModel : public AbstractDataPluginModel
 {
     Q_OBJECT
 
- public:
-    explicit PostalCodeModel( const MarbleModel *marbleModel, QObject *parent = nullptr );
+public:
+    explicit PostalCodeModel(const MarbleModel *marbleModel, QObject *parent = nullptr);
     ~PostalCodeModel() override;
 
- protected:
+protected:
     /**
      * Generates the download url for the description file from the web service depending on
      * the @p box surrounding the view and the @p number of files to show.
      **/
-    void getAdditionalItems( const GeoDataLatLonAltBox& box,
-                             qint32 number = 10 ) override;
+    void getAdditionalItems(const GeoDataLatLonAltBox &box, qint32 number = 10) override;
 
     /**
      * Parses the @p file which getAdditionalItems downloads and
      * prepares the data for usage.
      **/
-    void parseFile( const QByteArray& file ) override;
+    void parseFile(const QByteArray &file) override;
 
 private:
-    static void addLine( QString* string, const QString &line );
+    static void addLine(QString *string, const QString &line);
 };
 
 }
