@@ -3,7 +3,6 @@
 // SPDX-FileCopyrightText: 2013 Mihail Ivchenko <ematirov@gmail.com>
 //
 
-
 #ifndef MARBLE_CYCLESTREETSPLUGIN_H
 #define MARBLE_CYCLESTREETSPLUGIN_H
 
@@ -16,10 +15,10 @@ class CycleStreetsPlugin : public RoutingRunnerPlugin
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.kde.marble.CycleStreetsPlugin")
-    Q_INTERFACES( Marble::RoutingRunnerPlugin )
+    Q_INTERFACES(Marble::RoutingRunnerPlugin)
 
 public:
-    explicit CycleStreetsPlugin( QObject *parent = nullptr );
+    explicit CycleStreetsPlugin(QObject *parent = nullptr);
 
     QString name() const override;
 
@@ -33,14 +32,13 @@ public:
 
     QString copyrightYears() const override;
 
-    QVector<PluginAuthor> pluginAuthors() const override;
+    QList<PluginAuthor> pluginAuthors() const override;
 
     RoutingRunner *newRunner() const override;
 
-    ConfigWidget* configWidget() override;
-
-    bool supportsTemplate( RoutingProfilesModel::ProfileTemplate profileTemplate ) const override;
+    ConfigWidget *configWidget() override;
 
+    bool supportsTemplate(RoutingProfilesModel::ProfileTemplate profileTemplate) const override;
 };
 
 }
