@@ -5,12 +5,9 @@
 
 #include "GPXeleTagHandler.h"
 
-#include "MarbleDebug.h"
-
 #include "GPXElementDictionary.h"
-#include "GeoParser.h"
-#include "GeoDataPoint.h"
 #include "GeoDataTrack.h"
+#include "GeoParser.h"
 
 namespace Marble
 {
@@ -18,15 +15,14 @@ namespace gpx
 {
 GPX_DEFINE_TAG_HANDLER(ele)
 
-GeoNode* GPXeleTagHandler::parse(GeoParser& parser) const
+GeoNode *GPXeleTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(gpxTag_ele)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(gpxTag_ele)));
 
     GeoStackItem parentItem = parser.parentElement();
-    if (parentItem.represents(gpxTag_trkpt))
-    {
-        GeoDataTrack* track = parentItem.nodeAs<GeoDataTrack>();
-        track->appendAltitude( parser.readElementText().trimmed().toDouble() );
+    if (parentItem.represents(gpxTag_trkpt)) {
+        auto track = parentItem.nodeAs<GeoDataTrack>();
+        track->appendAltitude(parser.readElementText().trimmed().toDouble());
         return track;
     }
     return nullptr;
