@@ -5,13 +5,13 @@
 
 #include "GPXtrkptTagHandler.h"
 
-#include "MarbleDebug.h"
+#include <QStringView>
 
 #include "GPXElementDictionary.h"
-#include "GeoParser.h"
-#include "GeoDataLineString.h"
 #include "GeoDataCoordinates.h"
+#include "GeoDataLineString.h"
 #include "GeoDataTrack.h"
+#include "GeoParser.h"
 
 namespace Marble
 {
@@ -19,32 +19,29 @@ namespace gpx
 {
 GPX_DEFINE_TAG_HANDLER(trkpt)
 
-GeoNode* GPXtrkptTagHandler::parse(GeoParser& parser) const
+GeoNode *GPXtrkptTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(gpxTag_trkpt)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(gpxTag_trkpt)));
 
     GeoStackItem parentItem = parser.parentElement();
-    if (parentItem.represents(gpxTag_trkseg))
-    {
-        GeoDataTrack* track = parentItem.nodeAs<GeoDataTrack>();
+    if (parentItem.represents(gpxTag_trkseg)) {
+        auto track = parentItem.nodeAs<GeoDataTrack>();
         GeoDataCoordinates coord;
 
         QXmlStreamAttributes attributes = parser.attributes();
-        QStringRef tmp;
+        QStringView tmp;
         qreal lat = 0;
         qreal lon = 0;
-        tmp = attributes.value(QLatin1String(gpxTag_lat));
-        if ( !tmp.isEmpty() )
-        {
+        tmp = attributes.value(QLatin1StringView(gpxTag_lat));
+        if (!tmp.isEmpty()) {
             lat = tmp.toString().toDouble();
         }
-        tmp = attributes.value(QLatin1String(gpxTag_lon));
-        if ( !tmp.isEmpty() )
-        {
+        tmp = attributes.value(QLatin1StringView(gpxTag_lon));
+        if (!tmp.isEmpty()) {
             lon = tmp.toString().toDouble();
         }
         coord.set(lon, lat, 0, GeoDataCoordinates::Degree);
-        track->appendCoordinates( coord );
+        track->appendCoordinates(coord);
 
         return track;
     }
