@@ -5,12 +5,9 @@
 
 #include "GPXtypeTagHandler.h"
 
-#include "MarbleDebug.h"
-
 #include "GPXElementDictionary.h"
-#include "GeoParser.h"
 #include "GeoDataPlacemark.h"
-#include "GeoDataPoint.h"
+#include "GeoParser.h"
 
 namespace Marble
 {
@@ -21,22 +18,17 @@ GPX_DEFINE_TAG_HANDLER(type)
 // type is used in wpt, rte and trk to provide some sort of keyword, like "Geocache/traditional cache",
 // and in link to provide a mimetype
 
-GeoNode* GPXtypeTagHandler::parse(GeoParser& parser) const
+GeoNode *GPXtypeTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(gpxTag_type)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(gpxTag_type)));
 
     GeoStackItem parentItem = parser.parentElement();
-    if (parentItem.represents(gpxTag_wpt)
-        || parentItem.represents(gpxTag_trk)
-        || parentItem.represents(gpxTag_rtept))
-    {
-        GeoDataPlacemark* placemark = parentItem.nodeAs<GeoDataPlacemark>();
+    if (parentItem.represents(gpxTag_wpt) || parentItem.represents(gpxTag_trk) || parentItem.represents(gpxTag_rtept)) {
+        auto placemark = parentItem.nodeAs<GeoDataPlacemark>();
 
         placemark->setRole(parser.readElementText().trimmed());
-    }
-    else if (parentItem.represents(gpxTag_rte))
-    {
-        GeoDataFeature* route = parentItem.nodeAs<GeoDataFeature>();
+    } else if (parentItem.represents(gpxTag_rte)) {
+        auto route = parentItem.nodeAs<GeoDataFeature>();
         route->setRole(parser.readElementText().trimmed());
     }
     // TODO: tracks, link
