@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2010      Dennis Nienhüser <nienhueser@kde.org>
+// SPDX-FileCopyrightText: 2010 Dennis Nienhüser <nienhueser@kde.org>
 //
 
 #include "HostipPlugin.h"
@@ -15,21 +10,21 @@
 namespace Marble
 {
 
-HostipPlugin::HostipPlugin( QObject *parent ) :
-    SearchRunnerPlugin( parent )
+HostipPlugin::HostipPlugin(QObject *parent)
+    : SearchRunnerPlugin(parent)
 {
     setSupportedCelestialBodies(QStringList(QStringLiteral("earth")));
-    setCanWorkOffline( false );
+    setCanWorkOffline(false);
 }
 
 QString HostipPlugin::name() const
 {
-    return tr( "Hostip.info Search" );
+    return tr("Hostip.info Search");
 }
 
 QString HostipPlugin::guiString() const
 {
-    return tr( "Hostip.info" );
+    return tr("Hostip.info");
 }
 
 QString HostipPlugin::nameId() const
@@ -44,7 +39,7 @@ QString HostipPlugin::version() const
 
 QString HostipPlugin::description() const
 {
-    return tr( "Host name and IP geolocation search using the hostip.info service" );
+    return tr("Host name and IP geolocation search using the hostip.info service");
 }
 
 QString HostipPlugin::copyrightYears() const
@@ -52,13 +47,12 @@ QString HostipPlugin::copyrightYears() const
     return QStringLiteral("2010");
 }
 
-QVector<PluginAuthor> HostipPlugin::pluginAuthors() const
+QList<PluginAuthor> HostipPlugin::pluginAuthors() const
 {
-    return QVector<PluginAuthor>()
-            << PluginAuthor(QStringLiteral("Dennis Nienhüser"), QStringLiteral("nienhueser@kde.org"));
+    return QList<PluginAuthor>() << PluginAuthor(QStringLiteral("Dennis Nienhüser"), QStringLiteral("nienhueser@kde.org"));
 }
 
-SearchRunner* HostipPlugin::newRunner() const
+SearchRunner *HostipPlugin::newRunner() const
 {
     return new HostipRunner;
 }
