@@ -7,11 +7,10 @@
 #include "LocalOsmSearchRunner.h"
 #include "DatabaseQuery.h"
 
-#include "MarbleDebug.h"
 #include "GeoDataPoint.h"
 
+#include <QList>
 #include <QString>
-#include <QVector>
 #include <QUrl>
 
 namespace Marble
@@ -19,11 +18,11 @@ namespace Marble
 
 QMap<OsmPlacemark::OsmCategory, GeoDataPlacemark::GeoDataVisualCategory> LocalOsmSearchRunner::m_categoryMap;
 
-LocalOsmSearchRunner::LocalOsmSearchRunner( const QStringList &databaseFiles, QObject *parent ) :
-    SearchRunner( parent ),
-    m_database( databaseFiles )
+LocalOsmSearchRunner::LocalOsmSearchRunner(const QStringList &databaseFiles, QObject *parent)
+    : SearchRunner(parent)
+    , m_database(databaseFiles)
 {
-    if ( m_categoryMap.isEmpty() ) {
+    if (m_categoryMap.isEmpty()) {
         m_categoryMap[OsmPlacemark::UnknownCategory] = GeoDataPlacemark::OsmSite;
         m_categoryMap[OsmPlacemark::Address] = GeoDataPlacemark::OsmSite;
         m_categoryMap[OsmPlacemark::AccomodationCamping] = GeoDataPlacemark::AccomodationCamping;
@@ -89,35 +88,32 @@ LocalOsmSearchRunner::LocalOsmSearchRunner( const QStringList &databaseFiles, QO
     }
 }
 
-LocalOsmSearchRunner::~LocalOsmSearchRunner()
+LocalOsmSearchRunner::~LocalOsmSearchRunner() = default;
+
+void LocalOsmSearchRunner::search(const QString &searchTerm, const GeoDataLatLonBox &preferred)
 {
-}
+    const DatabaseQuery userQuery(model(), searchTerm, preferred);
 
+    QList<OsmPlacemark> placemarks = m_database.find(userQuery);
 
-void LocalOsmSearchRunner::search( const QString &searchTerm, const GeoDataLatLonBox &preferred )
-{
-    const DatabaseQuery userQuery( model(), searchTerm, preferred );
-
-    QVector<OsmPlacemark> placemarks = m_database.find( userQuery );
-
-    QVector<GeoDataPlacemark*> result;
-    for( const OsmPlacemark &placemark: placemarks ) {
-        GeoDataPlacemark* hit = new GeoDataPlacemark;
-        hit->setName( placemark.name() );
-        if ( placemark.category() == OsmPlacemark::Address && !placemark.houseNumber().isEmpty() ) {
+    QList<GeoDataPlacemark *> result;
+    for (const OsmPlacemark &placemark : std::as_const(placemarks)) {
+        auto hit = new GeoDataPlacemark;
+        hit->setName(placemark.name());
+        if (placemark.category() == OsmPlacemark::Address && !placemark.houseNumber().isEmpty()) {
             hit->setName(hit->name() + QLatin1Char(' ') + placemark.houseNumber());
         }
-        if ( !placemark.additionalInformation().isEmpty() ) {
+        if (!placemark.additionalInformation().isEmpty()) {
             hit->setName(hit->name() + QLatin1Char('(') + placemark.additionalInformation() + QLatin1Char(')'));
         }
-        if ( placemark.category() != OsmPlacemark::UnknownCategory ) {
-            hit->setVisualCategory( m_categoryMap[placemark.category()] );
+        if (placemark.category() != OsmPlacemark::UnknownCategory) {
+            hit->setVisualCategory(m_categoryMap[placemark.category()]);
         }
-        hit->setGeometry( new GeoDataPoint( placemark.longitude(), placemark.latitude(), 0.0, GeoDataCoordinates::Degree ) );
+        hit->setGeometry(new GeoDataPoint(placemark.longitude(), placemark.latitude(), 0.0, GeoDataCoordinates::Degree));
         result << hit;
     }
 
-    emit searchFinished( result );
+    Q_EMIT searchFinished(result);
 }
 
 } // namespace Marble
