@@ -10,24 +10,25 @@
 #define OSMPARSER_H
 
 #include "OsmNode.h"
-#include "OsmWay.h"
 #include "OsmRelation.h"
+#include "OsmWay.h"
 
 #include <QString>
 
-namespace Marble {
+namespace Marble
+{
 
 class GeoDataDocument;
 
 class OsmParser
 {
 public:
-    static GeoDataDocument* parse(const QString &filename, QString &error);
+    static GeoDataDocument *parse(const QString &filename, QString &error);
 
 private:
-    static GeoDataDocument* parseXml(const QString &filename, QString &error);
-    static GeoDataDocument* parseO5m(const QString &filename, QString &error);
-    static GeoDataDocument* parseOsmPbf(const QString &filename, QString &error);
+    static GeoDataDocument *parseXml(const QString &filename, QString &error);
+    static GeoDataDocument *parseO5m(const QString &filename, QString &error);
+    static GeoDataDocument *parseOsmPbf(const QString &filename, QString &error);
     static GeoDataDocument *createDocument(OsmNodes &nodes, OsmWays &way, OsmRelations &relations);
 };
 
