@@ -8,34 +8,34 @@
 
 #include "OsmNode.h"
 #include "OsmWay.h"
-#include <osm/OsmPlacemarkData.h>
 #include <GeoDataLinearRing.h>
+#include <osm/OsmPlacemarkData.h>
 
+#include <QSet>
 #include <QString>
 #include <QXmlStreamAttributes>
-#include <QSet>
 
-namespace Marble {
+namespace Marble
+{
 
 class GeoDataDocument;
 
 class OsmRelation
 {
 public:
-    OsmPlacemarkData & osmData();
+    OsmPlacemarkData &osmData();
     void parseMember(const QXmlStreamAttributes &attributes);
     void addMember(qint64 reference, const QString &role, const QString &type);
-    void createMultipolygon(GeoDataDocument* document, OsmWays &ways, const OsmNodes &nodes, QSet<qint64> &usedNodes, QSet<qint64> &usedWays) const;
-    void createRelation(GeoDataDocument* document, const QHash<qint64, GeoDataPlacemark*>& wayPlacemarks) const;
+    void createMultipolygon(GeoDataDocument *document, OsmWays &ways, const OsmNodes &nodes, QSet<qint64> &usedNodes, QSet<qint64> &usedWays) const;
+    void createRelation(GeoDataDocument *document, const QHash<qint64, GeoDataPlacemark *> &wayPlacemarks) const;
 
-    const OsmPlacemarkData & osmData() const;
+    const OsmPlacemarkData &osmData() const;
 
 private:
-    typedef QPair<GeoDataLinearRing, OsmPlacemarkData> OsmRing;
-    using OsmRings = QVector<OsmRing>;
+    using OsmRing = QPair<GeoDataLinearRing, OsmPlacemarkData>;
+    using OsmRings = QList<OsmRing>;
 
-    struct OsmMember
-    {
+    struct OsmMember {
         QString type;
         QString role;
         qint64 reference;
@@ -46,11 +46,10 @@ private:
     OsmRings rings(const QStringList &roles, const OsmWays &ways, const OsmNodes &nodes, QSet<qint64> &usedNodes, QSet<qint64> &usedWays) const;
 
     OsmPlacemarkData m_osmData;
-    QVector<OsmMember> m_members;
+    QList<OsmMember> m_members;
 };
 
-typedef QHash<qint64,OsmRelation> OsmRelations;
-
+using OsmRelations = QHash<qint64, OsmRelation>;
 }
 
 #endif
