@@ -6,28 +6,29 @@
 #ifndef MARBLE_OSMWAY
 #define MARBLE_OSMWAY
 
-#include "OsmNode.h"
 #include "GeoDataBuilding.h"
-#include <osm/OsmPlacemarkData.h>
+#include "OsmNode.h"
 #include <StyleBuilder.h>
+#include <osm/OsmPlacemarkData.h>
 
 #include <QSet>
 #include <QString>
 
-namespace Marble {
+namespace Marble
+{
 
 class GeoDataDocument;
 
 class OsmWay
 {
 public:
-    OsmPlacemarkData & osmData();
+    OsmPlacemarkData &osmData();
     void addReference(qint64 id);
 
-    const OsmPlacemarkData & osmData() const;
-    const QVector<qint64> &references() const;
+    const OsmPlacemarkData &osmData() const;
+    const QList<qint64> &references() const;
 
-    GeoDataPlacemark* create(const OsmNodes &nodes, QSet<qint64> &usedNodes) const;
+    GeoDataPlacemark *create(const OsmNodes &nodes, QSet<qint64> &usedNodes) const;
 
 private:
     bool isArea() const;
@@ -39,18 +40,17 @@ private:
     static bool isBuildingTag(const StyleBuilder::OsmTag &keyValue);
 
     OsmPlacemarkData m_osmData;
-    QVector<qint64> m_references;
+    QList<qint64> m_references;
 
     static QSet<StyleBuilder::OsmTag> s_areaTags;
     static QSet<StyleBuilder::OsmTag> s_buildingTags;
 
     QString extractBuildingName() const;
     double extractBuildingHeight() const;
-    QVector<GeoDataBuilding::NamedEntry> extractNamedEntries() const;
+    QList<GeoDataBuilding::NamedEntry> extractNamedEntries() const;
 };
 
-typedef QHash<qint64,OsmWay> OsmWays;
-
+using OsmWays = QHash<qint64, OsmWay>;
 }
 
 #endif
