@@ -3,7 +3,6 @@
 // SPDX-FileCopyrightText: 2012 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
 //
 
-
 #include "RenderPluginModel.h"
 #include "MarbleMap.h"
 #include "TestUtils.h"
@@ -15,19 +14,26 @@ class RenderPluginModelTest : public QObject
 {
     Q_OBJECT
 
- public:
-    RenderPluginModelTest() :
-        m_map( nullptr )
-    {}
+public:
+    RenderPluginModelTest()
+        : m_map(nullptr)
+    {
+    }
 
- private Q_SLOTS:
-    void initTestCase() { m_map = new MarbleMap(); }
-    void cleanupTestCase() { delete m_map; }
+private Q_SLOTS:
+    void initTestCase()
+    {
+        m_map = new MarbleMap();
+    }
+    void cleanupTestCase()
+    {
+        delete m_map;
+    }
 
     void construct();
     void setRenderPlugins();
 
- private:
+private:
     MarbleMap *m_map;
 };
 
@@ -35,19 +41,19 @@ void RenderPluginModelTest::construct()
 {
     const RenderPluginModel model;
 
-    QCOMPARE( model.rowCount(), 0 );
+    QCOMPARE(model.rowCount(), 0);
 }
 
 void RenderPluginModelTest::setRenderPlugins()
 {
     RenderPluginModel model;
-    model.setRenderPlugins( m_map->renderPlugins() );
+    model.setRenderPlugins(m_map->renderPlugins());
 
-    QCOMPARE( model.rowCount(), m_map->renderPlugins().count() );
+    QCOMPARE(model.rowCount(), m_map->renderPlugins().count());
 }
 
 }
 
-QTEST_MAIN( Marble::RenderPluginModelTest )
+QTEST_MAIN(Marble::RenderPluginModelTest)
 
 #include "RenderPluginModelTest.moc"
