@@ -11,14 +11,14 @@
 
 #include <QSignalMapper>
 
-Thread::Thread( QObject * const parent )
-    : QThread( parent )
+Thread::Thread(QObject *const parent)
+    : QThread(parent)
 {
     // we need a class that receives signals from other threads and emits a signal in response
     m_shutDownHelper = new QSignalMapper;
-    m_shutDownHelper->setMapping( this, 0 );
-    connect( this, SIGNAL(started()), this, SLOT(setReadyStatus()), Qt::DirectConnection );
-    connect( this, SIGNAL(aboutToStop()), m_shutDownHelper, SLOT(map()));
+    m_shutDownHelper->setMapping(this, 0);
+    connect(this, &Thread::started, this, &Thread::setReadyStatus, Qt::DirectConnection);
+    connect(this, SIGNAL(aboutToStop()), m_shutDownHelper, SLOT(map()));
 }
 
 Thread::~Thread()
@@ -27,15 +27,15 @@ Thread::~Thread()
 }
 
 // starts thread, moves worker to this thread and blocks
-void Thread::launchWorker( QObject * const worker )
+void Thread::launchWorker(QObject *const worker)
 {
     m_worker = worker;
     start();
-    m_worker->moveToThread( this );
-    m_shutDownHelper->moveToThread( this );
-    connect( m_shutDownHelper, SIGNAL(mapped(int)), this, SLOT(stopExecutor()), Qt::DirectConnection );
+    m_worker->moveToThread(this);
+    m_shutDownHelper->moveToThread(this);
+    connect(m_shutDownHelper, &QSignalMapper::mappedInt, this, &Thread::stopExecutor, Qt::DirectConnection);
     m_mutex.lock();
-    m_waitCondition.wait( &m_mutex );
+    m_waitCondition.wait(&m_mutex);
 }
 
 // puts a command to stop processing in the event queue of worker thread
@@ -47,7 +47,7 @@ void Thread::stop()
 // methods above this line should be called in ui thread context
 // methods below this line are private and will be run in  secondary thread context
 
-void Thread::stopExecutor()  //secondary thread context
+void Thread::stopExecutor() // secondary thread context
 {
     exit();
 }
