@@ -6,15 +6,15 @@
 #ifndef MARBLE_OSMPARSER_H
 #define MARBLE_OSMPARSER_H
 
-#include "Writer.h"
-#include "OsmRegion.h"
 #include "OsmPlacemark.h"
+#include "OsmRegion.h"
 #include "OsmRegionTree.h"
+#include "Writer.h"
 
-#include <QObject>
 #include <QFileInfo>
 #include <QHash>
 #include <QList>
+#include <QObject>
 #include <QPair>
 
 namespace Marble
@@ -36,10 +36,13 @@ enum RelationRole {
 };
 
 struct OsmOsmRegion {
-    OsmOsmRegion* parent;
+    OsmOsmRegion *parent;
     OsmRegion region;
 
-    OsmOsmRegion() : parent( nullptr ) {}
+    OsmOsmRegion()
+        : parent(nullptr)
+    {
+    }
 };
 
 struct Element {
@@ -50,15 +53,18 @@ struct Element {
     QString city;
     OsmPlacemark::OsmCategory category;
 
-    Element() : save( false ),
-        category( OsmPlacemark::UnknownCategory ) {}
+    Element()
+        : save(false)
+        , category(OsmPlacemark::UnknownCategory)
+    {
+    }
 };
 
 struct Coordinate {
     float lon;
     float lat;
 
-    Coordinate(float lon=0.0, float lat=0.0);
+    Coordinate(float lon = 0.0, float lat = 0.0);
 };
 
 struct Node : public Element {
@@ -74,32 +80,39 @@ struct Way : public Element {
     bool isBuilding;
 
     operator OsmPlacemark() const;
-    void setPosition( const QHash<int, Coordinate> &database, OsmPlacemark &placemark ) const;
-    void setRegion( const QHash<int, Node> &database, const OsmRegionTree & tree, QList<OsmOsmRegion> & osmOsmRegions, OsmPlacemark &placemark ) const;
+    void setPosition(const QHash<int, Coordinate> &database, OsmPlacemark &placemark) const;
+    void setRegion(const QHash<int, Node> &database, const OsmRegionTree &tree, QList<OsmOsmRegion> &osmOsmRegions, OsmPlacemark &placemark) const;
 };
 
 struct WayMerger {
 public:
     QList<Way> ways;
 
-    WayMerger( const Way &way ) {
+    WayMerger(const Way &way)
+    {
         ways << way;
     }
 
-    bool compatible( const Way &aWay ) const {
-        for( const Way & way: ways ) {
-            if ( way.nodes.first() == aWay.nodes.first() ) return true;
-            if ( way.nodes.last()  == aWay.nodes.first() ) return true;
-            if ( way.nodes.first() == aWay.nodes.last() ) return true;
-            if ( way.nodes.last()  == aWay.nodes.last() ) return true;
+    bool compatible(const Way &aWay) const
+    {
+        for (const Way &way : ways) {
+            if (way.nodes.first() == aWay.nodes.first())
+                return true;
+            if (way.nodes.last() == aWay.nodes.first())
+                return true;
+            if (way.nodes.first() == aWay.nodes.last())
+                return true;
+            if (way.nodes.last() == aWay.nodes.last())
+                return true;
         }
 
         return false;
     }
 
-    bool compatible( const WayMerger &other ) const {
-        for( const Way & way: ways ) {
-            if ( other.compatible( way ) ) {
+    bool compatible(const WayMerger &other) const
+    {
+        for (const Way &way : ways) {
+            if (other.compatible(way)) {
                 return true;
             }
         }
@@ -107,23 +120,25 @@ public:
         return false;
     }
 
-    void merge( const WayMerger &other ) {
+    void merge(const WayMerger &other)
+    {
         ways << other.ways;
     }
 };
 
 struct Relation : public Element {
     QList<int> nodes;
-    QList< QPair<int, RelationRole> > ways;
+    QList<QPair<int, RelationRole>> ways;
     QList<int> relations;
     QString name;
     bool isMultipolygon;
     bool isAdministrativeBoundary;
     int adminLevel;
 
-    Relation() : isMultipolygon( false ),
-        isAdministrativeBoundary( false ),
-        adminLevel( 0 )
+    Relation()
+        : isMultipolygon(false)
+        , isAdministrativeBoundary(false)
+        , adminLevel(0)
     {
         // nothing to do
     }
@@ -133,29 +148,32 @@ struct Statistic {
     unsigned int mergedWays;
     unsigned int uselessWays;
 
-    Statistic() : mergedWays( 0 ),
-        uselessWays( 0 )
-    {}
+    Statistic()
+        : mergedWays(0)
+        , uselessWays(0)
+    {
+    }
 };
 
 class OsmParser : public QObject
 {
     Q_OBJECT
 public:
-    explicit OsmParser( QObject *parent = nullptr );
+    explicit OsmParser(QObject *parent = nullptr);
 
-    void addWriter( Writer* writer );
+    void addWriter(Writer *writer);
 
-    void read( const QFileInfo &file, const QString &areaName );
+    void read(const QFileInfo &file, const QString &areaName);
 
-    void writeKml( const QString &area, const QString &version, const QString &date, const QString &transport, const QString &payload, const QString &outputKml ) const;
+    void writeKml(const QString &area, const QString &version, const QString &date, const QString &transport, const QString &payload, const QString &outputKml)
+        const;
 
 protected:
-    virtual bool parse( const QFileInfo &file, int pass, bool &needAnotherPass ) = 0;
+    virtual bool parse(const QFileInfo &file, int pass, bool &needAnotherPass) = 0;
 
-    bool shouldSave( ElementType type, const QString &key, const QString &value );
+    bool shouldSave(ElementType type, const QString &key, const QString &value);
 
-    void setCategory( Element &element, const QString &key, const QString &value );
+    void setCategory(Element &element, const QString &key, const QString &value);
 
     QHash<int, Coordinate> m_coordinates;
 
@@ -168,24 +186,25 @@ protected:
 private:
     GeoDataLinearRing *convexHull() const;
 
-    void importMultipolygon( const Relation &relation );
+    void importMultipolygon(const Relation &relation);
 
-    void importWay( QVector<Marble::GeoDataLineString> &ways, int id );
+    void importWay(QList<Marble::GeoDataLineString> &ways, int id);
 
-    QList< QList<Way> > merge( const QList<Way> &ways ) const;
+    QList<QList<Way>> merge(const QList<Way> &ways) const;
 
     template<class T, class S>
-    bool contains( const T &outer, const S &inner ) const {
-        for ( int i = 0; i < inner.size(); ++i ) {
-            if ( !outer.contains( inner[i] ) ) {
+    bool contains(const T &outer, const S &inner) const
+    {
+        for (int i = 0; i < inner.size(); ++i) {
+            if (!outer.contains(inner[i])) {
                 bool onBorder = false;
-                for ( int k=0; k<outer.size(); ++k ) {
-                    if ( inner[i] == outer[k] ) {
+                for (int k = 0; k < outer.size(); ++k) {
+                    if (inner[i] == outer[k]) {
                         onBorder = true;
                         break;
                     }
                 }
-                if ( !onBorder ) {
+                if (!onBorder) {
                     return false;
                 }
             }
@@ -196,9 +215,9 @@ private:
 
     QColor randomColor() const;
 
-    Marble::GeoDataLineString reverse( const Marble::GeoDataLineString & string );
+    Marble::GeoDataLineString reverse(const Marble::GeoDataLineString &string);
 
-    QList<Writer*> m_writers;
+    QList<Writer *> m_writers;
 
     QList<OsmOsmRegion> m_osmOsmRegions;
 
@@ -208,7 +227,7 @@ private:
 
     mutable Statistic m_statistic;
 
-    GeoDataLinearRing* m_convexHull;
+    GeoDataLinearRing *m_convexHull;
 };
 
 }
