@@ -10,9 +10,14 @@ namespace Marble
 
 int OsmRegion::m_idFactory = 0;
 
-OsmRegion::OsmRegion() : m_identifier( ++m_idFactory ),
-    m_parent( 0 ), m_longitude( 0.0 ), m_latitude( 0.0 ),
-    m_left( 0 ), m_right( 0 ), m_adminLevel( 10 )
+OsmRegion::OsmRegion()
+    : m_identifier(++m_idFactory)
+    , m_parent(0)
+    , m_longitude(0.0)
+    , m_latitude(0.0)
+    , m_left(0)
+    , m_right(0)
+    , m_adminLevel(10)
 {
     // nothing to do
 }
@@ -22,7 +27,7 @@ int OsmRegion::identifier() const
     return m_identifier;
 }
 
-void OsmRegion::setIdentifier( int identifier )
+void OsmRegion::setIdentifier(int identifier)
 {
     m_identifier = identifier;
 }
@@ -32,7 +37,7 @@ int OsmRegion::parentIdentifier() const
     return m_parent;
 }
 
-void OsmRegion::setParentIdentifier( int identifier )
+void OsmRegion::setParentIdentifier(int identifier)
 {
     m_parent = identifier;
 }
@@ -42,7 +47,7 @@ QString OsmRegion::name() const
     return m_name;
 }
 
-void OsmRegion::setName( const QString &name )
+void OsmRegion::setName(const QString &name)
 {
     m_name = name;
 }
@@ -52,7 +57,7 @@ qreal OsmRegion::longitude() const
     return m_longitude;
 }
 
-void OsmRegion::setLongitude( qreal longitude )
+void OsmRegion::setLongitude(qreal longitude)
 {
     m_longitude = longitude;
 }
@@ -62,17 +67,17 @@ qreal OsmRegion::latitude() const
     return m_latitude;
 }
 
-void OsmRegion::setLatitude( qreal latitude )
+void OsmRegion::setLatitude(qreal latitude)
 {
     m_latitude = latitude;
 }
 
-bool OsmRegion::operator==( const OsmRegion &other ) const
+bool OsmRegion::operator==(const OsmRegion &other) const
 {
     return identifier() == other.identifier();
 }
 
-void OsmRegion::setLeft( int left )
+void OsmRegion::setLeft(int left)
 {
     m_left = left;
 }
@@ -82,7 +87,7 @@ int OsmRegion::left() const
     return m_left;
 }
 
-void OsmRegion::setRight( int right )
+void OsmRegion::setRight(int right)
 {
     m_right = right;
 }
@@ -92,12 +97,12 @@ int OsmRegion::right() const
     return m_right;
 }
 
-const GeoDataPolygon& OsmRegion::geometry() const
+const GeoDataPolygon &OsmRegion::geometry() const
 {
     return m_geometry;
 }
 
-void OsmRegion::setGeometry( const GeoDataPolygon &polygon )
+void OsmRegion::setGeometry(const GeoDataPolygon &polygon)
 {
     m_geometry = polygon;
 }
@@ -107,10 +112,8 @@ int OsmRegion::adminLevel() const
     return m_adminLevel;
 }
 
-void OsmRegion::setAdminLevel( int level )
+void OsmRegion::setAdminLevel(int level)
 {
     m_adminLevel = level;
 }
-
-
 }
