@@ -9,11 +9,13 @@
 #include "OsmPlacemarkData.h"
 #include "VectorClipper.h"
 
-namespace Marble {
+namespace Marble
+{
 
-class NodeReducer {
+class NodeReducer
+{
 public:
-    NodeReducer(GeoDataDocument* document, const TileId &tileId);
+    NodeReducer(GeoDataDocument *document, const TileId &tileId);
 
     qint64 removedNodes() const;
     qint64 remainingNodes() const;
@@ -23,15 +25,13 @@ private:
     qreal perpendicularDistance(const GeoDataCoordinates &a, const GeoDataCoordinates &b, const GeoDataCoordinates &c) const;
     bool touchesTileBorder(const GeoDataCoordinates &coordinates) const;
 
-    GeoDataLinearRing* reducedRing(const GeoDataLinearRing& prevRing,
-                                   GeoDataPlacemark* placemark,
-                                   const GeoDataPlacemark::GeoDataVisualCategory& visualCategory);
-    GeoDataPolygon* reducedPolygon(const GeoDataPolygon& prevPolygon,
-                                   GeoDataPlacemark* placemark,
-                                   const GeoDataPlacemark::GeoDataVisualCategory& visualCategory);
+    GeoDataLinearRing *
+    reducedRing(const GeoDataLinearRing &prevRing, GeoDataPlacemark *placemark, const GeoDataPlacemark::GeoDataVisualCategory &visualCategory);
+    GeoDataPolygon *
+    reducedPolygon(const GeoDataPolygon &prevPolygon, GeoDataPlacemark *placemark, const GeoDataPlacemark::GeoDataVisualCategory &visualCategory);
 
     template<class T>
-    void reduce(T const & lineString, OsmPlacemarkData& osmData, GeoDataPlacemark::GeoDataVisualCategory visualCategory, T* reducedLine)
+    void reduce(T const &lineString, OsmPlacemarkData &osmData, GeoDataPlacemark::GeoDataVisualCategory visualCategory, T *reducedLine)
     {
         bool const isArea = lineString.isClosed() && VectorClipper::canBeArea(visualCategory);
         qreal const epsilon = epsilonFor(isArea ? 45.0 : 30.0);
@@ -44,17 +44,17 @@ private:
     }
 
     template<class T>
-    T extract(T const & lineString, int start, int end) const
+    T extract(T const &lineString, int start, int end) const
     {
         T result;
-        for (int i=start; i<=end; ++i) {
+        for (int i = start; i <= end; ++i) {
             result << lineString[i];
         }
         return result;
     }
 
     template<class T>
-    T merge(T const & a, T const &b) const
+    T merge(T const &a, T const &b) const
     {
         T result = a;
         int const index = a.size();
@@ -64,7 +64,7 @@ private:
     }
 
     template<class T>
-    T douglasPeucker(T const & lineString, const OsmPlacemarkData &osmData, qreal epsilon) const
+    T douglasPeucker(T const &lineString, const OsmPlacemarkData &osmData, qreal epsilon) const
     {
         if (lineString.size() < 3) {
             return lineString;
@@ -72,8 +72,8 @@ private:
 
         double maxDistance = 0.0;
         int index = 1;
-        int const end = lineString.size()-1;
-        for (int i = 1; i<end; ++i) {
+        int const end = lineString.size() - 1;
+        for (int i = 1; i < end; ++i) {
             double const distance = perpendicularDistance(lineString[i], lineString[0], lineString[end]);
             if (distance > maxDistance) {
                 index = i;
@@ -89,7 +89,7 @@ private:
 
         T result;
         result << lineString[0];
-        for (int i=1; i<end; ++i) {
+        for (int i = 1; i < end; ++i) {
             // even if under the Douglas Peucker threshold, we keep the following nodes:
             // - nodes at a tile border
             // - nodes containing any OSM tag themselves
@@ -97,7 +97,7 @@ private:
             //   synthetic only line segments that geometry reassembly on the client might
             //   remove entirely and thus distort the original geometry.
             bool const keepNode = touchesTileBorder(lineString[i]) || !osmData.nodeReference(lineString[i]).isEmpty()
-                || osmData.nodeReference(lineString[i-1]).id() < 0 || ((i + 1) < end && osmData.nodeReference(lineString[i+1]).id() < 0);
+                || osmData.nodeReference(lineString[i - 1]).id() < 0 || ((i + 1) < end && osmData.nodeReference(lineString[i + 1]).id() < 0);
             if (keepNode) {
                 result << lineString[i];
             }
